@@ -14,11 +14,11 @@ void Gijab_UHF(void)
   nirreps = moinfo.nirreps;
 
   /* ( g(I,M) + L(M,E) T(I,E) ) --> Z(I,M)(TMP0)  */
-  dpd_file2_init(&g, CC_OEI, 0, 0, 0, "GMI");
+  dpd_file2_init(&g, CC_GLG, 0, 0, 0, "GMI");
   dpd_file2_copy(&g, CC_TMP0, "Z(I,M)");
   dpd_file2_close(&g);
   dpd_file2_init(&ZZ, CC_TMP0, 0, 0, 0, "Z(I,M)");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_file2_init(&T1, CC_OEI, 0, 0, 1, "tIA");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 1.0);
   dpd_file2_close(&T1);
@@ -26,11 +26,11 @@ void Gijab_UHF(void)
   dpd_file2_close(&ZZ);
 
   /* ( g(i,m) + L(m,e) T(i,e) ) --> Z(i,m)(TMP1)  */
-  dpd_file2_init(&g, CC_OEI, 0, 2, 2, "Gmi");
+  dpd_file2_init(&g, CC_GLG, 0, 2, 2, "Gmi");
   dpd_file2_copy(&g, CC_TMP1, "Z(i,m)");
   dpd_file2_close(&g);
   dpd_file2_init(&ZZ, CC_TMP1, 0, 2, 2, "Z(i,m)");
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_file2_init(&T1, CC_OEI, 0, 2, 3, "tia");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 1.0);
   dpd_file2_close(&T1);
@@ -38,11 +38,11 @@ void Gijab_UHF(void)
   dpd_file2_close(&ZZ);
 
   /* ( g(E,A) - L(M,E) T(M,A) ) --> Z(E,A)(TMP2) */
-  dpd_file2_init(&g, CC_OEI, 0, 1, 1, "GAE");
+  dpd_file2_init(&g, CC_GLG, 0, 1, 1, "GAE");
   dpd_file2_copy(&g, CC_TMP2, "Z(E,A)");
   dpd_file2_close(&g);
   dpd_file2_init(&ZZ, CC_TMP2, 0, 1, 1, "Z(E,A)");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_file2_init(&T1, CC_OEI, 0, 0, 1, "tIA");
   dpd_contract222(&L1, &T1, &ZZ, 1, 1, -1.0, 1.0);
   dpd_file2_close(&T1);
@@ -50,11 +50,11 @@ void Gijab_UHF(void)
   dpd_file2_close(&ZZ);
 
   /* ( g(e,a) - L(m,e) T(m,a) ) --> Z(e,a)(TMP3) */
-  dpd_file2_init(&g, CC_OEI, 0, 3, 3, "Gae");
+  dpd_file2_init(&g, CC_GLG, 0, 3, 3, "Gae");
   dpd_file2_copy(&g, CC_TMP3, "Z(e,a)");
   dpd_file2_close(&g);
   dpd_file2_init(&ZZ, CC_TMP3, 0, 3, 3, "Z(e,a)");
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_file2_init(&T1, CC_OEI, 0, 2, 3, "tia");
   dpd_contract222(&L1, &T1, &ZZ, 1, 1, -1.0, 1.0);
   dpd_file2_close(&T1);
@@ -196,14 +196,16 @@ void Gijab_UHF(void)
   dpd_file2_close(&T1B);
 
   /* L(IJ,AB) */
-  dpd_buf4_init(&L, CC_LAMPS, 0, 2, 7, 2, 7, 0, "LIJAB");
+  dpd_buf4_init(&L, CC_GLG, 0, 2, 7, 2, 7, 0, "LIJAB");
   dpd_buf4_copy(&L, CC_GAMMA, "GIJAB");
   dpd_buf4_close(&L);
   dpd_buf4_init(&G, CC_GAMMA, 0, 2, 7, 2, 7, 0, "GIJAB");
-  /* Tau(IJ,AB) */
-  dpd_buf4_init(&T, CC_TAMPS, 0, 2, 7, 2, 7, 0, "tauIJAB");
-  dpd_buf4_axpy(&T, &G, 1.0);
-  dpd_buf4_close(&T);
+  /* Tau(IJ,AB) * (L0*R0 = 1, ground or 0, excited */
+  if (params.ground) {
+    dpd_buf4_init(&T, CC_TAMPS, 0, 2, 7, 2, 7, 0, "tauIJAB");
+    dpd_buf4_axpy(&T, &G, 1.0);
+    dpd_buf4_close(&T);
+  }
   /* V(IJ,MN) Tau(MN,AB) */
   dpd_buf4_init(&T, CC_TAMPS, 0, 2, 7, 2, 7, 0, "tauIJAB");
   dpd_buf4_init(&V, CC_MISC, 0, 2, 2, 2, 2, 0, "VMNIJ");
@@ -275,12 +277,12 @@ void Gijab_UHF(void)
   dpd_buf4_close(&G);
   /* T'(IA,ME) (TMP4) L(M,E) + T'(IA,me) (T2) L(m,e) --> ZZ(I,A) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 0, 1, "ZZ(I,A)");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_buf4_init(&T, CC_TMP4, 0, 20, 20, 20, 20, 0, "Z(IA,ME)");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_buf4_close(&T);
   dpd_file2_close(&L1);
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_buf4_init(&T, CC_TAMPS, 0, 20, 30, 20, 30, 0, "tIAjb");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, -1.0, 1.0);
   dpd_buf4_close(&T);
@@ -353,7 +355,7 @@ void Gijab_UHF(void)
   /* T(J,E) L(M,E) --> ZZ(J,M) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 0, 0, "Z(J,M)");
   dpd_file2_init(&T1, CC_OEI, 0, 0, 1, "tIA");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_file2_close(&L1);
   dpd_file2_close(&T1);
@@ -433,14 +435,16 @@ void Gijab_UHF(void)
 
 
   /* L(ij,ab) */
-  dpd_buf4_init(&L, CC_LAMPS, 0, 12, 17, 12, 17, 0, "Lijab");
+  dpd_buf4_init(&L, CC_GLG, 0, 12, 17, 12, 17, 0, "Lijab");
   dpd_buf4_copy(&L, CC_GAMMA, "Gijab");
   dpd_buf4_close(&L);
   dpd_buf4_init(&G, CC_GAMMA, 0, 12, 17, 12, 17, 0, "Gijab");
-  /* Tau(ij,ab) */
-  dpd_buf4_init(&T, CC_TAMPS, 0, 12, 17, 12, 17, 0, "tauijab");
-  dpd_buf4_axpy(&T, &G, 1.0);
-  dpd_buf4_close(&T);
+  /* Tau(ij,ab) * (L0*R0 = 1, ground or 0, excited */
+  if (params.ground) {
+    dpd_buf4_init(&T, CC_TAMPS, 0, 12, 17, 12, 17, 0, "tauijab");
+    dpd_buf4_axpy(&T, &G, 1.0);
+    dpd_buf4_close(&T);
+  }
   /* V(ij,mn) Tau(mn,ab) */
   dpd_buf4_init(&T, CC_TAMPS, 0, 12, 17, 12, 17, 0, "tauijab");
   dpd_buf4_init(&V, CC_MISC, 0, 12, 12, 12, 12, 0, "Vmnij");
@@ -512,12 +516,12 @@ void Gijab_UHF(void)
   dpd_buf4_close(&G);
   /* T'(ia,me) (TMP5) L(m,e) + T'(ia,ME) (T2) L(M,E) --> ZZ(i,a) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 2, 3, "ZZ(i,a)");
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_buf4_init(&T, CC_TMP5, 0, 30, 30, 30, 30, 0, "Z(ia,me)");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_buf4_close(&T);
   dpd_file2_close(&L1);
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_buf4_init(&T, CC_TAMPS, 0, 30, 20, 30, 20, 0, "tiaJB");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, -1.0, 1.0);
   dpd_buf4_close(&T);
@@ -590,7 +594,7 @@ void Gijab_UHF(void)
   /* T(j,e) L(m,e) --> ZZ(j,m) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 2, 2, "Z(j,m)");
   dpd_file2_init(&T1, CC_OEI, 0, 2, 3, "tia");
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_file2_close(&L1);
   dpd_file2_close(&T1);
@@ -670,14 +674,16 @@ void Gijab_UHF(void)
 
 
   /* L(Ij,Ab) */
-  dpd_buf4_init(&L, CC_LAMPS, 0, 22, 28, 22, 28, 0, "LIjAb");
+  dpd_buf4_init(&L, CC_GLG, 0, 22, 28, 22, 28, 0, "LIjAb");
   dpd_buf4_copy(&L, CC_GAMMA, "GIjAb");
   dpd_buf4_close(&L);
   dpd_buf4_init(&G, CC_GAMMA, 0, 22, 28, 22, 28, 0, "GIjAb");
-  /* Tau(Ij,Ab) */
-  dpd_buf4_init(&T, CC_TAMPS, 0, 22, 28, 22, 28, 0, "tauIjAb");
-  dpd_buf4_axpy(&T, &G, 1.0);
-  dpd_buf4_close(&T);
+  /* Tau(Ij,Ab) * (L0*R0 = 1, ground or 0, excited */
+  if (params.ground) {
+    dpd_buf4_init(&T, CC_TAMPS, 0, 22, 28, 22, 28, 0, "tauIjAb");
+    dpd_buf4_axpy(&T, &G, 1.0);
+    dpd_buf4_close(&T);
+  }
   /* V(Ij,Mn) Tau(Mn,Ab) */
   dpd_buf4_init(&T, CC_TAMPS, 0, 22, 28, 22, 28, 0, "tauIjAb");
   dpd_buf4_init(&V, CC_MISC, 0, 22, 22, 22, 22, 0, "VMnIj");
@@ -795,12 +801,12 @@ void Gijab_UHF(void)
   dpd_buf4_close(&G);
   /* T'(IA,me) (T2) L(m,e) + T'(IA,ME) (TMP4) L(M,E) --> ZZ(I,A) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 0, 1, "ZZ(I,A)");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_buf4_init(&T, CC_TMP4, 0, 20, 20, 20, 20, 0, "Z(IA,ME)");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_buf4_close(&T);
   dpd_file2_close(&L1);
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_buf4_init(&T, CC_TAMPS, 0, 20, 30, 20, 30, 0, "tIAjb");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, -1.0, 1.0);
   dpd_buf4_close(&T);
@@ -852,12 +858,12 @@ void Gijab_UHF(void)
 
   /* T'(jb,ME) (T2) L(M,E) + T'(jb,me) (TMP5) L(m,e) --> ZZ(j,b) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 2, 3, "ZZ(j,b)");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_buf4_init(&T, CC_TAMPS, 0, 30, 20, 30, 20, 0, "tiaJB");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, -1.0, 0.0);
   dpd_buf4_close(&T);
   dpd_file2_close(&L1);
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_buf4_init(&T, CC_TMP5, 0, 30, 30, 30, 30, 0, "Z(ia,me)");
   dpd_contract422(&T, &L1, &ZZ, 0, 0, 1.0, 1.0);
   dpd_buf4_close(&T);
@@ -910,7 +916,7 @@ void Gijab_UHF(void)
   /* T(j,e) L(m,e) --> ZZ(j,m) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 2, 2, "Z(j,m)");
   dpd_file2_init(&T1, CC_OEI, 0, 2, 3, "tia");
-  dpd_file2_init(&L1, CC_OEI, 0, 2, 3, "Lia");
+  dpd_file2_init(&L1, CC_GLG, 0, 2, 3, "Lia");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_file2_close(&L1);
   dpd_file2_close(&T1);
@@ -969,7 +975,7 @@ void Gijab_UHF(void)
   /* T(I,E) L(M,E) --> ZZ(I,M) */
   dpd_file2_init(&ZZ, CC_TMP8, 0, 0, 0, "Z(I,M)");
   dpd_file2_init(&T1, CC_OEI, 0, 0, 1, "tIA");
-  dpd_file2_init(&L1, CC_OEI, 0, 0, 1, "LIA");
+  dpd_file2_init(&L1, CC_GLG, 0, 0, 1, "LIA");
   dpd_contract222(&T1, &L1, &ZZ, 0, 0, 1.0, 0.0);
   dpd_file2_close(&L1);
   dpd_file2_close(&T1);
