@@ -26,11 +26,11 @@
 ** G'mpmr = Dpr + Gmpmr
 ** */
 
-void fold_ROHF(void);
-void fold_UHF(void);
+void fold_ROHF(struct RHO_Params rho_params);
+void fold_UHF(struct RHO_Params rho_params);
 
-void fold(void)
+void fold(struct RHO_Params rho_params)
 {
-  if(params.ref == 0 || params.ref == 1) fold_ROHF();
-  else if(params.ref == 2) fold_UHF();
+  if(params.ref == 0 || params.ref == 1) fold_ROHF(rho_params);
+  else if(params.ref == 2) fold_UHF(rho_params);
 }
