@@ -28,7 +28,7 @@
 ** G'mpmr = Dpr + Gmpmr
 ** */
 
-void fold_UHF(void)
+void fold_UHF(struct RHO_Params rho_params)
 {
   int h, nirreps;
   int i, j, k, l, m, a, b;
@@ -57,7 +57,7 @@ void fold_UHF(void)
   fprintf(outfile, "\n\tEnergies re-computed from Fock-adjusted CC density:\n");
   fprintf(outfile,   "\t---------------------------------------------------\n");
 
-  dpd_file2_init(&D, CC_OEI, 0, 0, 0, "DIJ");
+  dpd_file2_init(&D, CC_OEI, 0, 0, 0, rho_params.DIJ_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 0, 0, "h(I,J)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -65,7 +65,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDIJ = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 2, 2, "Dij");
+  dpd_file2_init(&D, CC_OEI, 0, 2, 2, rho_params.Dij_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 2, 2, "h(i,j)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -74,7 +74,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDij = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 1, 1, "DAB");
+  dpd_file2_init(&D, CC_OEI, 0, 1, 1, rho_params.DAB_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 1, 1, "h(A,B)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -83,7 +83,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDAB = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 3, 3, "Dab");
+  dpd_file2_init(&D, CC_OEI, 0, 3, 3, rho_params.Dab_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 3, 3, "h(a,b)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -92,7 +92,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDab = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 0, 1, "DIA");
+  dpd_file2_init(&D, CC_OEI, 0, 0, 1, rho_params.DIA_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 0, 1, "h(I,A)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -101,7 +101,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDIA = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 2, 3, "Dia");
+  dpd_file2_init(&D, CC_OEI, 0, 2, 3, rho_params.Dia_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 2, 3, "h(i,a)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -110,7 +110,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDia = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 0, 1, "DAI");
+  dpd_file2_init(&D, CC_OEI, 0, 0, 1, rho_params.DAI_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 0, 1, "h(I,A)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -119,7 +119,7 @@ void fold_UHF(void)
   /*  fprintf(outfile, "\tDAI = %20.15f\n", this_energy); */
   one_energy += this_energy;
 
-  dpd_file2_init(&D, CC_OEI, 0, 2, 3, "Dai");
+  dpd_file2_init(&D, CC_OEI, 0, 2, 3, rho_params.Dai_lbl);
   dpd_file2_init(&F, CC_OEI, 0, 2, 3, "h(i,a)");
   this_energy = dpd_file2_dot(&D, &F);
   dpd_file2_close(&F);
@@ -131,7 +131,7 @@ void fold_UHF(void)
   fprintf(outfile, "\tOne-electron energy        = %20.15f\n", one_energy);
   fflush(outfile);
 
-  dpd_file2_init(&D, CC_OEI, 0, 0, 0, "DIJ");
+  dpd_file2_init(&D, CC_OEI, 0, 0, 0, rho_params.DIJ_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -178,7 +178,7 @@ void fold_UHF(void)
   dpd_file2_mat_close(&D);
   dpd_file2_close(&D);
 
-  dpd_file2_init(&D, CC_OEI, 0, 2, 2, "Dij");
+  dpd_file2_init(&D, CC_OEI, 0, 2, 2, rho_params.Dij_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -224,7 +224,7 @@ void fold_UHF(void)
   dpd_file2_mat_close(&D);
   dpd_file2_close(&D);
 
-  dpd_file2_init(&D, CC_OEI, 0, 0, 0, "DIJ");
+  dpd_file2_init(&D, CC_OEI, 0, 0, 0, rho_params.DIJ_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -261,7 +261,7 @@ void fold_UHF(void)
   dpd_file2_close(&D);
 
 
-  dpd_file2_init(&D, CC_OEI, 0, 2, 2, "Dij");
+  dpd_file2_init(&D, CC_OEI, 0, 2, 2, rho_params.Dij_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -306,10 +306,10 @@ void fold_UHF(void)
   dpd_file2_mat_close(&D);
   dpd_file2_close(&D);
 
-  dpd_file2_init(&D1, CC_OEI, 0, 0, 1, "DIA");
+  dpd_file2_init(&D1, CC_OEI, 0, 0, 1, rho_params.DIA_lbl);
   dpd_file2_mat_init(&D1);
   dpd_file2_mat_rd(&D1);
-  dpd_file2_init(&D2, CC_OEI, 0, 0, 1, "DAI");
+  dpd_file2_init(&D2, CC_OEI, 0, 0, 1, rho_params.DAI_lbl);
   dpd_file2_mat_init(&D2);
   dpd_file2_mat_rd(&D2);
 
@@ -357,10 +357,10 @@ void fold_UHF(void)
   dpd_file2_mat_close(&D2);
   dpd_file2_close(&D2);
 
-  dpd_file2_init(&D1, CC_OEI, 0, 2, 3, "Dia");
+  dpd_file2_init(&D1, CC_OEI, 0, 2, 3, rho_params.Dia_lbl);
   dpd_file2_mat_init(&D1);
   dpd_file2_mat_rd(&D1);
-  dpd_file2_init(&D2, CC_OEI, 0, 2, 3, "Dai");
+  dpd_file2_init(&D2, CC_OEI, 0, 2, 3, rho_params.Dai_lbl);
   dpd_file2_mat_init(&D2);
   dpd_file2_mat_rd(&D2);
 
@@ -406,10 +406,10 @@ void fold_UHF(void)
   dpd_file2_mat_close(&D2);
   dpd_file2_close(&D2);
 
-  dpd_file2_init(&D1, CC_OEI, 0, 0, 1, "DIA");
+  dpd_file2_init(&D1, CC_OEI, 0, 0, 1, rho_params.DIA_lbl);
   dpd_file2_mat_init(&D1);
   dpd_file2_mat_rd(&D1);
-  dpd_file2_init(&D2, CC_OEI, 0, 0, 1, "DAI");
+  dpd_file2_init(&D2, CC_OEI, 0, 0, 1, rho_params.DAI_lbl);
   dpd_file2_mat_init(&D2);
   dpd_file2_mat_rd(&D2);
 
@@ -454,10 +454,10 @@ void fold_UHF(void)
   dpd_file2_close(&D2);
 
 
-  dpd_file2_init(&D1, CC_OEI, 0, 2, 3, "Dia");
+  dpd_file2_init(&D1, CC_OEI, 0, 2, 3, rho_params.Dia_lbl);
   dpd_file2_mat_init(&D1);
   dpd_file2_mat_rd(&D1);
-  dpd_file2_init(&D2, CC_OEI, 0, 2, 3, "Dai");
+  dpd_file2_init(&D2, CC_OEI, 0, 2, 3, rho_params.Dai_lbl);
   dpd_file2_mat_init(&D2);
   dpd_file2_mat_rd(&D2);
 
@@ -530,7 +530,7 @@ void fold_UHF(void)
   fprintf(outfile, "\tIJAB energy                = %20.15f\n", two_energy);
   fflush(outfile);
 
-  dpd_file2_init(&D, CC_OEI, 0, 1, 1, "DAB");
+  dpd_file2_init(&D, CC_OEI, 0, 1, 1, rho_params.DAB_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -573,7 +573,7 @@ void fold_UHF(void)
   dpd_file2_close(&D);
 
 
-  dpd_file2_init(&D, CC_OEI, 0, 3, 3, "Dab");
+  dpd_file2_init(&D, CC_OEI, 0, 3, 3, rho_params.Dab_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -615,7 +615,7 @@ void fold_UHF(void)
   dpd_file2_close(&D);
 
 
-  dpd_file2_init(&D, CC_OEI, 0, 3, 3, "Dab");
+  dpd_file2_init(&D, CC_OEI, 0, 3, 3, rho_params.Dab_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
@@ -657,7 +657,7 @@ void fold_UHF(void)
   dpd_file2_close(&D);
 
 
-  dpd_file2_init(&D, CC_OEI, 0, 1, 1, "DAB");
+  dpd_file2_init(&D, CC_OEI, 0, 1, 1, rho_params.DAB_lbl);
   dpd_file2_mat_init(&D);
   dpd_file2_mat_rd(&D);
 
