@@ -12,8 +12,13 @@
 #define EXTERN
 #endif
 
+/* #define DEBUG_XI (1) */
+
 EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
 EXTERN struct MOInfo moinfo;
 EXTERN struct Frozen frozen;
 EXTERN struct Params params;
+EXTERN struct RHO_Params *rho_params;
+EXTERN struct TD_Params *td_params;
+
