@@ -19,4 +19,7 @@ struct Local {
   char *weakp;
   int filter_singles;
   double weak_pair_energy;
+  double cphf_cutoff;
+  char *freeze_core;
+  char *pairdef;
 };
