@@ -23,6 +23,7 @@ void Wmbej_build(void)
   dpdbuf4 WMBEJ, Wmbej, WMbEj, WmBeJ, WmBEj, WMbeJ, W; 
   dpdbuf4 C, D, E, F, X, tIAjb, tiaJB, t2, Y, Z;
   dpdfile2 tIA, tia;
+  int Gmb, mb, Gj, Ge, Gf, nrows, ncols, nlinks;
 
   timer_on("C->Wmbej");
 
@@ -91,13 +92,12 @@ void Wmbej_build(void)
     dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
 
     dpd_buf4_init(&F, CC_FINTS, 0, 10, 5, 10, 5, 0, "F <ia|bc>");
-
     dpd_buf4_init(&WMbEj, CC_TMP0, 0, 10, 11, 10, 11, 0, "WMbEj");
-    dpd_contract424(&F, &tIA, &WMbEj, 3, 1, 0, 1, 1);
+    dpd_contract424(&F, &tIA, &WMbEj, 3, 1, 0, 1, 1); /* should be OOC-capable in libdpd */
     dpd_buf4_close(&WMbEj);
-
     dpd_buf4_close(&F);
 
+    /*
     dpd_buf4_init(&F, CC_FINTS, 0, 11, 5, 11, 5, 0, "F <ai|bc>");
 
     dpd_buf4_init(&Z, CC_TMP0, 0, 11, 11, 11, 11, 0, "Z(bM,eJ)");
@@ -110,6 +110,46 @@ void Wmbej_build(void)
     dpd_buf4_close(&WMbeJ);
     dpd_buf4_close(&Z);
 
+    dpd_buf4_close(&F);
+    */
+
+    /* W(Mb,Je) <-- t(J,F) <Mb|Fe> */
+    /* OOC code added to replace above on 3/23/05, TDC */
+    dpd_buf4_init(&F, CC_FINTS, 0, 10, 5, 10, 5, 0, "F <ia|bc>");
+    dpd_buf4_init(&W, CC_TMP0, 0, 10, 10, 10, 10, 0, "WMbeJ");
+    dpd_file2_mat_init(&tIA);
+    dpd_file2_mat_rd(&tIA);
+
+    for(Gmb=0; Gmb < moinfo.nirreps; Gmb++) {
+      dpd_buf4_mat_irrep_row_init(&W, Gmb);
+      dpd_buf4_mat_irrep_row_init(&F, Gmb);
+
+      for(mb=0; mb < F.params->rowtot[Gmb]; mb++) {
+	dpd_buf4_mat_irrep_row_rd(&W, Gmb, mb);
+	dpd_buf4_mat_irrep_row_rd(&F, Gmb, mb);
+
+	for(Gj=0; Gj < moinfo.nirreps; Gj++) {
+	  Gf = Gj;  /* T1 is totally symmetric */
+	  Ge = Gmb ^ Gf; /* <mb|fe> is totally symmetric */
+
+	  nrows = moinfo.occpi[Gj];
+	  ncols = moinfo.virtpi[Ge];
+	  nlinks = moinfo.virtpi[Gf];
+	  if(nrows && ncols && nlinks)
+	    C_DGEMM('n','n',nrows,ncols,nlinks,-1.0,tIA.matrix[Gj][0],nlinks,
+		    &F.matrix[Gmb][0][F.col_offset[Gmb][Gf]],ncols,1.0,
+		    &W.matrix[Gmb][0][W.col_offset[Gmb][Gj]],ncols);
+	}
+
+	dpd_buf4_mat_irrep_row_wrt(&W, Gmb, mb);
+      }
+
+      dpd_buf4_mat_irrep_row_close(&F, Gmb);
+      dpd_buf4_mat_irrep_row_close(&W, Gmb);
+    }
+
+    dpd_file2_mat_close(&tIA);
+    dpd_buf4_close(&W);
     dpd_buf4_close(&F);
 
     dpd_file2_close(&tIA);
@@ -297,8 +337,6 @@ void Wmbej_build(void)
 
   /* Convert to (ME,JB) for remaining terms */
 
-  timer_on("sort Wmbej");
-
   if(params.ref == 0) { /** RHF **/
 
     dpd_buf4_init(&WMbEj, CC_TMP0, 0, 10, 11, 10, 11, 0, "WMbEj");
@@ -363,8 +401,6 @@ void Wmbej_build(void)
     dpd_buf4_close(&W);
   }
 
-  timer_off("sort Wmbej");
-
   timer_on("X->Wmbej");
 
   if(params.ref == 0) { /** RHF **/
@@ -375,12 +411,12 @@ void Wmbej_build(void)
     dpd_buf4_init(&W, CC_HBAR, 0, 10, 10, 10, 10, 0, "WMbEj");
     dpd_buf4_init(&t2, CC_TAMPS, 0, 10, 10, 10, 10, 0, "tIAjb");
     dpd_buf4_init(&D, CC_DINTS, 0, 10, 10, 10, 10, 0, "D 2<ij|ab> - <ij|ba> (ia,jb)");
-    dpd_contract444(&D, &t2, &W, 0, 0, 0.5, 1);
+    dpd_contract444(&D, &t2, &W, 0, 1, 0.5, 1);
     dpd_buf4_close(&D);
     dpd_buf4_close(&t2);
     dpd_buf4_init(&t2, CC_TAMPS, 0, 10, 10, 10, 10, 0, "tjAIb");
     dpd_buf4_init(&D, CC_DINTS, 0, 10, 10, 10, 10, 0, "D <ij|ab> (ia,jb)");
-    dpd_contract444(&D, &t2, &W, 0, 0, -0.5, 1);
+    dpd_contract444(&D, &t2, &W, 0, 1, -0.5, 1);
     dpd_buf4_close(&D);
     dpd_buf4_close(&t2);
     dpd_buf4_close(&W);
@@ -399,7 +435,7 @@ void Wmbej_build(void)
     dpd_buf4_init(&W, CC_HBAR, 0, 10, 10, 10, 10, 0, "WMbeJ");
     dpd_buf4_init(&t2, CC_TAMPS, 0, 10, 10, 10, 10, 0, "tIbjA");
     dpd_buf4_init(&D, CC_DINTS, 0, 10, 10, 10, 10, 0, "D <ij|ab> (ib,ja)");
-    dpd_contract444(&D, &t2, &W, 0, 0, 0.5, 1);
+    dpd_contract444(&D, &t2, &W, 0, 1, 0.5, 1);
     dpd_buf4_close(&D);
     dpd_buf4_close(&t2);
     dpd_buf4_close(&W);
