@@ -7,6 +7,11 @@ struct Params {
   int ref;
   int eom_ref;
   int local;
+  char *wfn;
+  int semicanonical;
+  int full_matrix; /* include reference rows/cols in diagonalization */
+  char *abcd;
+  int t3_Ws_incore;
 };
 
 struct Eom_params {
@@ -15,6 +20,7 @@ struct Eom_params {
   int *states_per_irrep;
   int *cs_per_irrep;
   double eval_tol;
+  double eval_tol_SS;
   double residual_tol;
   int prop_root;
   int prop_sym;
@@ -27,6 +33,13 @@ struct Eom_params {
   int excitation_range;
   double residual_tol_SS;
   char *guess;
+  int rhf_triplets;
+  int mult;
+  int follow_root;
+  int restart_vectors_per_root;
+  int skip_diagSS;
+  int vectors_cc3;
+  int restart_eom_cc3;
 
   /* compute overlap of normalized R with L (must run cclambda first) */
   int dot_with_L;
