@@ -6,6 +6,8 @@
 
 extern double norm_C(dpdfile2 *CME, dpdfile2 *Cme,
             dpdbuf4 *CMNEF, dpdbuf4 *Cmnef, dpdbuf4 *CMnEf);
+extern double dot_C(dpdfile2 *CME, dpdfile2 *Cme,
+            dpdbuf4 *CMNEF, dpdbuf4 *Cmnef, dpdbuf4 *CMnEf);
 extern double norm_C_rhf(dpdfile2 *CME, dpdbuf4 *CMnEf, dpdbuf4 *CMnfE);
 extern void scm_C(dpdfile2 *CME, dpdfile2 *Cme, dpdbuf4 *CMNEF,
             dpdbuf4 *Cmnef, dpdbuf4 *CMnEf, double a);
@@ -45,12 +47,30 @@ void rzero(int C_irr, int *converged) {
     if (!converged[i]) continue; /* this root did not converged */
     ++R_index;
 
-    sprintf(E_lbl, "EOM CCSD Energy for root %d %d", C_irr, R_index);
-    if ( psio_tocscan(CC_INFO, E_lbl) == NULL) {
-      fprintf(outfile,"No EOM CCSD Energy found in CC_INFO.  Not normalizing R.\n");
-      return;
-    };
-    psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    if(!strcmp(params.wfn,"EOM_CC2")) {
+      sprintf(E_lbl, "EOM CC2 Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) {
+        fprintf(outfile,"No EOM CC2 Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CCSD")) {
+      sprintf(E_lbl, "EOM CCSD Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) {
+        fprintf(outfile,"No EOM CCSD Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CC3")) {
+      sprintf(E_lbl, "EOM CC3 Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) {
+        fprintf(outfile,"No EOM CC3 Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
 
     sprintf(R1A_lbl, "RIA %d %d", C_irr, R_index);
     sprintf(R1B_lbl, "Ria %d %d", C_irr, R_index);
@@ -120,19 +140,42 @@ void rzero(int C_irr, int *converged) {
     dpd_buf4_init(&fRijab, CC_RAMPS, C_irr, BB_OCC, BB_VIR, BB_OCC, BB_VIR, 0, R2BB_lbl);
     dpd_buf4_init(&fRIjAb, CC_RAMPS, C_irr, AB_OCC, AB_VIR, AB_OCC, AB_VIR, 0, R2AB_lbl);
 
+    /* make R0 a positive number */
+    /*
+    if (rzero < 0.0) {
+      rzero *= -1.0;
+      dpd_file2_scm(&RIA,-1.0);
+      dpd_file2_scm(&Ria,-1.0);
+      dpd_buf4_scm(&fRIJAB,-1.0);
+      dpd_buf4_scm(&fRijab,-1.0);
+      dpd_buf4_scm(&fRIjAb,-1.0);
+    }
+    */
+
+    /*
     norm = norm_C(&RIA, &Ria, &fRIJAB, &fRijab, &fRIjAb);
     norm *= norm;
+    */
+    norm = dot_C(&RIA, &Ria, &fRIJAB, &fRijab, &fRIjAb);
     norm += rzero * rzero;
     norm = sqrt(norm);
     rzero = rzero / norm;
     scm_C(&RIA, &Ria, &fRIJAB, &fRijab, &fRIjAb, 1.0/norm);
 
+    norm = dot_C(&RIA, &Ria, &fRIJAB, &fRijab, &fRIjAb);
+    norm += rzero * rzero;
+    fprintf(outfile,"<R|R> = %20.16lf\n",norm);
+
+/* just debugging with converged solutions - also my need a sort_C() */
 /*
-dpd_file2_print(&RIA, outfile);
-dpd_buf4_print(&fRIJAB, outfile, 1);
-dpd_buf4_print(&fRijab, outfile, 1);
-dpd_buf4_print(&fRIjAb, outfile, 1);
+dpd_file2_copy(&RIA, EOM_CME, "CME 0");
+dpd_file2_copy(&Ria, EOM_Cme, "Cme 0");
+dpd_buf4_copy(&fRIJAB, EOM_CMNEF, "CMNEF 0");
+dpd_buf4_copy(&fRijab, EOM_Cmnef, "Cmnef 0");
+dpd_buf4_copy(&fRIjAb, EOM_CMnEf, "CMnEf 0");
 */
+/* end debugging stuff */ 
+
 
     dpd_file2_close(&RIA);
     dpd_file2_close(&Ria);
@@ -140,9 +183,21 @@ dpd_buf4_print(&fRIjAb, outfile, 1);
     dpd_buf4_close(&fRijab);
     dpd_buf4_close(&fRIjAb);
 
-    fprintf(outfile,"EOM CCSD R0 for root %d = %15.10lf\n", R_index, rzero);
-    sprintf(lbl, "EOM CCSD R0 for root %d %d", C_irr, R_index);
-    psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    if(!strcmp(params.wfn,"EOM_CC2")) {
+      fprintf(outfile,"EOM CC2 R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CC2 R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CCSD")) {
+      fprintf(outfile,"EOM CCSD R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CCSD R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CC3")) {
+      fprintf(outfile,"EOM CC3 R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CC3 R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
 
     if (eom_params.dot_with_L) {
       /* evaluate check <R|L> == 0 */
@@ -213,12 +268,30 @@ void rzero_rhf(int C_irr, int *converged) {
     if (!converged[i]) continue; /* this root did not converge */
     ++R_index;
 
-    sprintf(E_lbl, "EOM CCSD Energy for root %d %d", C_irr, R_index);
-    if ( psio_tocscan(CC_INFO, E_lbl) == NULL) { 
-      fprintf(outfile,"No EOM CCSD Energy found in CC_INFO.  Not normalizing R.\n");
-      return;
-    };
-    psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    if(!strcmp(params.wfn,"EOM_CC2")) {
+      sprintf(E_lbl, "EOM CC2 Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) { 
+        fprintf(outfile,"No EOM CC2 Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CCSD")) {
+      sprintf(E_lbl, "EOM CCSD Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) { 
+        fprintf(outfile,"No EOM CCSD Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CC3")) {
+      sprintf(E_lbl, "EOM CC3 Energy for root %d %d", C_irr, R_index);
+      if(psio_tocscan(CC_INFO, E_lbl) == NULL) { 
+        fprintf(outfile,"No EOM CC3 Energy found in CC_INFO.  Not normalizing R.\n");
+        return;
+      }
+      psio_read_entry(CC_INFO, E_lbl, (char *) &(energy), sizeof(double));
+    }
 
     sprintf(R1A_lbl, "RIA %d %d", C_irr, R_index);
     sprintf(R1B_lbl, "Ria %d %d", C_irr, R_index);
@@ -242,23 +315,29 @@ void rzero_rhf(int C_irr, int *converged) {
     dpd_buf4_close(&RIjAb);
 
     /* calculate <0| hbar | 0> */
-    if (C_irr == H_IRR) {
-      dpd_file2_init(&FIA, CC_OEI, H_IRR, 0, 1, "FME");
-      dpd_file2_init(&RIA, CC_RAMPS, C_irr, 0, 1, R1A_lbl);
-      r1 = 2.0 * dpd_file2_dot(&FIA, &RIA);
-      dpd_file2_close(&RIA);
-      dpd_file2_close(&FIA);
-  
-      sprintf(lbl, "%s %d %d", "2RIjAb - RIjbA", C_irr, R_index);
-      dpd_buf4_init(&RIjAb, CC_RAMPS, C_irr, 0, 5, 0, 5, 0, lbl);
-      dpd_buf4_init(&D, CC_DINTS, H_IRR, 0, 5, 0, 5, 0, "D <ij|ab>");
-      r2 = dpd_buf4_dot(&D, &RIjAb);
-      dpd_buf4_close(&D);
-      dpd_buf4_close(&RIjAb);
-      rzero = (r1 + r2)/energy;
+    if (!params.full_matrix) {
+      if (C_irr == H_IRR) {
+        dpd_file2_init(&FIA, CC_OEI, H_IRR, 0, 1, "FME");
+        dpd_file2_init(&RIA, CC_RAMPS, C_irr, 0, 1, R1A_lbl);
+        r1 = 2.0 * dpd_file2_dot(&FIA, &RIA);
+        dpd_file2_close(&RIA);
+        dpd_file2_close(&FIA);
+    
+        sprintf(lbl, "%s %d %d", "2RIjAb - RIjbA", C_irr, R_index);
+        dpd_buf4_init(&RIjAb, CC_RAMPS, C_irr, 0, 5, 0, 5, 0, lbl);
+        dpd_buf4_init(&D, CC_DINTS, H_IRR, 0, 5, 0, 5, 0, "D <ij|ab>");
+        r2 = dpd_buf4_dot(&D, &RIjAb);
+        dpd_buf4_close(&D);
+        dpd_buf4_close(&RIjAb);
+        rzero = (r1 + r2)/energy;
+      }
+      else {
+        rzero = 0.0;
+      }
     }
-    else {
-      rzero = 0.0;
+    else { /* full matrix */
+      sprintf(lbl, "%s %d %d", "R0", C_irr, R_index);
+      psio_read_entry(CC_RAMPS, lbl, (char *) &rzero, sizeof(double));
     }
 
     /* Now normalize R so that <R|R> = 1 */
@@ -266,6 +345,15 @@ void rzero_rhf(int C_irr, int *converged) {
     dpd_buf4_init(&RIjAb, CC_RAMPS, C_irr, 0, 5, 0, 5, 0, R2AB_lbl);
     dpd_buf4_init(&RIjbA, CC_TMP, C_irr, 0, 5, 0, 5, 0, "RIjbA");
 
+    /*
+    if (rzero < 0.0) {
+      rzero *= -1.0;
+      dpd_file2_scm(&RIA,-1.0);
+      dpd_buf4_scm(&RIjAb,-1.0);
+      dpd_buf4_scm(&RIjbA,-1.0);
+    }
+    */
+
     norm = norm_C_rhf(&RIA, &RIjAb, &RIjbA);
     norm *= norm;
     norm += rzero * rzero;
@@ -275,13 +363,32 @@ void rzero_rhf(int C_irr, int *converged) {
     dpd_buf4_scm(&RIjAb, 1.0/norm);
     dpd_buf4_scm(&RIjbA, 1.0/norm);
 
+/* just for debugging cc3 put normalized vector back into C as well */
+/*
+dpd_file2_copy(&RIA, EOM_CME, "CME 0");
+dpd_buf4_copy(&RIjAb, EOM_CMnEf, "CMnEf 0");
+*/
+/* end debugging stuff */ 
+
     dpd_file2_close(&RIA);
     dpd_buf4_close(&RIjAb);
     dpd_buf4_close(&RIjbA);
 
-    fprintf(outfile,"EOM CCSD R0 for root %d = %15.10lf\n", R_index, rzero);
-    sprintf(lbl, "EOM CCSD R0 for root %d %d", C_irr, R_index);
-    psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    if(!strcmp(params.wfn,"EOM_CC2")) {
+      fprintf(outfile,"EOM CC2 R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CC2 R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CCSD")) {
+      fprintf(outfile,"EOM CCSD R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CCSD R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
+    else if(!strcmp(params.wfn,"EOM_CC3")) {
+      fprintf(outfile,"EOM CC3 R0 for root %d = %15.11lf\n", R_index, rzero);
+      sprintf(lbl, "EOM CC3 R0 for root %d %d", C_irr, R_index);
+      psio_write_entry(CC_INFO, lbl, (char *) &rzero, sizeof(double));
+    }
 
     /* produce ROHF like quantities and 2RIjAb-RIjbA */
     dpd_file2_init(&RIA, CC_RAMPS, C_irr, 0, 1, R1A_lbl);
