@@ -1,5 +1,8 @@
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <libdpd/dpd.h>
+#include <libqt/qt.h>
 #define EXTERN
 #include "globals.h"
 
@@ -22,7 +25,7 @@
 */
 
 void F_build(void) {
-  int h,i,e,a;
+  int h,e,a,m;
   dpdfile2 Faet, FAEt, Fmit, FMIt;
   dpdfile2 Fae, FAE, FMI, Fmi;
   dpdfile2 fab, fAB, fij, fIJ;
@@ -31,8 +34,154 @@ void F_build(void) {
   dpdfile2 tIA, tia;
   dpdbuf4 F_anti, F, E_anti, E, D_anti, D;
   dpdbuf4 tautIJAB, tautijab, tautIjAb, taut;
+  int Gma, Gm, Ga, Gf, Ge, ma, M, A, fe, ef, f, nrows, ncols;
+  double *X;
 
-  if(params.ref == 0 ||  params.ref == 1) { /** RHF or ROHF **/
+  if(params.ref == 0) {
+
+    /** FME **/
+    dpd_file2_init(&fIA, CC_OEI, 0, 0, 1, "fIA");
+    dpd_file2_copy(&fIA, CC_OEI, "FME");
+    dpd_file2_close(&fIA);
+
+    dpd_file2_init(&FME, CC_OEI, 0, 0, 1, "FME");
+    dpd_buf4_init(&D, CC_DINTS, 0, 0, 5, 0, 5, 0, "D 2<ij|ab> - <ij|ba>");
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_dot13(&tIA, &D, &FME, 0, 0, 1.0, 1.0);
+    dpd_file2_close(&tIA);
+    dpd_buf4_close(&D);
+    dpd_file2_close(&FME);
+
+    /** FAE **/
+    dpd_file2_init(&fAB, CC_OEI, 0, 1, 1, "fAB");
+    dpd_file2_copy(&fAB, CC_OEI, "FAE");
+    dpd_file2_close(&fAB);
+
+    dpd_file2_init(&FAE, CC_OEI, 0, 1, 1, "FAE");
+
+    /*
+    dpd_buf4_init(&F, CC_FINTS, 0, 10, 5, 10, 5, 0,"F 2<ia|bc> - <ia|cb>");
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_dot13(&tIA, &F, &FAE, 0, 0, 1.0, 1.0);
+    dpd_file2_close(&tIA);
+    dpd_buf4_close(&F);
+    */
+
+    dpd_file2_mat_init(&FAE);
+    dpd_file2_mat_rd(&FAE);
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_file2_mat_init(&tIA);
+    dpd_file2_mat_rd(&tIA);
+    dpd_buf4_init(&F, CC_FINTS, 0, 10, 5, 10, 5, 0,"F <ia|bc>");
+    for(Gma=0; Gma < moinfo.nirreps; Gma++) {
+      dpd_buf4_mat_irrep_row_init(&F, Gma);
+      X = init_array(F.params->coltot[Gma]);
+
+      for(ma=0; ma < F.params->rowtot[Gma]; ma++) {
+	dpd_buf4_mat_irrep_row_rd(&F, Gma, ma);
+	m = F.params->roworb[Gma][ma][0];
+	a = F.params->roworb[Gma][ma][1];
+	Gm = F.params->psym[m];
+	Ga = Ge = Gm ^ Gma;  /* Fae is totally symmetric */
+	Gf = Gm; /* T1 is totally symmetric */
+	M = m - F.params->poff[Gm];
+	A = a - F.params->qoff[Ga];
+
+	zero_arr(X, F.params->coltot[Gma]);
+
+	/* build spin-adapted F-integrals for current ma */
+	for(fe=0; fe < F.params->coltot[Gma]; fe++) {
+	  f = F.params->colorb[Gma][fe][0];
+	  e = F.params->colorb[Gma][fe][1];
+	  ef = F.params->colidx[e][f];
+	  X[fe] = 2.0 * F.matrix[Gma][0][fe] - F.matrix[Gma][0][ef];
+	}
+	
+	nrows = moinfo.virtpi[Gf];
+	ncols = moinfo.virtpi[Ge];
+	if(nrows && ncols)
+	  C_DGEMV('t',nrows,ncols,1.0,&X[F.col_offset[Gma][Gf]],ncols,
+		  tIA.matrix[Gm][M],1,1.0,
+		  FAE.matrix[Ga][A],1);
+      }
+
+      free(X);
+      dpd_buf4_mat_irrep_row_close(&F, Gma);
+    }
+    dpd_buf4_close(&F);
+    dpd_file2_mat_close(&tIA);
+    dpd_file2_close(&tIA);
+    dpd_file2_mat_wrt(&FAE);
+    dpd_file2_mat_close(&FAE);
+
+    dpd_buf4_init(&D, CC_DINTS, 0, 0, 5, 0, 5, 0, "D 2<ij|ab> - <ij|ba>");
+    dpd_buf4_init(&tautIjAb, CC_TAMPS, 0, 0, 5, 0, 5, 0, "tautIjAb");
+    dpd_contract442(&tautIjAb, &D, &FAE, 3, 3, -1, 1);
+    dpd_buf4_close(&D);
+    dpd_buf4_close(&tautIjAb);
+
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_file2_init(&FME, CC_OEI, 0, 0, 1, "FME");
+    dpd_contract222(&tIA, &FME, &FAE, 1, 1, -0.5, 1);
+    dpd_file2_close(&tIA);
+    dpd_file2_close(&FME);
+  
+    dpd_file2_copy(&FAE, CC_OEI, "FAEt");
+    dpd_file2_close(&FAE);
+
+    dpd_file2_init(&fIJ, CC_OEI, 0, 0, 0, "fIJ");
+    dpd_file2_copy(&fIJ, CC_OEI, "FMI");
+    dpd_file2_close(&fIJ);
+
+    dpd_file2_init(&FMI, CC_OEI, 0, 0, 0, "FMI");
+
+    dpd_buf4_init(&E, CC_EINTS, 0, 11, 0, 11, 0, 0, "E 2<ai|jk> - <ai|kj>");
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_dot13(&tIA, &E, &FMI, 1, 1, 1.0, 1.0);
+    dpd_file2_close(&tIA);
+    dpd_buf4_close(&E);
+
+    dpd_buf4_init(&D, CC_DINTS, 0, 0, 5, 0, 5, 0, "D 2<ij|ab> - <ij|ba>");
+    dpd_buf4_init(&tautIjAb, CC_TAMPS, 0, 0, 5, 0, 5, 0, "tautIjAb");
+    dpd_contract442(&D, &tautIjAb, &FMI, 0, 0, 1, 1);
+    dpd_buf4_close(&tautIjAb);
+    dpd_buf4_close(&D);
+
+    dpd_file2_init(&tIA, CC_OEI, 0, 0, 1, "tIA");
+    dpd_file2_init(&FME, CC_OEI, 0, 0, 1, "FME");
+    dpd_contract222(&FME, &tIA, &FMI, 0, 0, 0.5, 1);
+    dpd_file2_close(&FME);
+    dpd_file2_close(&tIA);
+
+    dpd_file2_copy(&FMI, CC_OEI, "FMIt");
+    dpd_file2_close(&FMI);
+
+    dpd_file2_init(&FAEt, CC_OEI, 0, 1, 1, "FAEt");
+    dpd_file2_mat_init(&FAEt);
+    dpd_file2_mat_rd(&FAEt);
+
+    for(h=0; h < moinfo.nirreps; h++)
+      for(a=0; a < FAEt.params->rowtot[h]; a++)
+	FAEt.matrix[h][a][a] = 0.0;
+
+    dpd_file2_mat_wrt(&FAEt);
+    dpd_file2_mat_close(&FAEt);
+    dpd_file2_close(&FAEt);
+
+    dpd_file2_init(&FMIt, CC_OEI, 0, 0, 0, "FMIt");
+    dpd_file2_mat_init(&FMIt);
+    dpd_file2_mat_rd(&FMIt);
+
+    for(h=0; h < moinfo.nirreps; h++)
+      for(a=0; a < FMIt.params->rowtot[h]; a++)
+	FMIt.matrix[h][a][a] = 0.0;
+
+    dpd_file2_mat_wrt(&FMIt);
+    dpd_file2_mat_close(&FMIt);
+    dpd_file2_close(&FMIt);
+
+  }
+  else if(params.ref == 1) { /** ROHF **/
 
     /* FME and Fme */
     dpd_file2_init(&fIA, CC_OEI, 0, 0, 1, "fIA");
@@ -326,6 +475,31 @@ void F_build(void) {
     dpd_file2_copy(&fab, CC_OEI, "Fae");
     dpd_file2_close(&fab);
 
+    if((!strcmp(params.wfn,"CC2")) || (!strcmp(params.wfn,"EOM_CC2"))) {
+      dpd_file2_init(&FAE, CC_OEI, 0, 1, 1, "FAE");
+      dpd_file2_init(&Fae, CC_OEI, 0, 3, 3, "Fae");
+
+      dpd_file2_mat_init(&FAE);
+      dpd_file2_mat_rd(&FAE);
+      dpd_file2_mat_init(&Fae);
+      dpd_file2_mat_rd(&Fae);
+  
+      for(h=0; h < moinfo.nirreps; h++) {
+	for(e=0; e < FAE.params->coltot[h]; e++)
+	  FAE.matrix[h][e][e] = 0;
+	for(e=0; e < Fae.params->coltot[h]; e++)
+	  Fae.matrix[h][e][e] = 0;
+      }
+
+      dpd_file2_mat_wrt(&FAE);
+      dpd_file2_mat_close(&FAE);
+      dpd_file2_mat_wrt(&Fae);
+      dpd_file2_mat_close(&Fae);
+
+      dpd_file2_close(&FAE);
+      dpd_file2_close(&Fae);
+    }
+
     dpd_file2_init(&FAE, CC_OEI, 0, 1, 1, "FAE");
     dpd_file2_init(&Fae, CC_OEI, 0, 3, 3, "Fae");
 
@@ -415,6 +589,31 @@ void F_build(void) {
     dpd_file2_copy(&fij, CC_OEI, "Fmi");
     dpd_file2_close(&fij);
 
+    if((!strcmp(params.wfn,"CC2")) || (!strcmp(params.wfn,"EOM_CC2"))) {
+      dpd_file2_init(&FMI, CC_OEI, 0, 0, 0, "FMI");
+      dpd_file2_init(&Fmi, CC_OEI, 0, 2, 2, "Fmi");
+
+      dpd_file2_mat_init(&FMI);
+      dpd_file2_mat_rd(&FMI);
+      dpd_file2_mat_init(&Fmi);
+      dpd_file2_mat_rd(&Fmi);
+
+      for(h=0; h < moinfo.nirreps; h++) {
+	for(m=0; m < FMI.params->rowtot[h]; m++)
+	  FMI.matrix[h][m][m] = 0;
+	for(m=0; m < Fmi.params->rowtot[h]; m++)
+	  Fmi.matrix[h][m][m] = 0;
+      }
+
+      dpd_file2_mat_wrt(&FMI);
+      dpd_file2_mat_close(&FMI);
+      dpd_file2_mat_wrt(&Fmi);
+      dpd_file2_mat_close(&Fmi);
+
+      dpd_file2_close(&FMI);
+      dpd_file2_close(&Fmi);
+    }
+
     dpd_file2_init(&FMI, CC_OEI, 0, 0, 0, "FMI");
     dpd_file2_init(&Fmi, CC_OEI, 0, 2, 2, "Fmi");
 
@@ -497,7 +696,6 @@ void F_build(void) {
     dpd_file2_close(&FMI);
     dpd_file2_close(&Fmi);
 
-
     /* remove diagonal elements from Ft's */
     dpd_file2_init(&Faet, CC_OEI, 0, 3, 3, "Faet");
     dpd_file2_mat_init(&Faet);
