@@ -177,9 +177,6 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-
-
-
   /* Purge Wmbej matrix elements */
   dpd_file4_init(&W, CC_HBAR, 0, 10, 10,"WMBEJ");
   for(h=0; h < nirreps; h++) {
@@ -203,7 +200,6 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-
   dpd_file4_init(&W, CC_HBAR, 0, 10, 10,"Wmbej");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
@@ -226,7 +222,6 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-
   dpd_file4_init(&W, CC_HBAR, 0, 10, 10,"WMbEj");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
@@ -249,7 +244,6 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-
   dpd_file4_init(&W, CC_HBAR, 0, 10, 10,"WmBeJ");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
@@ -272,7 +266,6 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-
   dpd_file4_init(&W, CC_HBAR, 0, 10, 10,"WmBEj");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
@@ -305,16 +298,14 @@ void purge(void) {
 
   /* WMbeJ is already OK */
 
-
-
   /* Purge Wamef matrix elements */
-  dpd_file4_init(&W, CC_HBAR, 0, 10, 7,"WAMEF");
+  dpd_file4_init(&W, CC_HBAR, 0, 11, 7,"WAMEF");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
     dpd_file4_mat_irrep_rd(&W, h);
     for(ma=0; ma < W.params->rowtot[h]; ma++) {
-      a = W.params->roworb[h][ma][1];
-      asym = W.params->qsym[a];
+      a = W.params->roworb[h][ma][0];
+      asym = W.params->psym[a];
       A = a - vir_off[asym];
       for(ef=0; ef< W.params->coltot[h]; ef++) {
 	e = W.params->colorb[h][ef][0];
@@ -334,13 +325,13 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-  dpd_file4_init(&W, CC_HBAR, 0, 10, 7,"Wamef");
+  dpd_file4_init(&W, CC_HBAR, 0, 11, 7,"Wamef");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
     dpd_file4_mat_irrep_rd(&W, h);
     for(ma=0; ma < W.params->rowtot[h]; ma++) {
-      m = W.params->roworb[h][ma][0];
-      msym = W.params->psym[m];
+      m = W.params->roworb[h][ma][1];
+      msym = W.params->qsym[m];
       M = m - occ_off[msym];
       for(ef=0; ef< W.params->coltot[h]; ef++) {
 	if (M >=  (occpi[msym] - openpi[msym]))
@@ -352,15 +343,15 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-  dpd_file4_init(&W, CC_HBAR, 0, 10, 5,"WAmEf");
+  dpd_file4_init(&W, CC_HBAR, 0, 11, 5,"WAmEf");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
     dpd_file4_mat_irrep_rd(&W, h);
     for(ma=0; ma < W.params->rowtot[h]; ma++) {
-      m = W.params->roworb[h][ma][0];
-      a = W.params->roworb[h][ma][1];
-      msym = W.params->psym[m];
-      asym = W.params->qsym[a];
+      a = W.params->roworb[h][ma][0];
+      m = W.params->roworb[h][ma][1];
+      asym = W.params->psym[a];
+      msym = W.params->qsym[m];
       M = m - occ_off[msym];
       A = a - vir_off[asym];
       for(ef=0; ef< W.params->coltot[h]; ef++) {
@@ -378,7 +369,7 @@ void purge(void) {
   }
   dpd_file4_close(&W);
 
-  dpd_file4_init(&W, CC_HBAR, 0, 10, 5,"WaMeF");
+  dpd_file4_init(&W, CC_HBAR, 0, 11, 5,"WaMeF");
   for(h=0; h < nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
     dpd_file4_mat_irrep_rd(&W, h);
@@ -397,10 +388,8 @@ void purge(void) {
   dpd_file4_close(&W);
 
 
-
-
-
   /* Purge Wmnie matrix elements */
+  /* moving to separate function
   dpd_file4_init(&W, CC_HBAR, 0, 2, 11,"WMNIE");
   for(h=0; h < W.params->nirreps; h++) {
     dpd_file4_mat_irrep_init(&W, h);
@@ -487,7 +476,7 @@ void purge(void) {
     dpd_file4_mat_irrep_close(&W, h);
   }
   dpd_file4_close(&W);
-
+  */
 
 
   /* Purge WMBIJ matrix elements */
@@ -675,3 +664,110 @@ void purge(void) {
 
   return;
 }
+
+/* Purge Wmnie matrix elements */
+void purge_Wmnie(void) {
+  dpdfile4 W;
+  int *occpi, *virtpi;
+  int h, a, b, e, f, i, j, m, n;
+  int    A, B, E, F, I, J, M, N;
+  int mn, ei, ma, ef, me, jb, mb, ij, ab;
+  int asym, bsym, esym, fsym, isym, jsym, msym, nsym;
+  int *occ_off, *vir_off;
+  int *occ_sym, *vir_sym;
+  int *openpi, nirreps;
+
+  nirreps = moinfo.nirreps;
+  occpi = moinfo.occpi; virtpi = moinfo.virtpi;
+  occ_off = moinfo.occ_off; vir_off = moinfo.vir_off;
+  occ_sym = moinfo.occ_sym; vir_sym = moinfo.vir_sym;
+  openpi = moinfo.openpi;
+
+  dpd_file4_init(&W, CC_HBAR, 0, 0, 11,"WMnIe (Mn,eI)");
+  for(h=0; h < nirreps; h++) {
+    dpd_file4_mat_irrep_init(&W, h);
+    dpd_file4_mat_irrep_rd(&W, h);
+    for(mn=0; mn<W.params->rowtot[h]; mn++) {
+      n = W.params->roworb[h][mn][1];
+      nsym = W.params->qsym[n];
+      N = n - occ_off[nsym];
+      for(ei=0; ei<W.params->coltot[h]; ei++) {
+	if (N >= (occpi[nsym] - openpi[nsym]))
+	  W.matrix[h][mn][ei] = 0.0;
+      }
+    }
+    dpd_file4_mat_irrep_wrt(&W, h);
+    dpd_file4_mat_irrep_close(&W, h);
+  }
+
+  dpd_file4_init(&W, CC_HBAR, 0, 2, 11, "WMNIE (M>N,EI)");
+  for(h=0; h < W.params->nirreps; h++) {
+    dpd_file4_mat_irrep_init(&W, h);
+    dpd_file4_mat_irrep_rd(&W, h);
+    for(mn=0; mn<W.params->rowtot[h]; mn++) {
+      for(ei=0; ei<W.params->coltot[h]; ei++) {
+        e = W.params->colorb[h][ei][0];
+        esym = W.params->rsym[e];
+        E = e - vir_off[esym];
+        if (E >= (virtpi[esym] - openpi[esym]))
+          W.matrix[h][mn][ei] = 0.0;
+      }
+    }
+    dpd_file4_mat_irrep_wrt(&W, h);
+    dpd_file4_mat_irrep_close(&W, h);
+  }
+  dpd_file4_close(&W);
+
+  dpd_file4_init(&W, CC_HBAR, 0, 2, 11,"Wmnie (m>n,ei)");
+  for(h=0; h < nirreps; h++) {
+    dpd_file4_mat_irrep_init(&W, h);
+    dpd_file4_mat_irrep_rd(&W, h);
+    for(mn=0; mn<W.params->rowtot[h]; mn++) {
+      m = W.params->roworb[h][mn][0];
+      n = W.params->roworb[h][mn][1];
+      msym = W.params->psym[m];
+      nsym = W.params->qsym[n];
+      M = m - occ_off[msym];
+      N = n - occ_off[nsym];
+      for(ei=0; ei<W.params->coltot[h]; ei++) {
+        i = W.params->colorb[h][ei][1];
+        isym = W.params->ssym[i];
+        I = i - occ_off[isym];
+        if ((M >= (occpi[msym] - openpi[msym])) ||
+          (N >= (occpi[nsym] - openpi[nsym])) ||
+          (I >= (occpi[isym] - openpi[isym])) )
+          W.matrix[h][mn][ei] = 0.0;
+      }
+    }
+    dpd_file4_mat_irrep_wrt(&W, h);
+    dpd_file4_mat_irrep_close(&W, h);
+  }
+  dpd_file4_close(&W);
+
+  dpd_file4_init(&W, CC_HBAR, 0, 0, 11,"WmNiE (mN,Ei)");
+  for(h=0; h < nirreps; h++) {
+    dpd_file4_mat_irrep_init(&W, h);
+    dpd_file4_mat_irrep_rd(&W, h);
+    for(mn=0; mn<W.params->rowtot[h]; mn++) {
+      m = W.params->roworb[h][mn][0];
+      msym = W.params->psym[m];
+      M = m - occ_off[msym];
+      for(ei=0; ei<W.params->coltot[h]; ei++) {
+        e = W.params->colorb[h][ei][0];
+        i = W.params->colorb[h][ei][1];
+        esym = W.params->rsym[e];
+        isym = W.params->ssym[i];
+        E = e - vir_off[esym];
+        I = i - occ_off[isym];
+        if ((M >= (occpi[msym] - openpi[msym])) ||
+            (E >= (virtpi[esym] - openpi[esym])) ||
+            (I >= (occpi[isym] - openpi[isym])) )
+          W.matrix[h][mn][ei] = 0.0;
+      }
+    }
+    dpd_file4_mat_irrep_wrt(&W, h);
+    dpd_file4_mat_irrep_close(&W, h);
+  }
+  dpd_file4_close(&W);
+  return;
+}
