@@ -11,8 +11,8 @@ void Lmag(int L_irr)
 
   if(params.ref == 0 || params.ref == 1) { /** RHF/ROHF **/
 
-    dpd_file2_init(&LIA, CC_OEI, L_irr, 0, 1, "New LIA");
-    dpd_file2_init(&Lia, CC_OEI, L_irr, 0, 1, "New Lia");
+    dpd_file2_init(&LIA, CC_LAMBDA, L_irr, 0, 1, "New LIA");
+    dpd_file2_init(&Lia, CC_LAMBDA, L_irr, 0, 1, "New Lia");
     dpd_buf4_init(&LIJAB, CC_LAMBDA, L_irr, 2, 7, 2, 7, 0, "New LIJAB");
     dpd_buf4_init(&Lijab, CC_LAMBDA, L_irr, 2, 7, 2, 7, 0, "New Lijab");
     dpd_buf4_init(&LIjAb, CC_LAMBDA, L_irr, 0, 5, 0, 5, 0, "New LIjAb");
