@@ -2,7 +2,6 @@
 #include <libdpd/dpd.h>
 #include "MOInfo.h"
 #include "Params.h"
-#include <libciomr/libciomr.h>
 #include "Local.h"
 
 /* Global variables */
@@ -19,5 +18,6 @@ EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
 EXTERN struct MOInfo moinfo;
 EXTERN struct Params params;
+EXTERN struct L_Params *pL_params;
 EXTERN struct Local local;
 void check_sum(char *lbl, int L_irr);
