@@ -3,6 +3,7 @@ struct Local {
   int nso;
   int nocc;
   int nvir;
+  int cart;
   int *aostart;
   int *aostop;
   int **domain;
@@ -18,4 +19,7 @@ struct Local {
   int filter_singles;
   char *method;
   char *weakp;
+  double cphf_cutoff;
+  char *freeze_core;
+  char *pairdef;
 };
