@@ -6,10 +6,17 @@ struct Params {
   long int memory;       /* Memory available (in bytes) */
   int cachelev;
   int ref;
+  double *omega;         /* energy of applied field (a.u) for dynamic properties */
+  int nomega;            /* number of field energies desired */
   char *wfn;
   int make_abcd;
+  int make_unpacked_abcd;
+  int make_aibc;
   int dertype;
   char *aobasis;
   int reset;            /* cmdline argument; if true, all CC-related files */
                         /* are deleted at the beginning of the run */
+  int semicanonical;    /* semicanonical orbitals for perturbation theory */
+  int local;
+  char *prop;
 };
