@@ -6,12 +6,6 @@
 #define EXTERN
 #include "globals.h"
 
-enum pattern {abc, acb, cab, cba, bca, bac};
-
-void W_sort(double ***Win, double ***Wout, int nirreps, int h, int *coltot, int **colidx, 
-	    int ***colorb, int *asym, int *bsym, int *aoff, int *boff,
-	    int *cpi, int *coff, int **colidx_out, enum pattern index, int sum);
-
 double ET_UHF_AAA(void)
 {
   int cnt;
@@ -35,11 +29,8 @@ double ET_UHF_AAA(void)
   double f_ia, f_ib, f_ic, f_ja, f_jb, f_jc, f_ka, f_kb, f_kc;
   double D_jkbc, D_jkac, D_jkba, D_ikbc, D_ikac, D_ikba, D_jibc, D_jiac, D_jiba;
   double t_jkbc, t_jkac, t_jkba, t_ikbc, t_ikac, t_ikba, t_jibc, t_jiac, t_jiba;
-  int nump, p, Gp, offset;
   int nrows, ncols, nlinks;
   dpdbuf4 T2, Fints, Eints, Dints;
-  int **T2_row_start, **F_row_start;
-  int **T2_col_start, **E_col_start;
   dpdfile2 fIJ, fAB, fIA, T1;
   double ***WABC, ***WBCA, ***WACB, ***VABC;
   int nijk, mijk;
@@ -51,60 +42,6 @@ double ET_UHF_AAA(void)
   occ_off = moinfo.aocc_off;
   vir_off = moinfo.avir_off;
 
-  for(h=0,nump=0; h < nirreps; h++) nump += occpi[h];
-
-  F_row_start = init_int_matrix(nirreps, nump);
-  for(h=0; h < nirreps; h++) {
-
-    for(p=0; p < nump; p++) F_row_start[h][p] = -1;
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < occpi[Gp]; p++) {
-
-	if(virtpi[Gp^h]) 
-	  F_row_start[h][occ_off[Gp] + p] = nrows;
-
-	nrows += virtpi[Gp^h];
-      }
-    }
-  }
-
-  T2_row_start = init_int_matrix(nirreps, nump);
-  for(h=0; h < nirreps; h++) {
-
-    for(p=0; p < nump; p++) T2_row_start[h][p] = -1;
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < occpi[Gp]; p++) {
-
-	if(occpi[Gp^h]) 
-	  T2_row_start[h][occ_off[Gp] + p] = nrows;
-
-	nrows += occpi[Gp^h];
-      }
-    }
-  }
-
-  T2_col_start = init_int_matrix(nirreps, nirreps);
-  for(h=0; h < nirreps; h++) {
-    for(Gd = 0,offset=0; Gd < nirreps; Gd++) {
-      Gc = Gd ^ h;
-      T2_col_start[h][Gd] = offset;
-      offset += virtpi[Gd] * virtpi[Gc];
-    }
-  }
-
-  E_col_start = init_int_matrix(nirreps, nirreps);
-  for(h=0; h < nirreps; h++) {
-    for(Gl = 0,offset=0; Gl < nirreps; Gl++) {
-      Gc = Gl ^ h;
-      E_col_start[h][Gl] = offset;
-      offset += occpi[Gl] * virtpi[Gc];
-    }
-  }
-
   dpd_file2_init(&fIJ, CC_OEI, 0, 0, 0, "fIJ");
   dpd_file2_init(&fAB, CC_OEI, 0, 1, 1, "fAB");
   dpd_file2_init(&fIA, CC_OEI, 0, 0, 1, "fIA");
@@ -213,9 +150,9 @@ double ET_UHF_AAA(void)
 		  Gab = Gid = Gi ^ Gd;
 		  Gc = Gjk ^ Gd;
 
-		  cd = T2_col_start[Gjk][Gc];
-		  id = F_row_start[Gid][I];
-
+		  cd = T2.col_offset[Gjk][Gc];
+		  id = Fints.row_offset[Gid][I];
+ 
 		  Fints.matrix[Gid] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gid]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gid, id, virtpi[Gd]);
 
@@ -235,8 +172,8 @@ double ET_UHF_AAA(void)
 		  Gab = Gjd = Gj ^ Gd;
 		  Gc = Gik ^ Gd;
 
-		  cd = T2_col_start[Gik][Gc];
-		  jd = F_row_start[Gjd][J];
+		  cd = T2.col_offset[Gik][Gc];
+		  jd = Fints.row_offset[Gjd][J];
 
 		  Fints.matrix[Gjd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gjd, jd, virtpi[Gd]);
@@ -257,8 +194,8 @@ double ET_UHF_AAA(void)
 		  Gab = Gkd = Gk ^ Gd;
 		  Gc = Gji ^ Gd;
 
-		  cd = T2_col_start[Gji][Gc];
-		  kd = F_row_start[Gkd][K];
+		  cd = T2.col_offset[Gji][Gc];
+		  kd = Fints.row_offset[Gkd][K];
 
 		  Fints.matrix[Gkd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gkd, kd, virtpi[Gd]);
@@ -282,8 +219,8 @@ double ET_UHF_AAA(void)
 		  Gab = Gil = Gi ^ Gl;
 		  Gc = Gjk ^ Gl;
 
-		  lc = E_col_start[Gjk][Gl];
-		  il = T2_row_start[Gil][I];
+		  lc = Eints.col_offset[Gjk][Gl];
+		  il = T2.row_offset[Gil][I];
 
 		  nrows = T2.params->coltot[Gil];
 		  ncols = virtpi[Gc];
@@ -299,8 +236,8 @@ double ET_UHF_AAA(void)
 		  Gab = Gjl = Gj ^ Gl;
 		  Gc = Gik ^ Gl;
 
-		  lc = E_col_start[Gik][Gl];
-		  jl = T2_row_start[Gjl][J];
+		  lc = Eints.col_offset[Gik][Gl];
+		  jl = T2.row_offset[Gjl][J];
 
 		  nrows = T2.params->coltot[Gjl];
 		  ncols = virtpi[Gc];
@@ -316,8 +253,8 @@ double ET_UHF_AAA(void)
 		  Gab = Gkl = Gk ^ Gl;
 		  Gc = Gji ^ Gl;
 
-		  lc = E_col_start[Gji][Gl];
-		  kl = T2_row_start[Gkl][K];
+		  lc = Eints.col_offset[Gji][Gl];
+		  kl = T2.row_offset[Gkl][K];
 
 		  nrows = T2.params->coltot[Gkl];
 		  ncols = virtpi[Gc];
@@ -341,8 +278,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gid = Gi ^ Gd;
 		  Ga = Gjk ^ Gd;
 
-		  ad = T2_col_start[Gjk][Ga];
-		  id = F_row_start[Gid][I];
+		  ad = T2.col_offset[Gjk][Ga];
+		  id = Fints.row_offset[Gid][I];
 
 		  Fints.matrix[Gid] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gid]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gid, id, virtpi[Gd]);
@@ -363,8 +300,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gjd = Gj ^ Gd;
 		  Ga = Gik ^ Gd;
 
-		  ad = T2_col_start[Gik][Ga];
-		  jd = F_row_start[Gjd][J];
+		  ad = T2.col_offset[Gik][Ga];
+		  jd = Fints.row_offset[Gjd][J];
 
 		  Fints.matrix[Gjd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gjd, jd, virtpi[Gd]);
@@ -385,8 +322,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gkd = Gk ^ Gd;
 		  Ga = Gji ^ Gd;
 
-		  ad = T2_col_start[Gji][Ga];
-		  kd = F_row_start[Gkd][K];
+		  ad = T2.col_offset[Gji][Ga];
+		  kd = Fints.row_offset[Gkd][K];
 
 		  Fints.matrix[Gkd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gkd, kd, virtpi[Gd]);
@@ -410,8 +347,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gil = Gi ^ Gl;
 		  Ga = Gjk ^ Gl;
 
-		  la = E_col_start[Gjk][Gl];
-		  il = T2_row_start[Gil][I];
+		  la = Eints.col_offset[Gjk][Gl];
+		  il = T2.row_offset[Gil][I];
 
 		  nrows = T2.params->coltot[Gil];
 		  ncols = virtpi[Ga];
@@ -427,8 +364,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gjl = Gj ^ Gl;
 		  Ga = Gik ^ Gl;
 
-		  la = E_col_start[Gik][Gl];
-		  jl = T2_row_start[Gjl][J];
+		  la = Eints.col_offset[Gik][Gl];
+		  jl = T2.row_offset[Gjl][J];
 
 		  nrows = T2.params->coltot[Gjl];
 		  ncols = virtpi[Ga];
@@ -444,8 +381,8 @@ double ET_UHF_AAA(void)
 		  Gbc = Gkl = Gk ^ Gl;
 		  Ga = Gji ^ Gl;
 
-		  la = E_col_start[Gji][Gl];
-		  kl = T2_row_start[Gkl][K];
+		  la = Eints.col_offset[Gji][Gl];
+		  kl = T2.row_offset[Gkl][K];
 
 		  nrows = T2.params->coltot[Gkl];
 		  ncols = virtpi[Ga];
@@ -458,7 +395,7 @@ double ET_UHF_AAA(void)
 			    &(WBCA[Gbc][0][0]), ncols);
 		}
 
-		W_sort(WBCA, WABC, nirreps, Gijk, Fints.params->coltot, Fints.params->colidx,
+		dpd_3d_sort(WBCA, WABC, nirreps, Gijk, Fints.params->coltot, Fints.params->colidx,
 		       Fints.params->colorb, Fints.params->rsym, Fints.params->ssym,
 		       vir_off, vir_off, virtpi, vir_off, Fints.params->colidx, cab, 1);
 
@@ -475,8 +412,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gid = Gi ^ Gd;
 		  Gb = Gjk ^ Gd;
 
-		  bd = T2_col_start[Gjk][Gb];
-		  id = F_row_start[Gid][I];
+		  bd = T2.col_offset[Gjk][Gb];
+		  id = Fints.row_offset[Gid][I];
 
 		  Fints.matrix[Gid] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gid]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gid, id, virtpi[Gd]);
@@ -497,8 +434,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gjd = Gj ^ Gd;
 		  Gb = Gik ^ Gd;
 
-		  bd = T2_col_start[Gik][Gb];
-		  jd = F_row_start[Gjd][J];
+		  bd = T2.col_offset[Gik][Gb];
+		  jd = Fints.row_offset[Gjd][J];
 
 		  Fints.matrix[Gjd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gjd, jd, virtpi[Gd]);
@@ -519,8 +456,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gkd = Gk ^ Gd;
 		  Gb = Gji ^ Gd;
 
-		  bd = T2_col_start[Gji][Gb];
-		  kd = F_row_start[Gkd][K];
+		  bd = T2.col_offset[Gji][Gb];
+		  kd = Fints.row_offset[Gkd][K];
 
 		  Fints.matrix[Gkd] = dpd_block_matrix(virtpi[Gd], Fints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&Fints, Gkd, kd, virtpi[Gd]);
@@ -544,8 +481,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gil = Gi ^ Gl;
 		  Gb = Gjk ^ Gl;
 
-		  lb = E_col_start[Gjk][Gl];
-		  il = T2_row_start[Gil][I];
+		  lb = Eints.col_offset[Gjk][Gl];
+		  il = T2.row_offset[Gil][I];
 
 		  nrows = T2.params->coltot[Gil];
 		  ncols = virtpi[Gb];
@@ -561,8 +498,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gjl = Gj ^ Gl;
 		  Gb = Gik ^ Gl;
 
-		  lb = E_col_start[Gik][Gl];
-		  jl = T2_row_start[Gjl][J];
+		  lb = Eints.col_offset[Gik][Gl];
+		  jl = T2.row_offset[Gjl][J];
 
 		  nrows = T2.params->coltot[Gjl];
 		  ncols = virtpi[Gb];
@@ -578,8 +515,8 @@ double ET_UHF_AAA(void)
 		  Gac = Gkl = Gk ^ Gl;
 		  Gb = Gji ^ Gl;
 
-		  lb = E_col_start[Gji][Gl];
-		  kl = T2_row_start[Gkl][K];
+		  lb = Eints.col_offset[Gji][Gl];
+		  kl = T2.row_offset[Gkl][K];
 
 		  nrows = T2.params->coltot[Gkl];
 		  ncols = virtpi[Gb];
@@ -592,7 +529,7 @@ double ET_UHF_AAA(void)
 			    &(WACB[Gac][0][0]), ncols);
 		}
 
-		W_sort(WACB, WABC, nirreps, Gijk, Fints.params->coltot, Fints.params->colidx,
+		dpd_3d_sort(WACB, WABC, nirreps, Gijk, Fints.params->coltot, Fints.params->colidx,
 		       Fints.params->colorb, Fints.params->rsym, Fints.params->ssym,
 		       vir_off, vir_off, virtpi, vir_off, Fints.params->colidx, acb, 1);
 
@@ -627,7 +564,7 @@ double ET_UHF_AAA(void)
 
 		      /* +t_ia * D_jkbc + f_ia * t_jkbc */
 		      if(Gi == Ga && Gjk == Gbc) {
-			t_ia = D_jkbc = 0.0;
+			t_ia = D_jkbc = f_ia = t_jkbc = 0.0;
 
 			if(T1.params->rowtot[Gi] && T1.params->coltot[Gi]) {
 			  t_ia = T1.matrix[Gi][i][a];
@@ -644,7 +581,7 @@ double ET_UHF_AAA(void)
 
 		      /* -t_ib * D_jkac - f_ib * t_jkac */
 		      if(Gi == Gb && Gjk == Gac) {
-			t_ib = D_jkac = 0.0;
+			t_ib = D_jkac = f_ib = t_jkac = 0.0;
 
 			if(T1.params->rowtot[Gi] && T1.params->coltot[Gi]) {
 			  t_ib = T1.matrix[Gi][i][b];
@@ -661,7 +598,7 @@ double ET_UHF_AAA(void)
 
 		      /* +t_ic * D_jkab + f_ic * t_jkba */
 		      if(Gi == Gc && Gjk == Gab) {
-			t_ic = D_jkba = 0.0;
+			t_ic = D_jkba = f_ic = t_jkba = 0.0;
 
 			if(T1.params->rowtot[Gi] && T1.params->coltot[Gi]) {
 			  t_ic = T1.matrix[Gi][i][c];
@@ -678,7 +615,7 @@ double ET_UHF_AAA(void)
 
 		      /* -t_ja * D_ikbc - f_ja * t_ikbc*/
 		      if(Gj == Ga && Gik == Gbc) {
-			t_ja = D_ikbc = 0.0;
+			t_ja = D_ikbc = f_ja = t_ikbc = 0.0;
 
 			if(T1.params->rowtot[Gj] && T1.params->coltot[Gj]) {
 			  t_ja = T1.matrix[Gj][j][a];
@@ -695,7 +632,7 @@ double ET_UHF_AAA(void)
 
 		      /* +t_jb * D_ikac + f_jb * t_ikac */
 		      if(Gj == Gb && Gik == Gac) {
-			t_jb = D_ikac = 0.0;
+			t_jb = D_ikac = f_jb = t_ikac = 0.0;
 
 			if(T1.params->rowtot[Gj] && T1.params->coltot[Gj]) {
 			  t_jb = T1.matrix[Gj][j][b];
@@ -712,7 +649,7 @@ double ET_UHF_AAA(void)
 
 		      /* -t_jc * D_ikba - f_jc * t_ikba */
 		      if(Gj == Gc && Gik == Gab) {
-			t_jc = D_ikba = 0.0;
+			t_jc = D_ikba = f_jc = t_ikba = 0.0;
 
 			if(T1.params->rowtot[Gj] && T1.params->coltot[Gj]) {
 			  t_jc = T1.matrix[Gj][j][c];
@@ -729,7 +666,7 @@ double ET_UHF_AAA(void)
 
 		      /* -t_ka * D_jibc - f_ka * t_jibc */
 		      if(Gk == Ga && Gji == Gbc) {
-			t_ka = D_jibc = 0.0;
+			t_ka = D_jibc = f_ka = t_jibc = 0.0;
 
 			if(T1.params->rowtot[Gk] && T1.params->coltot[Gk]) {
 			  t_ka = T1.matrix[Gk][k][a];
@@ -746,7 +683,7 @@ double ET_UHF_AAA(void)
 
 		      /* +t_kb * D_jiac + f_kb * t_jiac */
 		      if(Gk == Gb && Gji == Gac) {
-			t_kb = D_jiac = 0.0;
+			t_kb = D_jiac = f_kb = t_jiac = 0.0;
 
 			if(T1.params->rowtot[Gk] && T1.params->coltot[Gk]) {
 			  t_kb = T1.matrix[Gk][k][b];
@@ -763,7 +700,7 @@ double ET_UHF_AAA(void)
 
 		      /* -t_kc * D_jiab - f_kc * t_jiba*/
 		      if(Gk == Gc && Gji == Gab) {
-			t_kc = D_jiba = 0.0;
+			t_kc = D_jiba = f_kc = t_jiba = 0.0;
 
 			if(T1.params->rowtot[Gk] && T1.params->coltot[Gk]) {
 			  t_kc = T1.matrix[Gk][k][c];
@@ -846,10 +783,5 @@ double ET_UHF_AAA(void)
   dpd_file2_close(&fAB);
   dpd_file2_close(&fIA);
 
-  free_int_matrix(F_row_start, nirreps);
-  free_int_matrix(E_col_start, nirreps);
-  free_int_matrix(T2_row_start, nirreps);
-  free_int_matrix(T2_col_start, nirreps);
-
   return ET;
 }
