@@ -1,4 +1,4 @@
-#include <stdio.h>
+ #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <libdpd/dpd.h>
@@ -6,12 +6,6 @@
 #define EXTERN
 #include "globals.h"
 
-enum pattern {abc, acb, cab, cba, bca, bac};
-
-void W_sort(double ***Win, double ***Wout, int nirreps, int h, int *coltot, int **colidx, 
-	    int ***colorb, int *asym, int *bsym, int *aoff, int *boff,
-	    int *cpi, int *coff, int **colidx_out, enum pattern index, int sum);
-
 double ET_UHF_ABB(void)
 {
   int cnt;
@@ -32,7 +26,6 @@ double ET_UHF_ABB(void)
   int *aoccpi, *avirtpi, *aocc_off, *avir_off;
   int *boccpi, *bvirtpi, *bocc_off, *bvir_off;
   double value_c, value_d, dijk, denom, ET_ABB;
-  int numpA, numpB, p, Gp, offset;
   int nrows, ncols, nlinks;
   double t_ia, t_jb, t_jc, t_kb, t_kc;
   double f_ia, f_jb, f_jc, f_kb, f_kc;
@@ -42,10 +35,6 @@ double ET_UHF_ABB(void)
   dpdbuf4 FBBints, FABints, FBAints;
   dpdbuf4 EBBints, EABints, EBAints;
   dpdbuf4 DBBints, DABints;
-  int **T2AB_row_start, **T2BA_row_start, **T2BB_row_start;
-  int **T2AB_col_start, **T2BB_col_start;
-  int **FAB_row_start, **FBA_row_start, **FBB_row_start;
-  int **EAB_col_start, **EBA_col_start, **EBB_col_start;
   dpdfile2 T1A, T1B, fIJ, fij, fAB, fab, fIA, fia;
   double ***WAbc, ***VAbc, ***WAcb, ***WbAc, ***WcAb, ***WbcA;
   int nijk, mijk;
@@ -61,153 +50,6 @@ double ET_UHF_ABB(void)
   bocc_off = moinfo.bocc_off;
   bvir_off = moinfo.bvir_off;
 
-  for(h=0,numpA=0; h < nirreps; h++) numpA += aoccpi[h];
-  for(h=0,numpB=0; h < nirreps; h++) numpB += boccpi[h];
-
-  /* Build F integral row offsets */
-  FBB_row_start = init_int_matrix(nirreps, numpB);
-  FAB_row_start = init_int_matrix(nirreps, numpA);
-  FBA_row_start = init_int_matrix(nirreps, numpB);
-
-  for(h=0; h < nirreps; h++) {
-
-    for(p=0; p < numpA; p++) FAB_row_start[h][p] = -1;
-    for(p=0; p < numpB; p++) FBB_row_start[h][p] = -1;
-    for(p=0; p < numpB; p++) FBA_row_start[h][p] = -1;
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < aoccpi[Gp]; p++) {
-
-	if(bvirtpi[Gp^h]) 
-	  FAB_row_start[h][aocc_off[Gp] + p] = nrows;
-
-	nrows += bvirtpi[Gp^h];
-      }
-    }
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < boccpi[Gp]; p++) {
-
-	if(bvirtpi[Gp^h]) 
-	  FBB_row_start[h][bocc_off[Gp] + p] = nrows;
-
-	nrows += bvirtpi[Gp^h];
-      }
-    }
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < boccpi[Gp]; p++) {
-
-	if(avirtpi[Gp^h]) 
-	  FBA_row_start[h][bocc_off[Gp] + p] = nrows;
-
-	nrows += avirtpi[Gp^h];
-      }
-    }
-  }
-
-  /* Build T2 amplitude row offsets */
-  T2BB_row_start = init_int_matrix(nirreps, numpB);
-  T2AB_row_start = init_int_matrix(nirreps, numpA);
-  T2BA_row_start = init_int_matrix(nirreps, numpB);
-
-  for(h=0; h < nirreps; h++) {
-
-    for(p=0; p < numpA; p++) {
-      T2AB_row_start[h][p] = -1;
-    }
-
-    for(p=0; p < numpB; p++) {
-      T2BB_row_start[h][p] = -1;
-      T2BA_row_start[h][p] = -1;
-    }
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < aoccpi[Gp]; p++) {
-
-	if(boccpi[Gp^h]) 
-	  T2AB_row_start[h][aocc_off[Gp] + p] = nrows;
-
-	nrows += boccpi[Gp^h];
-      }
-    }
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < boccpi[Gp]; p++) {
-
-	if(aoccpi[Gp^h]) 
-	  T2BA_row_start[h][bocc_off[Gp] + p] = nrows;
-
-	nrows += aoccpi[Gp^h];
-      }
-    }
-
-    nrows = 0;
-    for(Gp=0; Gp < nirreps; Gp++) {
-      for(p=0; p < boccpi[Gp]; p++) {
-
-	if(boccpi[Gp^h]) 
-	  T2BB_row_start[h][bocc_off[Gp] + p] = nrows;
-
-	nrows += boccpi[Gp^h];
-      }
-    }
-  }
-
-  /* Build T2 amplitude column offsets */
-  T2BB_col_start = init_int_matrix(nirreps, nirreps);
-  T2AB_col_start = init_int_matrix(nirreps, nirreps);
-
-  for(h=0; h < nirreps; h++) {
-    for(Gd = 0,offset=0; Gd < nirreps; Gd++) {
-      Gc = Gd ^ h;
-      T2BB_col_start[h][Gd] = offset;
-      offset += bvirtpi[Gd] * bvirtpi[Gc];
-    }
-  }
-
-  for(h=0; h < nirreps; h++) {
-    for(Gd = 0,offset=0; Gd < nirreps; Gd++) {
-      Gc = Gd ^ h;
-      T2AB_col_start[h][Gd] = offset;
-      offset += avirtpi[Gd] * bvirtpi[Gc];
-    }
-  }
-
-  /* Build E integral column offsets */
-  EBB_col_start = init_int_matrix(nirreps, nirreps);
-  EAB_col_start = init_int_matrix(nirreps, nirreps);
-  EBA_col_start = init_int_matrix(nirreps, nirreps);
-
-  for(h=0; h < nirreps; h++) {
-    for(Gl = 0,offset=0; Gl < nirreps; Gl++) {
-      Gc = Gl ^ h;
-      EBB_col_start[h][Gl] = offset;
-      offset += boccpi[Gl] * bvirtpi[Gc];
-    }
-  }
-
-  for(h=0; h < nirreps; h++) {
-    for(Gl = 0,offset=0; Gl < nirreps; Gl++) {
-      Gc = Gl ^ h;
-      EAB_col_start[h][Gl] = offset;
-      offset += aoccpi[Gl] * bvirtpi[Gc];
-    }
-  }
-
-  for(h=0; h < nirreps; h++) {
-    for(Gl = 0,offset=0; Gl < nirreps; Gl++) {
-      Gc = Gl ^ h;
-      EBA_col_start[h][Gl] = offset;
-      offset += boccpi[Gl] * avirtpi[Gc];
-    }
-  }
-
   dpd_file2_init(&fIJ, CC_OEI, 0, 0, 0, "fIJ");
   dpd_file2_init(&fij, CC_OEI, 0, 2, 2, "fij");
   dpd_file2_init(&fAB, CC_OEI, 0, 1, 1, "fAB");
@@ -358,8 +200,8 @@ double ET_UHF_ABB(void)
 		  Gab = Gid = Gi ^ Gd;
 		  Gc = Gjk ^ Gd;
 
-		  cd = T2BB_col_start[Gjk][Gc];
-		  id = FAB_row_start[Gid][I];
+		  cd = T2BB.col_offset[Gjk][Gc];
+		  id = FABints.row_offset[Gid][I];
 
 		  FABints.matrix[Gid] = dpd_block_matrix(bvirtpi[Gd], FABints.params->coltot[Gid]);
 		  dpd_buf4_mat_irrep_rd_block(&FABints, Gid, id, bvirtpi[Gd]);
@@ -383,8 +225,8 @@ double ET_UHF_ABB(void)
 		  Gab = Gil = Gi ^ Gl;
 		  Gc = Gjk ^ Gl;
 
-		  lc = EBB_col_start[Gjk][Gl];
-		  il = T2AB_row_start[Gil][I];
+		  lc = EBBints.col_offset[Gjk][Gl];
+		  il = T2AB.row_offset[Gil][I];
 
 		  nrows = T2AB.params->coltot[Gil];
 		  ncols = bvirtpi[Gc];
@@ -408,8 +250,8 @@ double ET_UHF_ABB(void)
 		  Gac = Gid = Gi ^ Gd;
 		  Gb = Gjk ^ Gd;
 
-		  bd = T2BB_col_start[Gjk][Gb];
-		  id = FAB_row_start[Gid][I];
+		  bd = T2BB.col_offset[Gjk][Gb];
+		  id = FABints.row_offset[Gid][I];
 
 		  FABints.matrix[Gid] = dpd_block_matrix(bvirtpi[Gd], FABints.params->coltot[Gid]);
 		  dpd_buf4_mat_irrep_rd_block(&FABints, Gid, id, bvirtpi[Gd]);
@@ -433,8 +275,8 @@ double ET_UHF_ABB(void)
 		  Gac = Gil = Gi ^ Gl;
 		  Gb = Gjk ^ Gl;
 
-		  lb = EBB_col_start[Gjk][Gl];
-		  il = T2AB_row_start[Gil][I];
+		  lb = EBBints.col_offset[Gjk][Gl];
+		  il = T2AB.row_offset[Gil][I];
 
 		  nrows = T2AB.params->coltot[Gil];
 		  ncols = bvirtpi[Gb];
@@ -447,7 +289,7 @@ double ET_UHF_ABB(void)
 			    &(WAcb[Gac][0][0]), ncols);
 		}
 
-		W_sort(WAcb, WAbc, nirreps, Gijk, FABints.params->coltot, FABints.params->colidx,
+		dpd_3d_sort(WAcb, WAbc, nirreps, Gijk, FABints.params->coltot, FABints.params->colidx,
 		       FABints.params->colorb, FABints.params->rsym, FABints.params->ssym,
 		       avir_off, bvir_off, bvirtpi, bvir_off, FABints.params->colidx, acb, 1);
 
@@ -464,8 +306,8 @@ double ET_UHF_ABB(void)
 		  Gbc = Gjd = Gj ^ Gd;
 		  Ga = Gik ^ Gd;
 
-		  ad = T2AB_col_start[Gik][Ga];
-		  jd = FBB_row_start[Gjd][J];
+		  ad = T2AB.col_offset[Gik][Ga];
+		  jd = FBBints.row_offset[Gjd][J];
 
 		  FBBints.matrix[Gjd] = dpd_block_matrix(bvirtpi[Gd], FBBints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBBints, Gjd, jd, bvirtpi[Gd]);
@@ -486,8 +328,8 @@ double ET_UHF_ABB(void)
 		  Gbc = Gkd = Gk ^ Gd;
 		  Ga = Gij ^ Gd;
 
-		  ad = T2AB_col_start[Gij][Ga];
-		  kd = FBB_row_start[Gkd][K];
+		  ad = T2AB.col_offset[Gij][Ga];
+		  kd = FBBints.row_offset[Gkd][K];
 
 		  FBBints.matrix[Gkd] = dpd_block_matrix(bvirtpi[Gd], FBBints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBBints, Gkd, kd, bvirtpi[Gd]);
@@ -511,8 +353,8 @@ double ET_UHF_ABB(void)
 		  Gbc = Gjl = Gj ^ Gl;
 		  Ga = Gki ^ Gl;
 
-		  la = EBA_col_start[Gki][Gl];
-		  jl = T2BB_row_start[Gjl][J];
+		  la = EBAints.col_offset[Gki][Gl];
+		  jl = T2BB.row_offset[Gjl][J];
 
 		  nrows = T2BB.params->coltot[Gjl];
 		  ncols = avirtpi[Ga];
@@ -528,8 +370,8 @@ double ET_UHF_ABB(void)
 		  Gbc = Gkl = Gk ^ Gl;
 		  Ga = Gji ^ Gl;
 
-		  la = EBA_col_start[Gji][Gl];
-		  kl = T2BB_row_start[Gkl][K];
+		  la = EBAints.col_offset[Gji][Gl];
+		  kl = T2BB.row_offset[Gkl][K];
 
 		  nrows = T2BB.params->coltot[Gkl];
 		  ncols = avirtpi[Ga];
@@ -542,7 +384,7 @@ double ET_UHF_ABB(void)
 			    &(WbcA[Gbc][0][0]), ncols);
 		}
 
-		W_sort(WbcA, WAbc, nirreps, Gijk, FBBints.params->coltot, FBBints.params->colidx,
+		dpd_3d_sort(WbcA, WAbc, nirreps, Gijk, FBBints.params->coltot, FBBints.params->colidx,
 		       FBBints.params->colorb, FBBints.params->rsym, FBBints.params->ssym,
 		       bvir_off, bvir_off, avirtpi, avir_off, FABints.params->colidx, cab, 1);
 
@@ -559,8 +401,8 @@ double ET_UHF_ABB(void)
 		  Gca = Gjd = Gj ^ Gd;
 		  Gb = Gik ^ Gd;
 
-		  db = T2AB_col_start[Gik][Gd];
-		  jd = FBA_row_start[Gjd][J];
+		  db = T2AB.col_offset[Gik][Gd];
+		  jd = FBAints.row_offset[Gjd][J];
 
 		  FBAints.matrix[Gjd] = dpd_block_matrix(avirtpi[Gd], FBAints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBAints, Gjd, jd, avirtpi[Gd]);
@@ -581,8 +423,8 @@ double ET_UHF_ABB(void)
 		  Gca = Gkd = Gk ^ Gd;
 		  Gb = Gij ^ Gd;
 
-		  db = T2AB_col_start[Gij][Gd];
-		  kd = FBA_row_start[Gkd][K];
+		  db = T2AB.col_offset[Gij][Gd];
+		  kd = FBAints.row_offset[Gkd][K];
 
 		  FBAints.matrix[Gkd] = dpd_block_matrix(avirtpi[Gd], FBAints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBAints, Gkd, kd, avirtpi[Gd]);
@@ -606,8 +448,8 @@ double ET_UHF_ABB(void)
 		  Gca = Gjl = Gj ^ Gl;
 		  Gb = Gik ^ Gl;
 
-		  lb = EAB_col_start[Gik][Gl];
-		  jl = T2BA_row_start[Gjl][J];
+		  lb = EABints.col_offset[Gik][Gl];
+		  jl = T2BA.row_offset[Gjl][J];
 
 		  nrows = T2BA.params->coltot[Gjl];
 		  ncols = bvirtpi[Gb];
@@ -623,8 +465,8 @@ double ET_UHF_ABB(void)
 		  Gca = Gkl = Gk ^ Gl;
 		  Gb = Gij ^ Gl;
 
-		  lb = EAB_col_start[Gij][Gl];
-		  kl = T2BA_row_start[Gkl][K];
+		  lb = EABints.col_offset[Gij][Gl];
+		  kl = T2BA.row_offset[Gkl][K];
 
 		  nrows = T2BA.params->coltot[Gkl];
 		  ncols = bvirtpi[Gb];
@@ -637,7 +479,7 @@ double ET_UHF_ABB(void)
 			    &(WcAb[Gca][0][0]), ncols);
 		}
 
-		W_sort(WcAb, WAbc, nirreps, Gijk, FBAints.params->coltot, FBAints.params->colidx,
+		dpd_3d_sort(WcAb, WAbc, nirreps, Gijk, FBAints.params->coltot, FBAints.params->colidx,
 		       FBAints.params->colorb, FBAints.params->rsym, FBAints.params->ssym,
 		       bvir_off, avir_off, bvirtpi, bvir_off, FABints.params->colidx, bca, 1);
 
@@ -654,8 +496,8 @@ double ET_UHF_ABB(void)
 		  Gba = Gjd = Gj ^ Gd;
 		  Gc = Gik ^ Gd;
 
-		  dc = T2AB_col_start[Gik][Gd];
-		  jd = FBA_row_start[Gjd][J];
+		  dc = T2AB.col_offset[Gik][Gd];
+		  jd = FBAints.row_offset[Gjd][J];
 
 		  FBAints.matrix[Gjd] = dpd_block_matrix(avirtpi[Gd], FBAints.params->coltot[Gjd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBAints, Gjd, jd, avirtpi[Gd]);
@@ -676,8 +518,8 @@ double ET_UHF_ABB(void)
 		  Gba = Gkd = Gk ^ Gd;
 		  Gc = Gij ^ Gd;
 
-		  dc = T2AB_col_start[Gij][Gd];
-		  kd = FBA_row_start[Gkd][K];
+		  dc = T2AB.col_offset[Gij][Gd];
+		  kd = FBAints.row_offset[Gkd][K];
 
 		  FBAints.matrix[Gkd] = dpd_block_matrix(avirtpi[Gd], FBAints.params->coltot[Gkd]);
 		  dpd_buf4_mat_irrep_rd_block(&FBAints, Gkd, kd, avirtpi[Gd]);
@@ -701,8 +543,8 @@ double ET_UHF_ABB(void)
 		  Gba = Gjl = Gj ^ Gl;
 		  Gc = Gik ^ Gl;
 
-		  lc = EAB_col_start[Gik][Gl];
-		  jl = T2BA_row_start[Gjl][J];
+		  lc = EABints.col_offset[Gik][Gl];
+		  jl = T2BA.row_offset[Gjl][J];
 
 		  nrows = T2BA.params->coltot[Gjl];
 		  ncols = bvirtpi[Gc];
@@ -718,8 +560,8 @@ double ET_UHF_ABB(void)
 		  Gba = Gkl = Gk ^ Gl;
 		  Gc = Gij ^ Gl;
 
-		  lc = EAB_col_start[Gij][Gl];
-		  kl = T2BA_row_start[Gkl][K];
+		  lc = EABints.col_offset[Gij][Gl];
+		  kl = T2BA.row_offset[Gkl][K];
 
 		  nrows = T2BA.params->coltot[Gkl];
 		  ncols = bvirtpi[Gc];
@@ -732,7 +574,7 @@ double ET_UHF_ABB(void)
 			    &(WbAc[Gba][0][0]), ncols);
 		}
 
-		W_sort(WbAc, WAbc, nirreps, Gijk, FBAints.params->coltot, FBAints.params->colidx,
+		dpd_3d_sort(WbAc, WAbc, nirreps, Gijk, FBAints.params->coltot, FBAints.params->colidx,
 		       FBAints.params->colorb, FBAints.params->rsym, FBAints.params->ssym,
 		       bvir_off, avir_off, bvirtpi, bvir_off, FABints.params->colidx, bac, 1);
 
@@ -767,7 +609,7 @@ double ET_UHF_ABB(void)
 
 		      /* +t_IA * D_jkbc + f_IA * t_jkbc */
 		      if(Gi == Ga && Gjk == Gbc) {
-			t_ia = D_jkbc = 0.0;
+			t_ia = D_jkbc = f_ia = t_jkbc = 0.0;
 
 			if(T1A.params->rowtot[Gi] && T1A.params->coltot[Gi]) {
 			  t_ia = T1A.matrix[Gi][i][a];
@@ -784,7 +626,7 @@ double ET_UHF_ABB(void)
 
 		      /* +t_jb * D_IkAc + f_jb * t_IkAc */
 		      if(Gj == Gb && Gik == Gac) {
-			t_jb = D_ikac = 0.0;
+			t_jb = D_ikac = f_jb = t_ikac = 0.0;
 
 			if(T1B.params->rowtot[Gj] && T1B.params->coltot[Gj]) {
 			  t_jb = T1B.matrix[Gj][j][b];
@@ -801,7 +643,7 @@ double ET_UHF_ABB(void)
 
 		      /* -t_jc * D_IkAb - f_jc * t_IkAb */
 		      if(Gj == Gc && Gik == Gab) {
-			t_jc = D_ikab = 0.0;
+			t_jc = D_ikab = f_jc = t_ikab = 0.0;
 
 			if(T1B.params->rowtot[Gj] && T1B.params->coltot[Gj]) {
 			  t_jc = T1B.matrix[Gj][j][c];
@@ -818,7 +660,7 @@ double ET_UHF_ABB(void)
 
 		      /* -t_kb * D_IjAc - f_kb * t_IjAc */
 		      if(Gk == Gb && Gji == Gac) {
-			t_kb = D_ijac = 0.0;
+			t_kb = D_ijac = f_kb = t_ijac = 0.0;
 
 			if(T1B.params->rowtot[Gk] && T1B.params->coltot[Gk]) {
 			  t_kb = T1B.matrix[Gk][k][b];
@@ -835,7 +677,7 @@ double ET_UHF_ABB(void)
 
 		      /* +t_kc * D_IjAb + f_kc * t_IjAb */
 		      if(Gk == Gc && Gji == Gab) {
-			t_kc = D_ijab = 0.0;
+			t_kc = D_ijab = f_kc = t_ijab = 0.0;
 
 			if(T1B.params->rowtot[Gk] && T1B.params->coltot[Gk]) {
 			  t_kc = T1B.matrix[Gk][k][c];
@@ -936,18 +778,5 @@ double ET_UHF_ABB(void)
   dpd_file2_close(&fIA);
   dpd_file2_close(&fia);
 
-  free_int_matrix(FBB_row_start, nirreps);
-  free_int_matrix(FAB_row_start, nirreps);
-  free_int_matrix(FBA_row_start, nirreps);
-  free_int_matrix(T2BB_row_start, nirreps);
-  free_int_matrix(T2AB_row_start, nirreps);
-  free_int_matrix(T2BA_row_start, nirreps);
-
-  free_int_matrix(T2BB_col_start, nirreps);
-  free_int_matrix(T2AB_col_start, nirreps);
-  free_int_matrix(EBB_col_start, nirreps);
-  free_int_matrix(EAB_col_start, nirreps);
-  free_int_matrix(EBA_col_start, nirreps);
-
   return ET_ABB;
 }
