@@ -43,8 +43,6 @@ static double ke_int(double a1, int l1, int m1, int n1, double norm1,
 		     struct coordinates PB);
 static double f_n(int k, int l1, int l2, double A, double B);
 static double int_pow(double a, int p);
-static double ***init_box(int a, int b, int c);
-static void free_box(double ***box, int a, int b);
 
 /*-------------------------------------------------------------
   This function computes derivatives of one-electron integrals
@@ -90,7 +88,7 @@ void oe_deriv2()
    double ab2;
    double tmp;
    double inorm, jnorm, over_pf;
-   double norm_pf, normover_pf, dens_pf, wdens_pf, zdens_pf, znormover_pf;
+   double norm_pf, normover_pf, dens_pf, wdens_pf, zdens_pf, znormover_pf, hds_norm_pf;
    double twozeta_a, twozeta_b, upuppfac, updownpfac, s_int, t_int, v_int;
    double *ptr1, *ptr2, norm1, norm12;
    double ***AI0;
@@ -203,6 +201,7 @@ void oe_deriv2()
 		    dens_pf *= norm_pf;
 		    wdens_pf = (-1.0)*Lagr[I][J];
 		    wdens_pf *= norm_pf;
+		    hds_norm_pf = norm_pf;
 		    if (I != J) {
 		      dens_pf *= 2.0;
 		      wdens_pf *= 2.0;
@@ -212,6 +211,59 @@ void oe_deriv2()
 		    if (strcmp(UserOptions.wfn,"SCF"))
 		      wdens_pf *= 0.5;
 
+		    /*----------------------------------
+		      Half-derivative overap integrals
+		     ----------------------------------*/
+		    /*--- d/dAx ---*/
+		    tmp = 2.0*a1*overlap_int(a1, l1+1, m1, n1, inorm, a2, l2, m2, 
+					     n2, jnorm, AB, PA, PB);
+		    if (l1)
+		      tmp -= l1*overlap_int(a1, l1-1, m1, n1, inorm, a2, l2, m2, 
+					    n2, jnorm, AB, PA, PB);
+		    HDS[coord_ax][I][J] += tmp*hds_norm_pf;
+
+		    /*--- d/dAy ---*/
+		    tmp = 2.0*a1*overlap_int(a1, l1, m1+1, n1, inorm, a2, l2, m2, 
+					     n2, jnorm, AB, PA, PB);
+		    if (m1)
+		      tmp -= m1*overlap_int(a1, l1, m1-1, n1, inorm, a2, l2, m2, 
+					    n2, jnorm, AB, PA, PB);
+		    HDS[coord_ay][I][J] += tmp*hds_norm_pf;
+
+		    /*--- d/dAz ---*/
+		    tmp = 2.0*a1*overlap_int(a1, l1, m1, n1+1, inorm, a2, l2, m2, 
+					     n2, jnorm, AB, PA, PB);
+		    if (n1)
+		      tmp -= n1*overlap_int(a1, l1, m1, n1-1, inorm, a2, l2, m2, 
+					    n2, jnorm, AB, PA, PB);
+		    HDS[coord_az][I][J] += tmp*hds_norm_pf;
+
+		    if(I != J) {
+                      /*--- d/dAx ---*/
+                      tmp = 2.0*a2*overlap_int(a2, l2+1, m2, n2, jnorm, a1, l1, m1,
+                                               n1, inorm, AB, PB, PA);
+                      if (l2)
+                        tmp -= l2*overlap_int(a2, l2-1, m2, n2, jnorm, a1, l1, m1,
+                                              n1, inorm, AB, PB, PA);
+                      HDS[coord_bx][J][I] += tmp*hds_norm_pf;
+  
+                      /*--- d/dAy ---*/
+                      tmp = 2.0*a2*overlap_int(a2, l2, m2+1, n2, jnorm, a1, l1, m1,
+                                               n1, inorm, AB, PB, PA);
+                      if (m2)
+                        tmp -= m2*overlap_int(a2, l2, m2-1, n2, jnorm, a1, l1, m1,
+                                              n1, inorm, AB, PB, PA);
+                      HDS[coord_by][J][I] += tmp*hds_norm_pf;
+  
+                      /*--- d/dAz ---*/
+                      tmp = 2.0*a2*overlap_int(a2, l2, m2, n2+1, jnorm, a1, l1, m1,
+                                               n1, inorm, AB, PB, PA);
+                      if (n2)
+                        tmp -= n2*overlap_int(a2, l2, m2, n2-1, jnorm, a1, l1, m1,
+                                              n1, inorm, AB, PB, PA);
+                      HDS[coord_bz][J][I] += tmp*hds_norm_pf;
+		    }
+
 		    /*----------------------------------
 		      First derivative overap integrals
 		     ----------------------------------*/
@@ -1567,39 +1619,3 @@ double int_pow(double a, int p)
   return b;
 }
 
-
-double ***init_box(int a, int b, int c)
-{
-  int i,j,k;
-  double ***box;
-
-  box = (double ***) malloc(sizeof(double **)*a);
-  for(i=0;i<a;i++)
-    box[i] = (double **) malloc(sizeof(double *)*b);
-  for(i=0;i<a;i++)
-    for(j=0;j<b;j++) {
-	box[i][j] = (double *) malloc(sizeof(double)*c);
-	bzero((char *) box[i][j],sizeof(double)*c);
-    }
-
-  return box;
-
-}
-
-
-void free_box(double ***box, int a, int b)
-{
-  int i,j;
-
-  for(i=0;i<a;i++)
-    for(j=0;j<b;j++)
-      free(box[i][j]);
-
-  for(i=0;i<a;i++)
-    free(box[i]); 
-
-  free(box);
-
-  return;
-}
-
