@@ -6,7 +6,6 @@
 #include<libipv1/ip_lib.h>
 #include<libiwl/iwl.h>
 #include<libciomr/libciomr.h>
-#include<psitypes.h>
 
 #include<libint/libint.h>
 #include"defines.h"
@@ -40,7 +39,7 @@ void te_ints()
   double_array_t fjt_table;
 #endif
 
-  PSI_INT_LEAST64 total_te_count = 0;
+  int total_te_count = 0;
   int ij, kl, ik, jl, ijkl;
   int ioffset, joffset, koffset, loffset;
   int count ;
@@ -1003,7 +1002,7 @@ void te_ints()
 #endif
 
 
-  fprintf(outfile,"\n    Wrote %ld two-electron integrals to IWL file %2d\n\n",total_te_count,IOUnits.itap33);
+  fprintf(outfile,"\n    Wrote %d two-electron integrals to IWL file %2d\n\n",total_te_count,IOUnits.itap33);
 
   /*---------
     Clean-up
