@@ -1,11 +1,20 @@
-/* $Log: cleanup.c,v $
-/* Revision 1.28.4.3  2005/01/29 20:10:11  crawdad
-/* (1) Fixed a bug in the UHF computation of the density in cints.
-/* (2) Corrected calculation of <S^2> for UHF in cscf.
-/* -TDC
+/* $Log$
+ * Revision 1.32  2007/04/05 15:45:25  crawdad
+ * Fixed a few memory leaks identified by valgrind. -TDC
+ *
+/* Revision 1.31  2005/11/10 16:37:50  evaleev
+/* Added CHECK_MO_ORTHONORMALITY input keyword. Useful for debugging.
 /*
-/* Revision 1.28.4.2  2004/09/07 21:40:37  evaleev
-/* Incorrect value for iopen was written out to chkpt file in UHF calculations.
+/* Revision 1.30  2004/08/12 19:13:32  crawdad
+/* Corrected computation of <S^2> for UHF references.  The equations were
+/* coded correctly, but variable types screwed up results for doublets,
+/* quartets, etc.  -TDC
+/*
+/* Revision 1.29  2004/05/03 04:32:40  crawdad
+/* Major mods based on merge with stable psi-3-2-1 release.  Note that this
+/* version has not been fully tested and some scf-optn test cases do not run
+/* correctly beccause of changes in mid-March 2004 to optking.
+/* -TDC
 /*
 /* Revision 1.28.4.1  2004/04/01 22:04:49  evaleev
 /* A critical bug: lagrangian was not written out to chkpt file correctly
@@ -192,7 +201,7 @@
 /* Added a version of CSCF that can work with CINTS.
 /* -Ed */
 
-static char *rcsid = "$Id: cleanup.c,v 1.28.4.3 2005/01/29 20:10:11 crawdad Exp $";
+static char *rcsid = "$Id: cleanup.c 3324 2007-04-05 15:45:25Z crawdad $";
 
 #define EXTERN
 #include "includes.h"
@@ -289,11 +298,8 @@ void cleanup()
   chkpt_wt_nsymhf(n_so_typs);
   chkpt_wt_nmo(nmo);
 
-  tmp_iopen = iopen;
-  if (n_open && !uhf) {
-    tmp_iopen = ioff[n_open];
-    if(twocon) tmp_iopen = -tmp_iopen;
-  }
+  tmp_iopen = ioff[n_open];
+  if(twocon) tmp_iopen = -tmp_iopen;
   chkpt_wt_iopen(tmp_iopen);
   nx = nmo*(nmo+1)/2;
    
@@ -376,14 +382,38 @@ void cleanup()
   }
   else {
     for(k=0,row=0,col=0; k < num_ir; k++) {
+      double** s_sq;
+      double** tmp;
       s=&scf_info[k];
-      for(i=0; i < s->num_so; i++) {
-	for(j=0; j < s->num_mo; j++) {
-	  scr1[i+row][j+col] = s->cmat[i][j];
-	}
+      if (s->num_mo) {
+        
+        /* Test normalization of MOs */
+        if (check_mo_orthonormality) {
+          fprintf(outfile,"  -Testing orthonormality of MOs in symmetry block %d\n",k);
+          fprintf(outfile,"    -overlap matrix:\n");
+          print_array(s->smat,s->num_so,outfile);
+          fprintf(outfile,"    -MOs:\n");
+          print_mat(s->cmat,s->num_so,s->num_mo,outfile);
+          s_sq = block_matrix(s->num_so,s->num_so);
+          tri_to_sq(s->smat,s_sq,s->num_so);
+          tmp = block_matrix(s->num_so,s->num_so);
+          mmult(s_sq,0,s->cmat,0,tmp,0,s->num_so,s->num_so,s->num_so,0);
+          mmult(s->cmat,1,tmp,0,s_sq,0,s->num_mo,s->num_so,s->num_mo,0);
+          fprintf(outfile,"    -Ct.S.C:\n");
+          print_mat(s_sq,s->num_mo,s->num_mo,outfile);
+          free_block(s_sq);
+          free_block(tmp);
+        } 
+        
+        for(i=0; i < s->num_so; i++) {
+          for(j=0; j < s->num_mo; j++) {
+            scr1[i+row][j+col] = s->cmat[i][j];
+          }
+        }
+        row += s->num_so;
+        col += s->num_mo;
+        
       }
-      row += s->num_so;
-      col += s->num_mo;
     }
     chkpt_wt_scf(scr1);
   }
@@ -487,6 +517,8 @@ void cleanup()
 	  }
 	}
       }
+      free_matrix(scr1,nsfmax);
+      free_matrix(scr2,nsfmax);
     }
        
     else {
@@ -556,7 +588,9 @@ void cleanup()
   /*if(print & 1){
     print_mos_new();
     }*/
-      
+
+  /* TDC (04/04/07) -- some old cleanups */
+  free(reference);
       
   fprintf(outfile,"\n%8cSCF total energy   = %20.12f\n",' ',etot);
       
@@ -674,58 +708,56 @@ print_mos_new() {
 
 double ssquare(void){
     
-    int i,j,k,nn,n;
-    int num_mo;
-    double ss=0.0;
-    double na=0;
-    double nb=0;
-    double nh=0;
-    double nm=0;
-    double **scr1,**scr2,**S;
-    struct symm *s;
+  int i,j,k,nn,n;
+  int num_mo;
+  double ss=0.0;
+  double na=0;
+  double nb=0;
+  double nm=0;
+  double nh=0.0;
+  double **scr1,**scr2,**S;
+  struct symm *s;
     
-    scr1 = (double **)init_matrix(nsfmax,nsfmax);
-    scr2 = (double **)init_matrix(nsfmax,nsfmax);
+  scr1 = (double **)init_matrix(nsfmax,nsfmax);
+  scr2 = (double **)init_matrix(nsfmax,nsfmax);
     
-    /* Calculate the overlap matrix elements */
+  /* Calculate the overlap matrix elements */
     
-    for(i = 0;i < num_ir;i++){
+  for(i = 0;i < num_ir;i++){
 	
-	na += spin_info[0].scf_spin[i].noccup;
-	nb += spin_info[1].scf_spin[i].noccup;
+    na += spin_info[0].scf_spin[i].noccup;
+    nb += spin_info[1].scf_spin[i].noccup;
 	
-	s = &scf_info[i];
-	if(nn = s->num_so){
-	    num_mo = s->num_mo;
-	    tri_to_sq(s->smat,scr1,nn);
+    s = &scf_info[i];
+    if(nn = s->num_so){
+      num_mo = s->num_mo;
+      tri_to_sq(s->smat,scr1,nn);
 	    
-	    /* Transform the Overlap matrix to the MO basis */
+      /* Transform the Overlap matrix to the MO basis */
 	    
-	    mmult(spin_info[0].scf_spin[i].cmat,1
-		  ,scr1,0,scr2,0,num_mo,nn,nn,0);
-	    mmult(scr2,0,spin_info[1].scf_spin[i].cmat,0
-		  ,scr1,0,num_mo,nn,num_mo,0);
+      mmult(spin_info[0].scf_spin[i].cmat,1,scr1,0,scr2,0,num_mo,nn,nn,0);
+      mmult(scr2,0,spin_info[1].scf_spin[i].cmat,0,scr1,0,num_mo,nn,num_mo,0);
 	    
-	    for(j = 0; j < spin_info[0].scf_spin[i].noccup; j++){
-		for(k = 0;k < spin_info[1].scf_spin[i].noccup; k++){
-		    ss -= scr1[j][k]*scr1[j][k];
-		}
-	    }
+      for(j = 0; j < spin_info[0].scf_spin[i].noccup; j++){
+	for(k = 0;k < spin_info[1].scf_spin[i].noccup; k++){
+	  ss -= scr1[j][k]*scr1[j][k];
 	}
+      }
     }
+  }
     
     
-      /* Calculate the occupation part of the equation */
+  /* Calculate the occupation part of the equation */
     
-    nm = (na-nb)/2.0;
-    nh = (nm*(nm+1))+nb;
+  nm = (na-nb)/2.0;
+  nh = (nm*(nm+1))+nb;
         
-    ss += (nm*(nm+1))+nb;
+  ss += (nm*(nm+1))+nb;
     
-    free_matrix(scr1,nsfmax);
-    free_matrix(scr2,nsfmax);
+  free_matrix(scr1,nsfmax);
+  free_matrix(scr2,nsfmax);
     
-    return fabs(ss);
+  return fabs(ss);
 }
 
 
