@@ -1,7 +1,7 @@
-/* $Log: errchk.c,v $
-/* Revision 1.2  2002/03/25 02:17:36  janssen
-/* Get rid of tmpl.  Use new naming scheme for libipv1 includes.
-/*
+/* $Log$
+ * Revision 1.2  2002/03/25 02:17:36  janssen
+ * Get rid of tmpl.  Use new naming scheme for libipv1 includes.
+ *
 /* Revision 1.1.1.1  2000/02/04 22:52:30  evaleev
 /* Started PSI 3 repository
 /*
@@ -19,7 +19,7 @@
 /* -Ed
  * */
 
-static char *rcsid = "$Id: errchk.c,v 1.2 2002/03/25 02:17:36 janssen Exp $";
+static char *rcsid = "$Id: errchk.c 737 2002-03-25 02:17:36Z janssen $";
 
 #include <stdio.h>
 #include <libipv1/ip_lib.h>
