@@ -1,7 +1,7 @@
-/* $Log: gprgid.c,v $
-/* Revision 1.1.1.1  2000/02/04 22:52:30  evaleev
-/* Started PSI 3 repository
-/*
+/* $Log$
+ * Revision 1.1  2000/02/04 22:52:30  evaleev
+ * Initial revision
+ *
 /* Revision 1.2  1999/08/17 19:04:15  evaleev
 /* Changed the default symmetric orthogonalization to the canonical
 /* orthogonalization. Now, if near-linear dependencies in the basis are found,
@@ -16,7 +16,7 @@
 /* -Ed
  * */
 
-static char *rcsid = "$Id: gprgid.c,v 1.1.1.1 2000/02/04 22:52:30 evaleev Exp $";
+static char *rcsid = "$Id: gprgid.c 2 2000-02-04 22:50:39Z evaleev $";
 
 char *gprgid()
 {
