@@ -1,7 +1,7 @@
-/* $Log: sdot.c,v $
-/* Revision 1.1.1.1  2000/02/04 22:52:32  evaleev
-/* Started PSI 3 repository
-/*
+/* $Log$
+ * Revision 1.1  2000/02/04 22:52:32  evaleev
+ * Initial revision
+ *
 /* Revision 1.2  1999/08/17 19:04:18  evaleev
 /* Changed the default symmetric orthogonalization to the canonical
 /* orthogonalization. Now, if near-linear dependencies in the basis are found,
@@ -16,7 +16,7 @@
 /* -Ed
  */
 
-static char *rcsid = "$Id: sdot.c,v 1.1.1.1 2000/02/04 22:52:32 evaleev Exp $";
+static char *rcsid = "$Id: sdot.c 2 2000-02-04 22:50:39Z evaleev $";
 
 #define EXTERN
 #include "includes.h"
