@@ -3,10 +3,11 @@
 #define _psi3_dboc_linalg_h_
 
 #include "float.h"
-#include <stdio.h>
+#include <cstdio>
 
 FLOAT** create_matrix(int a, int b);
 void delete_matrix(FLOAT** M);
+void delete_matrix(FLOAT** M, int nrow, int ncol);
 FLOAT** convert_matrix(double **M, int a, int b, int transpose);
 void print_mat(FLOAT** a, int m, int n, FILE* out);
 int matrix_mult(FLOAT** A, int arow, int acol, FLOAT** B, int brow, int bcol, FLOAT** C);
