@@ -4,7 +4,7 @@
 ** DETERMINANT CI Program, incorporating Abelian point-group symmetry
 **
 ** C. David Sherrill
-** Center for Computational Quantum Chemistry, 
+** Center for Computational Quantum Chemistry 
 ** University of Georgia
 ** August 1994
 **
@@ -35,6 +35,7 @@ extern "C" {
    #include <libchkpt/chkpt.h>
    #include <libpsio/psio.h>
    #include <libqt/slaterdset.h>
+   #include <masses.h>
    #include "structs.h"
    #include "globals.h"
    #include "ci_tol.h"
@@ -124,14 +125,15 @@ extern void sem_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
 extern void mpn_generator(CIvect &Hd, struct stringwr **alplist, 
           struct stringwr **betlist);
 extern void opdm(struct stringwr **alplist, struct stringwr **betlist, 
+          int transdens, int dipmom,
           int Inroots, int Iroot, int Inunits, int Ifirstunit,
           int Jnroots, int Jroot, int Jnunits, int Jfirstunit,
           int targetfile, int writeflag, int printflag);
 extern void tpdm(struct stringwr **alplist, struct stringwr **betlist, 
-          int Inroots, int Iroot, int Inunits, int Ifirstunit,
-          int Jnroots, int Jroot, int Jnunits, int Jfirstunit,
+          int Inroots, int Inunits, int Ifirstunit,
+          int Jnroots, int Jnunits, int Jfirstunit,
           int targetfile, int writeflag, int printflag);
-
+extern void calc_mrpt(void);
 
 main(int argc, char *argv[])
 {
@@ -144,25 +146,10 @@ main(int argc, char *argv[])
    get_parameters();            /* get running params (convergence, etc)    */
    init_ioff();                 /* set up the ioff array                    */
    title();                     /* print program identification             */
-
-   if (Parameters.print_lvl) {
-      print_parameters();       /* print running parameters                 */
-      }
-
    get_mo_info();               /* read DOCC, SOCC, frozen, nmo, etc        */
-
-   if (Parameters.fci) {
-      int num_electrons = 0;
-      for (i=0; i<CalcInfo.nirreps; i++) {
-         num_electrons += 2 * CalcInfo.docc[i];
-         num_electrons += CalcInfo.socc[i];
-         num_electrons -= 2 * CalcInfo.frozen_docc[i];
-         }
-      if (num_electrons != Parameters.ex_lvl) {
-         Parameters.ex_lvl = num_electrons;
-         fprintf(outfile, "\nEX_LVL was incorrect for full CI changed to %d\n\n", num_electrons);
-         }
-      }
+   
+   if (Parameters.print_lvl)
+     print_parameters();       /* print running parameters                 */
 
    set_ras_parms();             /* set fermi levels and the like            */ 
    fflush(outfile); 
@@ -174,9 +161,9 @@ main(int argc, char *argv[])
    fflush(outfile); 
 
    if (Parameters.istop) {      /* Print size of space, other stuff, only   */
-      close_io();
-      return(0);
-      }
+     close_io();
+     return(0);
+   }
 
    
    read_integrals();            /* get the 1 and 2 elec MO integrals        */
@@ -184,9 +171,12 @@ main(int argc, char *argv[])
    if (Parameters.genci) 
      diag_h_genci(alplist, betlist);
 
+   /*
+   else if (Parameters.mrpt)
+     calc_mrpt();
+   */
 
    else {
-
      if (Parameters.bendazzoli) /* form the Bendazzoli OV arrays            */
         form_ov(alplist);
                                 /* lump together one-electron contributions */
@@ -202,9 +192,9 @@ main(int argc, char *argv[])
      diag_h(alplist, betlist);
    }
 
-   if (Parameters.print_lvl) print_time_new(detci_time);
-   if (Parameters.opdm) form_opdm();
+   if (Parameters.opdm || Parameters.transdens) form_opdm();
    if (Parameters.tpdm) form_tpdm();
+   if (Parameters.print_lvl) print_time_new(detci_time);
    if (Parameters.pthreads) tpool_destroy(thread_pool, 1);
    if (Parameters.print_lvl > 0) quote();
    close_io();
@@ -343,6 +333,7 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
    double conv_rms, conv_e, *evals, **evecs, nucrep, efzc, tval;
    int *tptr;
    double *cbuf;
+   char e_label[PSIO_KEYLEN]; /* 80... */
 
    nroots = Parameters.num_roots;
 
@@ -502,14 +493,16 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
 	unsigned char *newocc;
 
 	if (CalcInfo.num_fzc_orbs > 0) {
-	  fzc_occ = (short int *) malloc(CalcInfo.num_fzc_orbs*sizeof(short int));
+	  fzc_occ = (short int *) 
+            malloc(CalcInfo.num_fzc_orbs*sizeof(short int));
 	  for (int l=0; l<CalcInfo.num_fzc_orbs; l++) {
 	    fzc_occ[l] = CalcInfo.order[l]; /* put it in Pitzer order */
 	  }
 	}
 
-	newocc = (unsigned char *) malloc(((AlphaG->num_el > BetaG->num_el) ? 
-					   AlphaG->num_el : BetaG->num_el)*sizeof(unsigned char));
+	newocc = (unsigned char *) 
+          malloc(((AlphaG->num_el > BetaG->num_el) ?  
+            AlphaG->num_el : BetaG->num_el)*sizeof(unsigned char));
 
         stringset_init(&alphastrings,AlphaG->num_str,AlphaG->num_el,
                        CalcInfo.num_fzc_orbs, fzc_occ);
@@ -730,7 +723,7 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
                exit(1);
                }
             tval = sm_evecs[l][i];
-            if (Parameters.S%2) tval = -tval;
+            if ((int) Parameters.S%2) tval = -tval;
             if (sm_evecs[j][i] - tval > 1.0E-12) tmpi=1;
             }
          if (tmpi) continue;
@@ -959,6 +952,20 @@ void diag_h(struct stringwr **alplist, struct stringwr **betlist)
    /* write the CI energy to PSIF_CHKPT: later fix this to loop over roots */
    chkpt_init(PSIO_OPEN_OLD);
    chkpt_wt_etot(evals[Parameters.root]+efzc+nucrep);
+
+   for (i=0; i<nroots; i++) {
+     sprintf(e_label,"Root %2d energy",i);
+     chkpt_wt_e_labeled(e_label, evals[i]+efzc+nucrep);
+   }
+
+   if (Parameters.average_num > 1) {
+     tval = 0.0;
+     for (i=0; i<Parameters.average_num; i++)
+       tval += Parameters.average_weights[i] * 
+               (efzc+nucrep+evals[Parameters.average_states[i]]);
+     chkpt_wt_e_labeled("State averaged energy",tval);
+   }
+ 
    chkpt_close();
 
 }
@@ -1050,21 +1057,62 @@ void H0block_fill(struct stringwr **alplist, struct stringwr **betlist)
 
 void form_opdm(void)
 {
+  int i, j, natom;
+  double *zvals, **geom;
 
-   /* don't need Parameters.root since it writes all opdm's */
-   opdm(alplist, betlist, Parameters.num_roots, 0,
+  if (Parameters.dipmom) {
+    chkpt_init(PSIO_OPEN_OLD);
+    natom = chkpt_rd_natom();
+    zvals = chkpt_rd_zvals();
+    geom = chkpt_rd_geom();
+    chkpt_close();
+
+    fprintf(outfile, "   Cartesian Coordinates of Nuclear Centers (a.u.)\n\n");
+    fprintf(outfile,
+       "   Center           X                   Y                    Z\n");
+    fprintf(outfile,
+       "   ------   -----------------   -----------------   -----------------\n");
+
+    for(i=0;i<natom;i++){
+      fprintf(outfile,"   %4s ",atomic_labels[(int) zvals[i]]); 
+      for(j=0;j<3;j++)
+        fprintf(outfile,"   %17.12lf",geom[i][j]);
+      fprintf(outfile,"\n");
+    }
+    fprintf(outfile,"\n");
+    fflush(outfile);
+
+    free(zvals);
+    free_block(geom);
+  }
+
+  /* don't need Parameters.root since it writes all opdm's */
+  if (Parameters.transdens) {
+    opdm(alplist, betlist, 1, Parameters.dipmom,
+      Parameters.num_roots, 0,
+      Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
+      Parameters.num_roots, 0,
+      Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
+      Parameters.opdm_file, Parameters.tdm_write, Parameters.tdm_print);
+  }
+  if (Parameters.opdm) {
+    opdm(alplist, betlist, 0, Parameters.dipmom,
+      Parameters.num_roots, 0,
       Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
       Parameters.num_roots, 0,
       Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
       Parameters.opdm_file, Parameters.opdm_write, Parameters.opdm_print);
+  }
+
 }
 
 
 void form_tpdm(void)
 {
-  tpdm(alplist, betlist, Parameters.num_roots, Parameters.root, 
+  tpdm(alplist, betlist, 
+       Parameters.num_roots,
        Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
-       Parameters.num_roots, Parameters.root,
+       Parameters.num_roots,
        Parameters.num_d_tmp_units, Parameters.first_d_tmp_unit, 
        Parameters.tpdm_file, Parameters.tpdm_write, Parameters.tpdm_print);
 }
