@@ -35,7 +35,67 @@ void get_parameters(void)
    int i, errcod;
    int iopen=0, tval;
    char line1[133];
+   double junk;
    
+   if (ip_exist(":DETCI:FROZEN_DOCC",0) &&
+      !(ip_exist(":DEFAULT:FROZEN_DOCC",0) || 
+        ip_exist(":PSI:FROZEN_DOCC",0)) ) {
+     fprintf(outfile, "\nDETCI: Error - FROZEN_DOCC needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+     exit(PSI_RETURN_FAILURE);
+   }
+
+   if (ip_exist(":DETCI:FROZEN_UOCC",0) &&
+      !(ip_exist(":DEFAULT:FROZEN_UOCC",0) || 
+        ip_exist(":PSI:FROZEN_UOCC",0)) ) {
+     fprintf(outfile, "\nDETCI: Error - FROZEN_UOCC needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+     exit(PSI_RETURN_FAILURE);
+   }
+
+   if (ip_exist(":DETCI:RAS1",0) &&
+      !(ip_exist(":DEFAULT:RAS1",0) || 
+        ip_exist(":PSI:RAS1",0)) ) {
+     fprintf(outfile, "\nDETCI: Warning - RAS1 needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+   }
+
+   if (ip_exist(":DETCI:RAS2",0) &&
+      !(ip_exist(":DEFAULT:RAS2",0) || 
+        ip_exist(":PSI:RAS2",0)) ) {
+     fprintf(outfile, "\nDETCI: Warning - RAS2 needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+   }
+
+   if (ip_exist(":DETCI:RAS3",0) &&
+      !(ip_exist(":DEFAULT:RAS3",0) || 
+        ip_exist(":PSI:RAS3",0)) ) {
+     fprintf(outfile, "\nDETCI: Warning - RAS3 needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+   }
+
+   if (ip_exist(":DETCI:RESTRICTED_DOCC",0) &&
+      !(ip_exist(":DEFAULT:RESTRICTED_DOCC",0) || 
+        ip_exist(":PSI:RESTRICTED_DOCC",0)) ) {
+     fprintf(outfile,"\nDETCI: Warning-RESTRICTED_DOCC needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+   }
+
+   if (ip_exist(":DETCI:RESTRICTED_UOCC",0) &&
+      !(ip_exist(":DEFAULT:RESTRICTED_UOCC",0) || 
+        ip_exist(":PSI:RESTRICTED_UOCC",0)) ) {
+     fprintf(outfile,"\nDETCI: Warning-RESTRICTED_UOCC needs to be readable\n");
+     fprintf(outfile, "by the transformation program also!  Move it to\n");
+     fprintf(outfile, "the psi: or default: sections of input.\n\n");
+   }
+
+
    /* default value of Ms0 depends on iopen but is modified below 
     * depending on value of opentype
     */
@@ -58,7 +118,9 @@ void get_parameters(void)
    }
 
   if (strcmp(Parameters.dertype, "FIRST")==0 ||
-      strcmp(Parameters.wfn, "DETCAS")==0) Parameters.filter_ints = 1;
+      strcmp(Parameters.wfn, "DETCAS")==0    ||
+      strcmp(Parameters.wfn, "CASSCF")==0    ||
+      strcmp(Parameters.wfn, "RASSCF")==0) Parameters.filter_ints = 1;
   else Parameters.filter_ints = 0;
 
  
@@ -71,7 +133,6 @@ void get_parameters(void)
    Parameters.num_roots = 1;
    Parameters.istop = 0;
    Parameters.print_ciblks = 0;
-   Parameters.S = 0;
    Parameters.opentype = PARM_OPENTYPE_UNKNOWN;
    Parameters.ref_sym = -1;
    Parameters.oei_file = PSIF_OEI;  /* always need fzc operator */
@@ -87,7 +148,10 @@ void get_parameters(void)
    Parameters.hd_otf = TRUE;
    Parameters.nodfile = 0;
    Parameters.fzc = 1;
-   Parameters.fci = 0;
+   if (strcmp(Parameters.wfn, "CASSCF")==0)
+     Parameters.fci = 1;
+   else
+     Parameters.fci = 0;
    Parameters.fci_strings = 0;
    Parameters.mixed = 1;
    Parameters.mixed4 = 1;
@@ -115,7 +179,9 @@ void get_parameters(void)
    Parameters.ras4_max = -1;
    Parameters.ras34_max = -1;
 
-   if (strcmp(Parameters.wfn, "DETCAS")==0)
+   if (strcmp(Parameters.wfn, "DETCAS")==0 ||
+       strcmp(Parameters.wfn, "CASSCF")==0 ||
+       strcmp(Parameters.wfn, "RASSCF")==0)
      Parameters.guess_vector = PARM_GUESS_VEC_DFILE;
    else
      Parameters.guess_vector = PARM_GUESS_VEC_H0_BLOCK;
@@ -150,7 +216,10 @@ void get_parameters(void)
    Parameters.bendazzoli = 0;
 
    if (strcmp(Parameters.dertype, "FIRST")==0 ||
-      strcmp(Parameters.wfn, "DETCAS")==0) {
+      strcmp(Parameters.wfn, "DETCAS")==0 ||
+      strcmp(Parameters.wfn, "CASSCF")==0 ||
+      strcmp(Parameters.wfn, "RASSCF")==0)
+   {
      Parameters.convergence = 7;
      Parameters.energy_convergence = 8;
      Parameters.opdm = 1;
@@ -183,6 +252,14 @@ void get_parameters(void)
    Parameters.nthreads = 1;
    Parameters.pthreads = 0;
    Parameters.sf_restrict = 0;
+   Parameters.print_sigma_overlap = 0;
+
+   tval = 1;
+   if (ip_exist("MULTP",0)) {
+     errcod = ip_data("MULTP","%d",&tval,0);
+   }
+   Parameters.S = (((double) tval) - 1.0) / 2.0;
+   errcod = ip_data("S","%lf",&(Parameters.S),0);
 
    errcod = ip_data("EX_LVL","%d",&(Parameters.ex_lvl),0);
    errcod = ip_data("VAL_EX_LVL","%d",&(Parameters.val_ex_lvl),0);
@@ -195,9 +272,8 @@ void get_parameters(void)
    errcod = ip_data("CONVERGENCE","%d",&(Parameters.convergence),0);
    errcod = ip_data("ENERGY_CONVERGENCE","%d",
                &(Parameters.energy_convergence),0);
-   errcod = ip_data("S","%d",&(Parameters.S),0);
 
-   /* this stuff was appropriate to the OPENTYPE keyword in PSI2 */
+   /* this handles backwards compatibility for PSI2 */
    errcod = ip_data("OPENTYPE","%s",line1,0);
    if (errcod == IPE_OK) {
       if (strcmp(line1, "NONE")==0) { 
@@ -214,7 +290,7 @@ void get_parameters(void)
          }
       else Parameters.opentype = PARM_OPENTYPE_UNKNOWN;
       } 
-   else { /* no opentype keyword, as appropriate for PSI3 */
+   else { /* this handles new PSI3 keywords */
      errcod = ip_data("REFERENCE","%s",line1,0);
      /* fprintf(outfile, "line1 = "); 
      for (int ij = 0; ij<3; ij++) fprintf(outfile, "%1c", line1[ij]); 
@@ -456,12 +532,14 @@ void get_parameters(void)
      Parameters.num_d_tmp_units = 1;
 
    errcod = ip_boolean("RESTART",&(Parameters.restart),0);
+ /* obsolete due to new restart procedure
    errcod = ip_data("RESTART_ITER","%d",&(Parameters.restart_iter),0);
    errcod = ip_data("RESTART_VECS","%d",&(Parameters.restart_vecs),0);
    if (Parameters.restart && (errcod!=IPE_OK || Parameters.restart_vecs==0)) {
       fprintf(outfile, "For RESTART must specify nonzero RESTART_VECS\n");
       exit(0);
       }
+ */ 
    errcod = ip_boolean("BENDAZZOLI",&(Parameters.bendazzoli),0) ;
    if (Parameters.bendazzoli & !Parameters.fci) Parameters.bendazzoli=0;
 
@@ -477,8 +555,6 @@ void get_parameters(void)
    errcod = ip_data("ORBSFILE","%d",&(Parameters.opdm_orbsfile),0);
    errcod = ip_data("ORBS_ROOT","%d",&(Parameters.opdm_orbs_root),0);
    errcod = ip_boolean("OPDM_KE",&(Parameters.opdm_ke),0);
-   errcod = ip_data("ROOT","%d",&(Parameters.root),0);
-   Parameters.root -= 1;
    
    if (Parameters.opdm_orbs_root != -1) Parameters.opdm_orbs_root -= 1;
    if (Parameters.opdm_orbs_root < 0) Parameters.opdm_orbs_root = 0;
@@ -491,6 +567,34 @@ void get_parameters(void)
    errcod = ip_boolean("OPDM_PRINT",&(Parameters.opdm_print),0);
    errcod = ip_data("OPDM_DIAG","%d",&(Parameters.opdm_diag),0);
 
+   /* transition density matrices */
+   Parameters.tdm_print = 0; Parameters.tdm_write = 0;
+   Parameters.transdens = 0;
+   errcod = ip_boolean("TDM_PRINT",&(Parameters.tdm_print),0);
+   errcod = ip_boolean("TDM_WRITE",&(Parameters.tdm_write),0);
+   if (Parameters.tdm_print || Parameters.tdm_write || 
+       (Parameters.num_roots > 1))
+     Parameters.transdens = 1;
+   else 
+     Parameters.transdens = 0;
+   errcod = ip_boolean("TRANSITION_DENSITY",&(Parameters.transdens),0);
+   if (Parameters.transdens) Parameters.tdm_write = 1;
+   errcod = ip_boolean("TDM_WRITE",&(Parameters.tdm_write),0);
+  
+   /* dipole or transition dipole moment? */
+   if (Parameters.opdm) Parameters.dipmom = 1;
+   else Parameters.dipmom = 0;
+   if (strcmp(Parameters.wfn, "RASSCF")==0 || 
+       strcmp(Parameters.wfn, "CASSCF")==0 ||
+       strcmp(Parameters.wfn, "DETCAS")==0)
+   Parameters.dipmom = 0;
+   if (Parameters.transdens) Parameters.dipmom = 1;
+   errcod = ip_boolean("DIPMOM",&(Parameters.dipmom),0);
+   if (Parameters.dipmom == 1) Parameters.opdm = 1; 
+ 
+   errcod = ip_data("ROOT","%d",&(Parameters.root),0);
+   Parameters.root -= 1;
+
    errcod = ip_boolean("TPDM",&(Parameters.tpdm),0);
    if (Parameters.tpdm) Parameters.tpdm_write = 1;
    errcod = ip_boolean("TPDM_WRITE",&(Parameters.tpdm_write),0);
@@ -498,7 +602,10 @@ void get_parameters(void)
    errcod = ip_data("TPDM_FILE","%d",&(Parameters.tpdm_file),0);
 
    if (Parameters.guess_vector == PARM_GUESS_VEC_DFILE &&
-       strcmp(Parameters.wfn, "DETCAS")!=0) {
+       strcmp(Parameters.wfn, "DETCAS")!=0 &&
+       strcmp(Parameters.wfn, "CASSCF")!=0 &&
+       strcmp(Parameters.wfn, "RASSCF")!=0)
+     {
 
       chkpt_init(PSIO_OPEN_OLD);
       i = chkpt_rd_phase_check();
@@ -545,6 +652,25 @@ void get_parameters(void)
    } 
    
    errcod = ip_boolean("SF_RESTRICT",&(Parameters.sf_restrict),0);
+   errcod = ip_boolean("SIGMA_OVERLAP",&(Parameters.print_sigma_overlap),0);
+
+   Parameters.ex_type = (int *)malloc(Parameters.ex_lvl*sizeof(int));
+   if (ip_exist("EX_TYPE",0)) {
+     ip_count("EX_TYPE", &i, 0);
+     if (i != Parameters.ex_lvl) {
+       fprintf(outfile,"Dim. of excitation type must be %d\n", 
+               Parameters.ex_lvl);
+       exit(0);
+     }
+     for (i=0;i<Parameters.ex_lvl;i++) {
+       errcod = ip_data("EX_TYPE","%d",&(Parameters.ex_type[i]),1,i);
+     }
+   }
+   else {
+     for (i=0;i<Parameters.ex_lvl;i++) {
+       Parameters.ex_type[i] = 1;
+     }
+   }
 
    /* The filter_guess options are used to filter out some trial
       vectors which may not have the appropriate phase convention
@@ -592,6 +718,132 @@ void get_parameters(void)
                         &(Parameters.filter_guess_Jb),1,1);
      }
    } /* end the filter_guess stuff */
+
+   /* sometimes the filter guess stuff is not sufficient in that
+      some states come in that we don't want.  We can help exclude
+      them by explicitly zeroing out certain determinants, if that
+      is correct for the desired state.  This stuff will allow the
+      user to select a determinant which should always have a zero
+      coefficient in the desired target state
+    */
+   Parameters.zero_det = 0;
+   if (ip_exist("ZERO_DET",0)) {
+     errcod = ip_count("ZERO_DET",&i,0); 
+     if (errcod != IPE_OK || i != 2) {
+       fprintf(outfile, "Need to specify ZERO_DET = "
+                        "(alphastr betastr)\n");
+       abort();
+     }
+     Parameters.zero_det = 1;
+     errcod = ip_data("ZERO_DET","%d",
+                      &(Parameters.zero_det_Ia),1,0);
+     errcod = ip_data("ZERO_DET","%d",
+                      &(Parameters.zero_det_Ib),1,1);
+   }
+
+   /* Does the user request a state-averaged calculation? */
+   if (ip_exist("AVERAGE_STATES",0)) {
+     ip_count("AVERAGE_STATES", &i, 0);
+     if (i < 1 || i > Parameters.num_roots) {
+       fprintf(outfile,"Invalid number of states to average (%d)\n", i);
+       exit(1);
+     }
+     Parameters.average_states = init_int_array(i);
+     Parameters.average_weights = init_array(i);
+     Parameters.average_num = i;
+     for (i=0;i<Parameters.average_num;i++) {
+       errcod = ip_data("AVERAGE_STATES","%d",
+         &(Parameters.average_states[i]),1,i);
+       if (Parameters.average_states[i] < 1) {
+         fprintf(outfile,"AVERAGE_STATES start numbering from 1.\n");
+         fprintf(outfile,"Invalid state number %d\n", 
+           Parameters.average_states[i]);
+         exit(1);
+       }
+       Parameters.average_states[i] -= 1; /* number from 1 externally */
+       Parameters.average_weights[i] = 1.0/((double)Parameters.average_num);
+     }
+     if (ip_exist("AVERAGE_WEIGHTS",0)) {
+       ip_count("AVERAGE_WEIGHTS", &i, 0);
+       if (i != Parameters.average_num) {
+         fprintf(outfile,"Mismatched number of average weights (%d)\n", i);
+         exit(0);
+       }
+       for (i=0; i<Parameters.average_num; i++) {
+         errcod = ip_data("AVERAGE_WEIGHTS","%lf", 
+           &(Parameters.average_weights[i]),1,i);
+       }
+     }
+      
+   if (Parameters.average_num > 1) Parameters.opdm_ave = 1;
+
+     if ((!ip_exist("ROOT",0)) && (Parameters.average_num==1)) {
+       Parameters.root = Parameters.average_states[0];
+     }
+   }
+
+   else {
+     Parameters.average_num = 1;
+     Parameters.average_states = init_int_array(1);
+     Parameters.average_weights = init_array(1);
+     Parameters.average_states[0] = Parameters.root;
+     Parameters.average_weights[0] = 1.0;
+   } /* end state-average parsing */
+
+   /* Follow a vector to determine the root number? */
+   Parameters.follow_vec_num = 0;
+   if (ip_exist("FOLLOW_VECTOR",0)) {
+     errcod = ip_count("FOLLOW_VECTOR",&i,0); 
+     if (errcod != IPE_OK || (i % 2)!=0) {
+       fprintf(outfile, "Need to specify FOLLOW_VECTOR = "
+                        "((alphastr_i betastr_i) coeff_i ... )\n");
+       abort();
+     }
+     i = i/2;
+     Parameters.follow_vec_num = i;     
+     Parameters.follow_vec_coef   = init_array(i);
+     Parameters.follow_vec_Ia     = init_int_array(i);
+     Parameters.follow_vec_Ib     = init_int_array(i);
+     Parameters.follow_vec_Iac    = init_int_array(i);
+     Parameters.follow_vec_Ibc    = init_int_array(i);
+     Parameters.follow_vec_Iaridx = init_int_array(i);
+     Parameters.follow_vec_Ibridx = init_int_array(i);
+
+     /* now parse each piece */
+     for (i=0; i<Parameters.follow_vec_num; i++) {
+       errcod = ip_data("FOLLOW_VECTOR","%d",
+                        Parameters.follow_vec_Ia+i,2,i*2,0);
+       if (errcod != IPE_OK) {
+         fprintf(outfile, "Trouble parsing FOLLOW_VECTOR\n");
+         abort();
+       }
+       errcod = ip_data("FOLLOW_VECTOR","%d",
+                        Parameters.follow_vec_Ib+i,2,i*2,1);
+       if (errcod != IPE_OK) {
+         fprintf(outfile, "Trouble parsing FOLLOW_VECTOR\n");
+         abort();
+       }
+       errcod = ip_data("FOLLOW_VECTOR","%lf",
+                        Parameters.follow_vec_coef+i,1,i*2+1);
+       if (errcod != IPE_OK) {
+         fprintf(outfile, "Trouble parsing FOLLOW_VECTOR\n");
+         abort();
+       }
+     } /* end loop over parsing */
+   } /* end follow vector stuff */
+
+   /* make sure SA weights add up to 1.0 */
+   for (i=0,junk=0.0; i<Parameters.average_num; i++) {
+     junk += Parameters.average_weights[i]; 
+   }
+   if (junk <= 0.0) {
+     fprintf(outfile, "Error: AVERAGE WEIGHTS add up to %12.6lf\n", junk);
+     exit(0);
+   }
+   for (i=0; i<Parameters.average_num; i++) {
+     Parameters.average_weights[i] /= junk; 
+   }
+   
 }
 
 
@@ -601,6 +853,8 @@ void get_parameters(void)
 */
 void print_parameters(void)
 {
+   int i;
+
    fprintf(outfile, "\n");
    fprintf(outfile, "PARAMETERS: \n");
    fprintf(outfile, "   EX LVL        =   %6d      H0 BLOCKSIZE =   %6d\n", 
@@ -696,7 +950,7 @@ void print_parameters(void)
        break;
       }
 
-   fprintf(outfile, "   S             =   %6d      Ms0          =   %6s\n",
+   fprintf(outfile, "   S             =   %6lf     Ms0          =   %6s\n",
       Parameters.S, Parameters.Ms0 ? "yes" : "no");           
    fprintf(outfile, "   TEI ERASE     =   %6s      MAXNVECT     =   %6d\n", 
       Parameters.tei_erase ? "yes" : "no", Parameters.maxnvect);
@@ -782,11 +1036,33 @@ void print_parameters(void)
    fprintf(outfile, "   FILTER_GUESS  =   %6s      SF_RESTRICT  =   %6s\n",
            Parameters.filter_guess ?  "yes":"no",
 	   Parameters.sf_restrict ? "yes":"no");
-   fprintf(outfile, "\n   FILES         =     %3d %3d %3d %3d\n",
+   fprintf(outfile, "   OPDM          =   %6s      TRANS DENSITY=   %6s\n",
+           Parameters.opdm ?  "yes":"no",
+	   Parameters.transdens ? "yes":"no");
+   fprintf(outfile, "\n   FILES         = %3d %2d %2d %2d\n",
       Parameters.first_hd_tmp_unit, Parameters.first_c_tmp_unit,
       Parameters.first_s_tmp_unit, Parameters.first_d_tmp_unit);
+   
+   fprintf(outfile, "\n   EX_TYPE       = ");
+   for (i=0;i<Parameters.ex_lvl;i++) {
+     fprintf(outfile, "%2d ", Parameters.ex_type[i]);
+   }
 
-   fprintf(outfile, "\n") ;
+   fprintf(outfile, "\n   STATE AVERAGE = ");
+   for (i=0; i<Parameters.average_num; i++) {
+     if (i%5==0 && i!=0) fprintf(outfile, "\n");
+     fprintf(outfile, "%2d(%4.2lf) ",Parameters.average_states[i]+1,
+       Parameters.average_weights[i]);
+   }
+
+   if (Parameters.follow_vec_num > 0) {
+     fprintf(outfile,"\nDensity matrices will follow vector like:\n");
+     for (i=0; i<Parameters.follow_vec_num; i++) 
+       fprintf(outfile, "(%d %d) %12.6lf\n", Parameters.follow_vec_Ia[i],
+         Parameters.follow_vec_Ib[i], Parameters.follow_vec_coef[i]);
+   }
+
+   fprintf(outfile, "\n\n") ;
    fflush(outfile) ;
 }
 
@@ -804,6 +1080,27 @@ void set_ras_parms(void)
    int *ras1, *ras2, *ras3;
    int *orbsym;
 
+   /* If the user asked for FCI=true, then override the other keywords
+      if necessary to ensure that it's really a FCI
+    */
+   if (Parameters.fci == 1 && 
+       (CalcInfo.num_alp_expl + CalcInfo.num_bet_expl) > Parameters.ex_lvl) 
+   {
+     Parameters.val_ex_lvl = 0;
+     Parameters.ex_lvl = CalcInfo.num_alp_expl + CalcInfo.num_bet_expl;
+     free(Parameters.ex_type);
+     Parameters.ex_type = init_int_array(Parameters.ex_lvl);
+     for (i=0; i<Parameters.ex_lvl; i++) Parameters.ex_type[i] = 1;
+
+     if (Parameters.print_lvl) {
+       fprintf(outfile, "Note: Calculation requested is a full CI.\n");
+       fprintf(outfile, 
+               "Resetting EX_LVL to %d and turning on all excitations\n\n",
+               Parameters.ex_lvl);
+     }
+
+   } /* end FCI override */
+
    for (i=0,j=0; i<CalcInfo.nirreps; i++) j += CalcInfo.ras_opi[0][i];
    Parameters.a_ras1_lvl = Parameters.b_ras1_lvl = Parameters.ras1_lvl = j-1;
 
@@ -968,7 +1265,18 @@ void set_ras_parms(void)
    i = 2 * (CalcInfo.num_ci_orbs - Parameters.ras4_lvl);
    if (i < Parameters.ras4_max) Parameters.ras4_max = i;
 
-   if (Parameters.print_lvl) {
+   if (Parameters.print_lvl > 0) {
+      fprintf(outfile, "ORBITALS:\n") ;
+      fprintf(outfile, "   NMO          =   %6d      NUM ALP      =   %6d\n",
+         CalcInfo.nmo, CalcInfo.num_alp);
+      fprintf(outfile, "   ORBS IN CI   =   %6d      NUM ALP EXPL =   %6d\n",
+         CalcInfo.num_ci_orbs, CalcInfo.num_alp_expl);
+      fprintf(outfile, "   FROZEN CORE  =   %6d      NUM BET      =   %6d\n",
+         CalcInfo.num_fzc_orbs, CalcInfo.num_bet);
+      fprintf(outfile, "   RESTR CORE   =   %6d      NUM BET EXPL =   %6d\n",
+         CalcInfo.num_cor_orbs, CalcInfo.num_bet_expl);
+      fprintf(outfile, "   IOPEN        =   %6s\n", CalcInfo.iopen ? "yes" :
+         "no");
       fprintf(outfile, "   RAS1 LVL     =   %6d      A RAS3 MAX   =   %6d\n",
          Parameters.ras1_lvl, Parameters.a_ras3_max);
       fprintf(outfile, "   RAS1 MIN     =   %6d      B RAS3 MAX   =   %6d\n",
@@ -988,7 +1296,6 @@ void set_ras_parms(void)
       fprintf(outfile, "   RAS3 LVL     =   %6d      RAS34 MAX    =   %6d\n", 
          Parameters.ras3_lvl, Parameters.ras34_max);
       fprintf(outfile, "   RAS3 MAX     =   %6d\n", Parameters.ras3_max);
-
    
       fprintf(outfile, "\n");
       fprintf(outfile, "   DOCC         = ") ;
