@@ -15,6 +15,8 @@
 
 /*** DEFINES ***/
 
+typedef unsigned long long int BIGINT; /* should be 64bits even on 32bit arch */
+
 #define CI_BLK_MAX 650
 #define IOFF_MAX 50604
 
@@ -228,7 +230,6 @@ struct H_zero_block {
 */
 struct calcinfo {
    int natom;            /* number of atoms */
-   int natom3;           /* number of atoms * 3 (to save calculations) */
    int nso;              /* number of symmetry orbitals */
    int nmo;              /* number of molecular orbitals */
    int nmotri;           /* num elements in lwr diag matrix nmo big */
@@ -236,6 +237,8 @@ struct calcinfo {
    int *docc;            /* doubly occupied orbitals per irrep */
    int *socc;            /* singly occupied orbitals per irrep */
    int *frozen_docc;     /* frozen doubly occupied orbs per irrep */
+   int *rstr_docc;       /* restricted core orbitals per irrep */
+   int *rstr_uocc;       /* restricted virtual orbitals per irrep */
    int *frozen_uocc;     /* frozen virtual orbs per irrep */
    int iopen;            /* flag for whether open shell or not */
    double enuc;          /* nuclear repulsion energy */
@@ -267,6 +270,7 @@ struct calcinfo {
    int num_bet_str;      /* number of beta strings */
    int num_ci_orbs;      /* nmo - num orbs frozen */
    int num_fzv_orbs;     /* number of frozen/deleted virtual orbitals */
+   int num_vir_orbs;     /* number of restricted virtual orbitals */
    int ref_alp;          /* address of reference alpha string */
    int ref_bet;          /* address of reference beta string */
    int ref_alp_list;     /* string list containing reference alpha string */
@@ -314,7 +318,7 @@ struct params {
    int fci_strings;  /* do a FULL ci calc?  (affects string storage) */
    int fzc;          /* do implicit frozen core (remove those orbs)? */
                      /* the alternative is a "restricted core" calc  */
-   int S;            /* the value of quantum number S */
+   double S;         /* the value of quantum number S */
    int Ms0;          /* 1 if Ms=0, 0 otherwise */
    int ref_sym;      /* irrep for CI vectors;  -1 = find automatically */
    int opentype;     /* closed, highspin, or open-shell singlet; see #define */
@@ -417,6 +421,10 @@ struct params {
                               roots and irreps of opdm in opdmfile */ 
    int **orbs_idxmat;      /* matrix of index values for various
                               roots and irreps of orbitals in orbsfile */ 
+   int transdens;          /* compute transition densities? */
+   int dipmom;             /* compute dipole moment or transition dip mom?  */
+   int tdm_write;          /* write the transition density matrix/matrices? */
+   int tdm_print;          /* print the transition density matrix/matrices? */
    int tpdm;               /* call the tpdm subroutine? */
    int tpdm_write;         /* write the tpdm? */
    int tpdm_print;         /* print the tpdm? */
@@ -437,6 +445,7 @@ struct params {
                               do only determinants (or their
                               spin-complements) in RASCI versions of
                               Krylov's SF CI */
+   int print_sigma_overlap;/* Print sigma overlap matrix?  Test for Arteum */
    int filter_guess;       /* 1 if we want to filter out some of our guess
                               vectors by checking the phase of a pair of
 			      determinants */
@@ -455,6 +464,26 @@ struct params {
    int filter_guess_Jbc;   /* string list number for beta of det 2 */
    int filter_guess_H0_det1; /* H0block determinant number for det 1 */
    int filter_guess_H0_det2; /* H0block determinant number for det 2 */
+   int zero_det;           /* zero out any particular determinant? */
+   int zero_det_Ia;        /* absolute alpha string addr for zero det */
+   int zero_det_Ib;        /* absolute beta  string addr for zero det */
+   int zero_det_Iac;       /* string list number for alpha of zero det */
+   int zero_det_Ibc;       /* string list number for beta of zero det */
+   int zero_det_Iaridx;    /* relative alpha string for zero det */
+   int zero_det_Ibridx;    /* relative beta string for zero det */
+   int follow_vec_num;     /* num components in user-specified vec to follow */
+   double *follow_vec_coef;/* array of coefficients for vec to follow */
+   int *follow_vec_Ia;     /* array of absolute alpha strings for vector */
+   int *follow_vec_Ib;     /* array of absolute beta  strings for vector */
+   int *follow_vec_Iac;    /* array of alpha string lists for vector */
+   int *follow_vec_Ibc;    /* array of beta  string lists for vector */
+   int *follow_vec_Iaridx; /* array of alpha relative idx for vector */
+   int *follow_vec_Ibridx; /* array of beta  relative idx for vector */
+   int *ex_type;           /* Determine nonstandard excitation types, such
+                                as CID, CIST, CIDTQ, etc. */
+   int *average_states;    /* which states to average in a SA calc */
+   double *average_weights;/* the weights for each state in a SA calc */
+   int average_num;        /* length of the above two arrays */
 };
 
 
@@ -467,13 +496,13 @@ struct params {
 ** beta) and determines the CI vector block number.
 */
 struct ci_blks {
-   unsigned long vectlen;     /* total number of elements in the CI vector */
+   BIGINT vectlen;            /* total number of elements in the CI vector */
    int num_blocks;            /* number of blocks in the CI vector */
    int Ia_code[CI_BLK_MAX];   /* gives the block's alpha string code */ 
    int Ib_code[CI_BLK_MAX];   /* gives the block's beta string code */ 
    int Ia_size[CI_BLK_MAX];   /* num of alp strings in the block */
    int Ib_size[CI_BLK_MAX];   /* num of bet strings in the block */
-   unsigned long offset[CI_BLK_MAX];  /* offset for absolute numbering */
+   BIGINT offset[CI_BLK_MAX];  /* offset for absolute numbering */
    int **decode;              /* gives the block number for a given pair
                                   of alpha and beta codes */
    int num_alp_codes;         /* number of alpha codes in decode matrix */
