@@ -156,25 +156,33 @@ main(argc, argv)
   for (i=1, num_unparsed=0; i<argc; i++) {
     if (strcmp("-g", argv[i]) == 0) {
       InputType = PSI_GEOM;
-      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) 
+      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) {
 	strcpy(geom_file, argv[i+1]) ;
+        i++;
+      }
     }
     else if (strcmp("-aces", argv[i]) == 0) {
       InputType = ACES2;
-      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) 
+      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) {
 	strcpy(geom_file, argv[i+1]) ;
+        i++;
+      }
     }
     else if (strcmp("-qchem", argv[i]) == 0) {
       InputType = QCHEM;
       ang_in = 1;  /* QCHEM format is in Angstrom */
-      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) 
+      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) {
 	strcpy(geom_file, argv[i+1]) ;
+        i++;
+      }
     }
     else if (strcmp("-xyz", argv[i]) == 0) {
       InputType = XYZ;
       ang_in = 1;  /* XYZ format is in Angstrom */
-      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) 
-	strcpy(geom_file, argv[i+1]) ;
+      if ( (i+1 < argc) && (strchr(argv[i+1], '-') == NULL) ) {
+	strcpy(geom_file, argv[i+1]);
+        i++;
+      }
     }
     else if (strcmp("-oop", argv[i]) == 0) do_oop = 1;
     else if (strcmp("-a", argv[i]) == 0) print_all_dist = 1;
@@ -473,7 +481,10 @@ void calc_mass_analysis(int natom, double *M, double *X, double *Y,
   center_of_mass(natom, M, X, Y, Z, CM) ;
   fprintf(fpo,"\nCenter of Mass Coords (bohr):\n   %12.7lf %12.7lf %12.7lf\n",
 	  CM[0], CM[1], CM[2]);
-  fflush(fpo) ;
+  fprintf(fpo,
+        "\nCenter of Mass Coords (angstroms):\n   %12.7lf %12.7lf %12.7lf\n",
+	  CM[0]*_bohr2angstroms, CM[1]*_bohr2angstroms, CM[2]*_bohr2angstroms);
+  fflush(fpo);
   
   /* translate the atomic coords rel to center of mass */
   calc_relative_coords(natom, X, Y, Z, &XR, &YR, &ZR, CM) ;
@@ -678,6 +689,17 @@ double dot_vect(double *a, double *b, int n)
   return(tval);     
 }
 
+/*
+   Function to compute the cross product of 2 Cartesian vectors
+*/
+
+void cross_prod(double *v1, double *v2, double *out)
+{
+   out[0] =     v1[1]*v2[2]-v1[2]*v2[1];
+   out[1] =    -v1[0]*v2[2]+v1[2]*v2[0];
+   out[2] =     v1[0]*v2[1]-v1[1]*v2[0];
+   return;
+}
 
 /*
 ** CALC_TORS_ANGLES(): This function calculates the torsional angles
@@ -696,9 +718,10 @@ void calc_tors_angles(int natom, double E[MAXATOM][MAXATOM][3],
 		      double BondAngles[MAXATOM][MAXATOM][MAXATOM], 
 		      double **R, FILE *fpo)
 {
-  int i, j, k, l ;
-  double cross1[3], cross2[3] ;
+  int i, j, k, l, xyz ;
+  double cross1[3], cross2[3], cross3[3] ;
   double tval, angle, phi2, phi3 ;
+  double sign, norm3;
   
   fprintf(fpo, "\nTorsional Angles:\n") ;
   for (i=0; i<natom; i++) {
@@ -721,10 +744,23 @@ void calc_tors_angles(int natom, double E[MAXATOM][MAXATOM][3],
 	    if (tval > 0.99999) angle = 0.0000 ;
 	    else if (tval < -0.99999) angle = _pi ;
 	    else angle = acos(tval) ;
+
+	    /* compute the sign */
+	    cross_prod(cross1, cross2, cross3);
+	    norm3 = sqrt(dot_vect(cross3,cross3,3));
+	    sign = 1.0;
+	    if (fabs(norm3) > 0.00001) {
+	      for(xyz=0; xyz<3; ++xyz)
+		cross3[xyz] *= 1.0/norm3;
+	      tval = dot_vect(cross3, E[j][k],3);
+	      if (tval < 0.0)
+		sign = -1.0;
+	    }
+
 	    if ( ((R[i][j] < print_dist) && (R[j][k] < print_dist) &&
 		  (R[k][l] < print_dist)) || print_all_dist) {
 	      fprintf(fpo, "%2d-%2d-%2d-%2d    %13.8lf\n",
-		      i+1, j+1, k+1, l+1, angle * 180.0/_pi) ;
+		      i+1, j+1, k+1, l+1, sign * angle * 180.0/_pi) ;
 	    }
 	  }
 	}
