@@ -19,6 +19,7 @@ void print_unique_geometry(double);
 void print_symm_trans();
 void print_basis_info();
 void cleanup();
+extern void build_cartdisp_salcs();
 
 int main(int argc, char *argv[])
 {
@@ -82,13 +83,6 @@ int main(int argc, char *argv[])
        free(user_basis_filename);
      }
 
-     local_basis = fopen("./basis.dat", "r");
-     if (local_basis != NULL) {
-       ip_append(local_basis, outfile);
-       fclose(local_basis);
-       if (print_lvl > 0) fprintf(outfile,"\n  Parsed basis sets from ./basis.dat\n");
-     }
-
      if (pbasis != NULL) {
        ip_append(pbasis, outfile);
        fclose(pbasis);
@@ -96,6 +90,13 @@ int main(int argc, char *argv[])
      }
      free(pbasis_filename);
 
+     local_basis = fopen("./basis.dat", "r");
+     if (local_basis != NULL) {
+       ip_append(local_basis, outfile);
+       fclose(local_basis);
+       if (print_lvl > 0) fprintf(outfile,"\n  Parsed basis sets from basis.dat\n");
+     }
+
      ip_cwk_add(":BASIS");
 
      /*-----------------
@@ -164,6 +165,7 @@ int main(int argc, char *argv[])
        build_cart2pureang();
      build_so_classes();
      build_usotao();
+     build_cartdisp_salcs();
 
      /*---------------------
        Read old calculation
