@@ -1,3 +1,7 @@
+#include <ccfiles.h>
+#include "moinfo.h"
+#include "params.h"
+
 #ifdef EXTERN
 #undef EXTERN
 #define EXTERN extern
@@ -12,3 +16,4 @@ EXTERN FILE *infile, *outfile;
 EXTERN char *psi_file_prefix;
 EXTERN struct moinfo mo;
 EXTERN struct params params;
+EXTERN int* ioff;
