@@ -143,6 +143,7 @@ void init_ioff(void);
 void get_parameters(void);
 void print_parameters(void);
 void get_moinfo(void);
+void semicanonical_fock(void);
 void get_one_electron_integrals(void);
 void transform_one(void);
 void transform_two(void);
@@ -166,11 +167,11 @@ main(int argc, char *argv[])
   params.print_lvl = 1;
   init_io(argc,argv);
   title();
+  init_ioff();
   get_parameters();
   print_parameters();
   get_moinfo();
   get_reorder_array();
-  init_ioff();
 
   get_one_electron_integrals();
 
@@ -346,7 +347,7 @@ void get_parameters(void)
     params.tei_trans_type = MAKE_OGOG;
     params.tei_type = R12T1;
     params.src_tei_file = PSIF_SO_R12T1;
-    params.mfile = PSIF_MO_R12T1;
+    params.mfile = PSIF_MO_R12T2;
     params.do_oei = 0;
   }
   else {
@@ -361,6 +362,15 @@ void get_parameters(void)
     params.ref = (char *) malloc(sizeof(char)*4);
     strcpy(params.ref, "RHF");
   }
+  
+  params.semicanonical = 0;
+  /* Semicanonical orbitals for perturbation theory */
+  if(!strcmp(params.ref, "ROHF") && (!strcmp(params.wfn, "CCSD_T") || !strcmp(params.wfn, "MP2") || 
+				     !strcmp(params.wfn, "CC3") || !strcmp(params.wfn,"EOM_CC3") ||
+				     !strcmp(params.wfn, "CC2") || !strcmp(params.wfn,"EOM_CC2"))) {
+    strcpy(params.ref, "UHF");
+    params.semicanonical = 1;
+  }  
 
   /* the default to this was already set by command line parsing */
   errcod = ip_boolean("BACKTRANS", &(params.backtr), 0);
@@ -433,11 +443,12 @@ void get_parameters(void)
   params.ab_mfile = PSIF_MO_AB_TEI;
   errcod = ip_data("AB_M_FILE","%d", &(params.ab_mfile),0);
 
-  params.max_buckets = 199;
+  params.max_buckets = 499;
   errcod = ip_data("MAX_BUCKETS","%d", &(params.max_buckets),0);
 
   if ((strcmp(params.wfn,"OOCCD")==0 || strcmp(params.wfn,"DETCAS")==0 ||
-      !strcmp(params.wfn,"BCCD") || !strcmp(params.wfn,"BCCD_T")) &&
+       strcmp(params.wfn,"BCCD")==0  || strcmp(params.wfn,"BCCD_T")==0 ||
+       strcmp(params.wfn,"CASSCF")==0|| strcmp(params.wfn,"RASSCF")==0) &&
       !params.backtr)
     params.delete_src_tei = 0;
   else 
@@ -472,6 +483,7 @@ void get_parameters(void)
   errcod = ip_data("PRINT", "%d", &(params.print_lvl),0);
      
   if (strcmp(params.wfn, "CI")==0 || strcmp(params.wfn, "DETCAS")==0 ||
+      strcmp(params.wfn, "CASSCF")==0 || strcmp(params.wfn, "RASSCF")==0 ||
       strcmp(params.wfn, "DETCI")==0) {
     params.lagran_double = 1;
     params.lagran_halve = 0;
@@ -487,8 +499,9 @@ void get_parameters(void)
  
 
 
-  if ((strcmp(params.wfn, "OOCCD")==0 || strcmp(params.dertype, "FIRST")==0
-       || strcmp(params.wfn, "DETCAS")==0) && !params.backtr) 
+  if ((strcmp(params.wfn, "OOCCD")==0 || strcmp(params.dertype, "FIRST")==0 ||
+       strcmp(params.wfn, "DETCAS")==0 || strcmp(params.wfn, "CASSCF")==0 ||
+       strcmp(params.wfn, "RASSCF")==0) && !params.backtr) 
     params.do_all_tei = 1;
   else params.do_all_tei = 0;
   if (params.runmode == MODE_MP2R12AERI || params.runmode == MODE_MP2R12AR12 ||
@@ -517,6 +530,11 @@ void get_parameters(void)
   params.tpdm_add_ref = 0;
   errcod = ip_boolean("TPDM_ADD_REF", &(params.tpdm_add_ref), 0);
 
+  if (strcmp(params.wfn,"DETCAS")==0 || strcmp(params.wfn,"CASSCF")==0 ||
+      strcmp(params.wfn,"RASSCF")==0)  
+    params.treat_cor_as_fzc = 1;
+  else
+    params.treat_cor_as_fzc = 0;
 
   params.fzc = 1;
   errcod = ip_boolean("FREEZE_CORE", &(params.fzc),0);
@@ -530,7 +548,8 @@ void get_parameters(void)
   if (strcmp(params.wfn,"GVVPT2")==0 || (strcmp(params.wfn,"MCSCF")==0))
     params.fzc=0;
 
-  params.del_restr_docc = 0;
+  /* remove restricted docc from RAS 1 ? */
+  params.del_restr_docc = 1;
   errcod = ip_boolean("DELETE_RESTR_DOCC",&(params.del_restr_docc),0);
   if (params.backtr) params.del_restr_docc = 0;
 
@@ -571,16 +590,21 @@ void print_parameters(void)
       fprintf(outfile,"\tInput Parameters:\n");
       fprintf(outfile,"\t-----------------\n");
       fprintf(outfile,"\tWavefunction           =  %s\n", params.wfn);
+      if(params.semicanonical) {
+      fprintf(outfile,"\tReference orbitals     =  ROHF changed to UHF for Semicanonical Orbitals\n");
+      }
+      else {
       fprintf(outfile,"\tReference orbitals     =  %s\n", params.ref);
+      }	      
       fprintf(outfile,"\tBacktrans              =  %s\n", 
 	                           params.backtr ? "Yes" : "No");
       fprintf(outfile,"\tPrint MOs              =  %s\n", 
                                   (params.print_mos ? "Yes": "No"));
-      fprintf(outfile,"\tFreeze Core            = %s\n", 
+      fprintf(outfile,"\tFreeze Core            =  %s\n", 
                                   (params.fzc ? "Yes" : "No"));
       fprintf(outfile,"\tDelete Restricted Docc =  %s\n", 
 		                  (params.del_restr_docc ? "Yes" : "No"));
-      fprintf(outfile,"\tDo All TEI             = %s\n", 
+      fprintf(outfile,"\tDo All TEI             =  %s\n", 
                                   (params.do_all_tei ? "Yes" : "No"));
       fprintf(outfile,"\tMemory (Mbytes)        =  %5.1f\n",params.maxcor/1e6);
       fprintf(outfile,"\tMax Buckets            =  %d\n",params.max_buckets);
@@ -629,6 +653,8 @@ void print_parameters(void)
                                   (params.qrhf ? "Yes" : "No"));
       fprintf(outfile,"\tIVO orbitals           =  %s\n", 
                                   (params.ivo ? "Yes" : "No"));
+      fprintf(outfile,"\tSemicanonical orbitals =  %s\n", 
+                                  (params.semicanonical ? "Yes" : "No"));
       fprintf(outfile,"\tPitzer                 =  %s\n", 
                                   (params.pitzer ? "Yes" : "No"));
     }
@@ -655,15 +681,6 @@ void get_moinfo(void)
   moinfo.openpi = chkpt_rd_openpi();
   moinfo.enuc = chkpt_rd_enuc();
   moinfo.escf = chkpt_rd_escf();
-  if(!strcmp(params.ref, "UHF")) {
-    /* moinfo.evals = chkpt_rd_alpha_evals(); */
-    moinfo.scf_vector_alpha = chkpt_rd_alpha_scf();
-    moinfo.scf_vector_beta = chkpt_rd_beta_scf();
-  }
-  else {
-    /* moinfo.evals = chkpt_rd_evals(); */
-    moinfo.scf_vector = chkpt_rd_scf();
-  }
   moinfo.nshell = chkpt_rd_nshell();
   moinfo.sloc = chkpt_rd_sloc();
   moinfo.snuc = chkpt_rd_snuc();
@@ -671,10 +688,22 @@ void get_moinfo(void)
   moinfo.rstrdocc = init_int_array(moinfo.nirreps);
   moinfo.rstruocc = init_int_array(moinfo.nirreps);
   
+  /* Needed for MO  reordering */
+  if(!strcmp(params.ref, "UHF") && params.semicanonical == 0) {
+    moinfo.scf_vector_alpha = chkpt_rd_alpha_scf();
+    moinfo.scf_vector_beta = chkpt_rd_beta_scf();
+  }
+  else if(!strcmp(params.ref, "UHF") && params.semicanonical == 1){
+    moinfo.scf_vector = chkpt_rd_scf();
+  }
+  else {
+    moinfo.scf_vector = chkpt_rd_scf();
+  }
+
   /* reorder the MOs if the user has requested it */
   if (params.reorder) {
 
-    if(!strcmp(params.ref, "UHF")) {
+    if(!strcmp(params.ref, "UHF") && params.semicanonical == 0) {
       fprintf(stderr, "ERROR: MO reordering not allowed for UHF references.\n");
       abort();
     }
@@ -710,13 +739,6 @@ void get_moinfo(void)
 	for (j=0; j<moinfo.nmo; j++) 
 	  moinfo.scf_vector[i][j] = tmpmat[i][params.moorder[j]];
 
-      /*
-      for (i=0; i<moinfo.nmo; i++)
-	tmpmat[0][i] = moinfo.evals[i];
-      for (i=0; i<moinfo.nmo; i++) 
-	moinfo.evals[i] = tmpmat[0][params.moorder[i]];
-      */
-
       free_matrix(tmpmat, moinfo.nso);        
     }
   } 
@@ -738,6 +760,16 @@ void get_moinfo(void)
   moinfo.frdocc = get_frzcpi();
   moinfo.fruocc = get_frzvpi();
 
+  errcod = ip_int_array("RESTRICTED_DOCC",moinfo.rstrdocc,moinfo.nirreps);
+  errcod = ip_int_array("RESTRICTED_UOCC",moinfo.rstruocc,moinfo.nirreps);
+
+  if (params.treat_cor_as_fzc) {
+    for (i=0; i<moinfo.nirreps; i++) {
+      moinfo.frdocc[i] += moinfo.rstrdocc[i];
+      moinfo.rstrdocc[i] = 0;
+    }
+  }
+
   if (!params.fzc) {
     for (i=0; i<moinfo.nirreps; i++) {
       moinfo.frdocc[i] = 0;
@@ -751,31 +783,34 @@ void get_moinfo(void)
     moinfo.nfzv += moinfo.fruocc[i];
   }
 
-  moinfo.ndocc = 0;
-  tmpi = init_int_array(moinfo.nirreps);
-  errcod = ip_int_array("DOCC", tmpi, moinfo.nirreps);
-  if (errcod == IPE_OK) {
-    for (i=0,warned=0; i<moinfo.nirreps; i++) {
-      if (tmpi[i] != moinfo.clsdpi[i] && !warned && !params.qrhf) {
-	fprintf(outfile, "\tWarning: DOCC doesn't match chkpt file\n");
-	warned = 1;
+  if ( chkpt_rd_override_occ() == 0 ) {
+    moinfo.ndocc = 0;
+    tmpi = init_int_array(moinfo.nirreps);
+    errcod = ip_int_array("DOCC", tmpi, moinfo.nirreps);
+    if (errcod == IPE_OK) {
+      for (i=0,warned=0; i<moinfo.nirreps; i++) {
+        if (tmpi[i] != moinfo.clsdpi[i] && !warned && !params.qrhf) {
+	  fprintf(outfile, "\tWarning: DOCC doesn't match chkpt file\n");
+	  warned = 1;
+        }
+        moinfo.clsdpi[i] = tmpi[i];
+        moinfo.ndocc += tmpi[i];
       }
-      moinfo.clsdpi[i] = tmpi[i];
-      moinfo.ndocc += tmpi[i];
     }
-  }
 
-  moinfo.nsocc = 0;
-  errcod = ip_int_array("SOCC", tmpi, moinfo.nirreps);
-  if (errcod == IPE_OK) {
-    for (i=0,warned=0; i<moinfo.nirreps; i++) {
-      if (tmpi[i] != moinfo.openpi[i] && !warned && !params.qrhf) {
-	fprintf(outfile, "\tWarning: SOCC doesn't match chkpt file\n");
-	warned = 1;
+    moinfo.nsocc = 0;
+    errcod = ip_int_array("SOCC", tmpi, moinfo.nirreps);
+    if (errcod == IPE_OK) {
+      for (i=0,warned=0; i<moinfo.nirreps; i++) {
+        if (tmpi[i] != moinfo.openpi[i] && !warned && !params.qrhf) {
+	  fprintf(outfile, "\tWarning: SOCC doesn't match chkpt file\n");
+	  warned = 1;
+        }
+        moinfo.openpi[i] = tmpi[i];
+        moinfo.nsocc += tmpi[i];
       }
-      moinfo.openpi[i] = tmpi[i];
-      moinfo.nsocc += tmpi[i];
     }
+    free(tmpi);
   }
 
   /* Dump the new occupations to chkpt file if QRHF reference requested 
@@ -791,7 +826,7 @@ void get_moinfo(void)
   for(i=0; i < moinfo.nirreps; i++) {
     moinfo.virtpi[i] = moinfo.orbspi[i]-moinfo.clsdpi[i]-moinfo.openpi[i];
   }
-
+  
   if (params.print_lvl) {
     fprintf(outfile,"\n\tChkpt File Parameters:\n");
     fprintf(outfile,"\t------------------\n");
@@ -819,7 +854,12 @@ void get_moinfo(void)
   moinfo.noeints = moinfo.nso*(moinfo.nso+1)/2;
   moinfo.nteints = moinfo.noeints*(moinfo.noeints+1)/2;
 
-
+  if(params.semicanonical) {
+    semicanonical_fock();
+    moinfo.scf_vector_alpha = chkpt_rd_alpha_scf();
+    moinfo.scf_vector_beta = chkpt_rd_beta_scf();
+  }
+  
   /*
     Construct first and last index arrays for SOs: this defines the first
     absolute orbital index and last absolute orbital
@@ -1107,6 +1147,8 @@ void get_reorder_array(void)
       || strcmp(params.wfn, "GVVPT2") == 0 
       || strcmp(params.wfn, "MCSCF") == 0 
       || strcmp(params.wfn, "OOCCD") == 0 
+      || strcmp(params.wfn, "CASSCF") == 0 
+      || strcmp(params.wfn, "RASSCF") == 0 
       || strcmp(params.wfn, "DETCAS") == 0) {
     
     ras_opi = init_int_matrix(MAX_RAS_SPACES,moinfo.nirreps); 
@@ -1124,8 +1166,16 @@ void get_reorder_array(void)
       abort();
     }
     
+    /* we just did this, but re-do it because ras_set() overwrites */
+    if (params.treat_cor_as_fzc) {
+      for (i=0; i<moinfo.nirreps; i++) {
+        moinfo.frdocc[i] += moinfo.rstrdocc[i];
+        moinfo.rstrdocc[i] = 0;
+      }
+    }
+
     free_int_matrix(ras_opi, MAX_RAS_SPACES);
-    
+
   } 
   
   else { /* default (CC, MP2, other) */
