@@ -60,8 +60,8 @@ extern struct MOInfo moinfo;
 ** where nbfao != nbfmo.
 */
 void yosh_init(struct yoshimine *YBuff, unsigned bra_indices,
-               unsigned ket_indices, unsigned long maxcor,
-               unsigned long maxcord, const int max_buckets,
+               unsigned ket_indices, long maxcor,
+               long maxcord, const int max_buckets,
                unsigned int first_tmp_file, 
                double cutoff, FILE *outfile)
 {
@@ -91,9 +91,9 @@ void yosh_init(struct yoshimine *YBuff, unsigned bra_indices,
     * the last bucket will have the remainder of the pq's.
     */
    YBuff->pq_per_bucket = bra_indices / nbuckets ;
-   bytes_per_bucket = maxcor / nbuckets;
-   free_bytes_per_bucket = bytes_per_bucket - sizeof(struct iwlbuf) - 
-      IWL_INTS_PER_BUF * (4*sizeof(Label) + sizeof(Value));
+   bytes_per_bucket = (unsigned long int) (maxcor / nbuckets);
+   free_bytes_per_bucket = bytes_per_bucket - 
+     (unsigned long int) (sizeof(struct iwlbuf) + IWL_INTS_PER_BUF * (4*sizeof(Label) + sizeof(Value)));
    YBuff->bucketsize = free_bytes_per_bucket / (4 * sizeof(int) +
       sizeof(double)); 
    YBuff->buckets = (struct bucket *) malloc(nbuckets * sizeof(struct bucket));
