@@ -6,6 +6,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 #include <libciomr/libciomr.h>
@@ -24,13 +25,16 @@
 int *chkpt_rd_am2canon_shell_order(void)
 {
   int *am2can_sh_ord, nshell;
+  char *keyword;
+  keyword = chkpt_build_keyword("AM -> canonical shell map"); 
 
   nshell = chkpt_rd_nshell();
   am2can_sh_ord = init_int_array(nshell);
 
-  psio_read_entry(PSIF_CHKPT, "::AM -> canonical shell map", 
-                  (char *) am2can_sh_ord, nshell*sizeof(int));
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) am2can_sh_ord,
+      nshell*sizeof(int));
 
+  free(keyword);
   return am2can_sh_ord;
 }
 
@@ -50,9 +54,13 @@ int *chkpt_rd_am2canon_shell_order(void)
 void chkpt_wt_am2canon_shell_order(int *am2can_sh_ord)
 {
   int nshell;
+  char *keyword;
+  keyword = chkpt_build_keyword("AM -> canonical shell map");
 
   nshell = chkpt_rd_nshell();
 
-  psio_write_entry(PSIF_CHKPT, "::AM -> canonical shell map", 
-                   (char *) am2can_sh_ord, nshell*sizeof(int));
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) am2can_sh_ord,
+      nshell*sizeof(int));
+
+  free(keyword);
 }
