@@ -4,6 +4,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 
@@ -20,8 +21,12 @@
 int chkpt_rd_max_am(void)
 {
   int max_am;
+  char *keyword;
+  keyword = chkpt_build_keyword("Max. AM");
 
-  psio_read_entry(PSIF_CHKPT, "::Max. AM", (char *) &max_am, sizeof(int));
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) &max_am, sizeof(int));
+
+  free(keyword);
   return max_am;
 }
 
@@ -41,5 +46,10 @@ int chkpt_rd_max_am(void)
 
 void chkpt_wt_max_am(int max_am)
 {
-  psio_write_entry(PSIF_CHKPT, "::Max. AM", (char *) &max_am, sizeof(int));
+  char *keyword;
+  keyword = chkpt_build_keyword("Max. AM");
+
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) &max_am, sizeof(int));
+
+  free(keyword);
 }
