@@ -4,6 +4,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 
@@ -17,9 +18,16 @@
 
 int chkpt_rd_ncalcs(void)
 {
-  if (psio_tocscan(PSIF_CHKPT,"::MO coefficients") == NULL &&
-      psio_tocscan(PSIF_CHKPT,"::Alpha MO coefficients") == NULL)
+  char *keyword_mo, *keyword_alpha_mo;
+  keyword_mo = chkpt_build_keyword("MO coefficients");
+  keyword_alpha_mo = chkpt_build_keyword("Alpha MO coefficients");
+
+  if (psio_tocscan(PSIF_CHKPT, keyword_mo) == NULL &&
+      psio_tocscan(PSIF_CHKPT, keyword_alpha_mo) == NULL)
     return 0;
   else
     return 1;
+
+  free(keyword_mo);
+  free(keyword_alpha_mo);
 }
