@@ -4,6 +4,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 
@@ -18,9 +19,12 @@
 int chkpt_rd_nfzv(void)
 {
   int nfzv;
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. Frozen UOCC");
 
-  psio_read_entry(PSIF_CHKPT, "::Num. Frozen UOCC", (char *) &nfzv, 
-                  sizeof(int) );
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) &nfzv, sizeof(int) );
+
+  free(keyword);
   return nfzv;
 }
 
@@ -36,5 +40,10 @@ int chkpt_rd_nfzv(void)
 
 void chkpt_wt_nfzv(int nfzv)
 {
-  psio_write_entry(PSIF_CHKPT, "::Num. Frozen UOCC", (char *) &nfzv, sizeof(int));
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. Frozen UOCC");
+
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) &nfzv, sizeof(int));
+
+  free(keyword);
 }
