@@ -4,6 +4,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 
@@ -18,9 +19,12 @@
 int chkpt_rd_nmo(void)
 {
   int nmo;
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. MO's");
 
-  psio_read_entry(PSIF_CHKPT, "::Num. MO's", (char *) &nmo, 
-                  sizeof(int) );
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) &nmo, sizeof(int));
+
+  free(keyword);
   return nmo;
 }
 
@@ -36,5 +40,10 @@ int chkpt_rd_nmo(void)
 
 void chkpt_wt_nmo(int nmo)
 {
-  psio_write_entry(PSIF_CHKPT, "::Num. MO's", (char *) &nmo, sizeof(int));
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. MO's");
+
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) &nmo, sizeof(int));
+
+  free(keyword);
 }
