@@ -4,6 +4,7 @@
 */
 
 #include "chkpt.h"
+#include <stdlib.h>
 #include <psifiles.h>
 #include <libpsio/psio.h>
 
@@ -18,8 +19,12 @@
 int chkpt_rd_nso(void)
 {
   int nso;
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. SO");
 
-  psio_read_entry(PSIF_CHKPT, "::Num. SO", (char *) &nso, sizeof(int));
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) &nso, sizeof(int));
+
+  free(keyword);
   return nso;
 }
 
@@ -37,5 +42,10 @@ int chkpt_rd_nso(void)
 
 void chkpt_wt_nso(int nso)
 {
-  psio_write_entry(PSIF_CHKPT, "::Num. SO", (char *) &nso, sizeof(int));
+  char *keyword;
+  keyword = chkpt_build_keyword("Num. SO");
+
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) &nso, sizeof(int));
+
+  free(keyword);
 }
