@@ -4,6 +4,7 @@
 */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <libciomr/libciomr.h>
 #include "chkpt.h"
 #include <psifiles.h>
@@ -24,14 +25,16 @@ int *chkpt_rd_stype(void)
 {
   int *stype;
   int nshell;
+  char *keyword;
+  keyword = chkpt_build_keyword("Shell ang. mom.");
 
   nshell = chkpt_rd_nshell();
 
   stype = init_int_array(nshell);
 
-  psio_read_entry(PSIF_CHKPT, "::Shell ang. mom.", (char *) stype, 
-                  nshell*sizeof(int));
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) stype, nshell*sizeof(int));
 
+  free(keyword);
   return stype;
 }
 
@@ -50,9 +53,12 @@ int *chkpt_rd_stype(void)
 void chkpt_wt_stype(int *stype)
 {
   int nshell;
+  char *keyword;
+  keyword = chkpt_build_keyword("Shell ang. mom.");
 
   nshell = chkpt_rd_nshell();
 
-  psio_write_entry(PSIF_CHKPT, "::Shell ang. mom.", (char *) stype, 
-                   nshell*sizeof(int));
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) stype, nshell*sizeof(int));
+
+  free(keyword);
 }
