@@ -21,15 +21,16 @@
 char *chkpt_rd_sym_label(void)
 {
   char *sym_label;
-  char *key;
+  char *keyword;
+  keyword = chkpt_build_keyword("Symmetry label");
 
   sym_label = (char *) malloc(4*sizeof(char));
 
-  key = chkpt_build_keyword("Symmetry label");
-  psio_read_entry(PSIF_CHKPT, key, (char *) sym_label, 4*sizeof(char));
-  sym_label[3] = '\0';
-  free(key);
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) sym_label, 4*sizeof(char));
 
+  sym_label[3] = '\0';
+
+  free(keyword);
   return sym_label;  
 }
 
@@ -46,10 +47,11 @@ char *chkpt_rd_sym_label(void)
 
 void chkpt_wt_sym_label(char *sym_label)
 {
-  char *key;
-  key = chkpt_build_keyword("Symmetry label");
-  psio_write_entry(PSIF_CHKPT, "::Symmetry label", (char *) sym_label, 
-                   4*sizeof(char));
-  free(key);
+  char *keyword;
+  keyword = chkpt_build_keyword("Symmetry label");
+
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) sym_label, 4*sizeof(char));
+
+  free(keyword);
 }
 
