@@ -4,6 +4,7 @@
 */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <psifiles.h>
 #include "chkpt.h"
 #include <libciomr/libciomr.h>
@@ -24,19 +25,19 @@ double **chkpt_rd_usotao(void)
   double **usotao;
   int num_ao, num_so, i;
   psio_address ptr;
-  char *key;
+  char *keyword;
+  keyword = chkpt_build_keyword("SO->AO transmat");
 
   num_ao = chkpt_rd_nao();
   num_so = chkpt_rd_nso();
 
   usotao = block_matrix(num_so,num_ao);
-
-  key = chkpt_build_keyword("SO->AO transmat");
   ptr = PSIO_ZERO;
-  for(i=0;i<num_so;i++)
-    psio_read(PSIF_CHKPT, key, (char *) usotao[i], (int) num_ao*sizeof(double), ptr, &ptr);
-  free(key);
 
+  for(i=0;i<num_so;i++)
+    psio_read(PSIF_CHKPT, keyword, (char *) usotao[i], (int) num_ao*sizeof(double), ptr, &ptr);
+
+  free(keyword);
   return usotao;
 }
 
@@ -55,14 +56,15 @@ void chkpt_wt_usotao(double **usotao)
 {
   int num_ao, num_so, i;
   psio_address ptr;
-  char *key;
+  char *keyword;
+  keyword = chkpt_build_keyword("SO->AO transmat");
 
   num_ao = chkpt_rd_nao();
   num_so = chkpt_rd_nso();
 
-  key = chkpt_build_keyword("SO->AO transmat");
   ptr = PSIO_ZERO;
   for(i=0;i<num_so;i++)
-    psio_write(PSIF_CHKPT, key, (char *) usotao[i], (int) num_ao*sizeof(double), ptr, &ptr);
-  free(key);
+    psio_write(PSIF_CHKPT, keyword, (char *) usotao[i], (int) num_ao*sizeof(double), ptr, &ptr);
+
+  free(keyword);
 }
