@@ -3,6 +3,7 @@
 */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include "chkpt.h"
 #include <psifiles.h>
 #include <libciomr/libciomr.h>
@@ -22,14 +23,16 @@ double *chkpt_rd_zvals(void)
 {
   int natom;
   double *zvals;
+  char *keyword;
+  keyword = chkpt_build_keyword("Nuclear charges");
 
   natom = chkpt_rd_natom();
-
   zvals = init_array(natom);
 
-  psio_read_entry(PSIF_CHKPT, "::Nuclear charges", (char *) zvals, 
-                  natom*sizeof(double));
+  psio_read_entry(PSIF_CHKPT, keyword, (char *) zvals, 
+    natom*sizeof(double));
 
+  free(keyword);
   return zvals;
 }
 
@@ -45,9 +48,13 @@ double *chkpt_rd_zvals(void)
 void chkpt_wt_zvals(double *zvals)
 {
   int natom;
+  char *keyword;
+  keyword = chkpt_build_keyword("Nuclear charges");
 
   natom = chkpt_rd_natom();
 
-  psio_write_entry(PSIF_CHKPT, "::Nuclear charges", (char *) zvals, 
-                   natom*sizeof(double));
+  psio_write_entry(PSIF_CHKPT, keyword, (char *) zvals, 
+    natom*sizeof(double));
+
+  free(keyword);
 }
