@@ -3,25 +3,6 @@
   \ingroup (CIOMR)
 */
  
-/* $Log: eivout.c,v $
-/* Revision 1.3  2002/06/01 18:23:54  sherrill
-/* Upgrade doxygen documentation
-/*
-/* Revision 1.2  2002/04/19 21:48:06  sherrill
-/* Remove some unused functions and do doxygen markup of libciomr.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:18  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.2  1995/01/16 22:48:46  cljanss
-/* Minor changes to make the SGI compiler happy.
-/*
- * Revision 2.1  1991/06/15  18:28:48  seidl
- * *** empty log message ***
- * */
-
-static char *rcsid = "$Id: eivout.c,v 1.3 2002/06/01 18:23:54 sherrill Exp $";
-
 #include "includes.h"
 
 /*!
