@@ -1,14 +1,3 @@
-
-/* $Log: lubksb.c,v $
-/* Revision 1.1.1.1  2000/02/04 22:53:20  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.1  1991/06/15 18:29:26  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: lubksb.c,v 1.1.1.1 2000/02/04 22:53:20 evaleev Exp $";
-
 #include "includes.h"
 
 void lubksb(a,n,indx,b)
