@@ -1,21 +1,3 @@
-
-/* $Log: ludcmp.c,v $
-/* Revision 1.2  2002/04/04 22:24:38  evaleev
-/* Converted allocation functions (init_array, etc.) to take unsigned long ints
-/* to be able to allocate properly 2GB+ chunks). Some declarations cleaned up.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:20  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.2  1999/11/01 20:10:57  evaleev
-/* Added explicit extern declarations of functions within the library.
-/*
-/* Revision 2.1  1991/06/15 18:29:27  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: ludcmp.c,v 1.2 2002/04/04 22:24:38 evaleev Exp $";
-
 #include "includes.h"
 
 void ludcmp(a,n,indx,d)
