@@ -3,26 +3,16 @@
 ** \ingroup (CIOMR)
 */
 
-/* $Log: print_array.c,v $
-/* Revision 1.3  2002/06/01 18:23:54  sherrill
-/* Upgrade doxygen documentation
-/*
-/* Revision 1.2  2002/04/19 21:48:06  sherrill
-/* Remove some unused functions and do doxygen markup of libciomr.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:21  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.1  1991/06/15 18:29:42  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: print_array.c,v 1.3 2002/06/01 18:23:54 sherrill Exp $";
-
 #include "includes.h"
 
 /*!
-** print_array: Prints a linear array a of length m to file pointer out.
+** print_array: Prints a lower-triangle of a symmetric matrix packed as
+**  an array of doubles.
+**
+** Arguments:
+** \param a     = array (packed lower triangle of matrix) to print
+** \param m     = dimension of matrix (mxm)
+** \param out   = file pointer for output
 **
 ** \ingroup (CIOMR)
 */
