@@ -3,27 +3,17 @@
 ** \ingroup (CIOMR)
 */
 
-/* $Log: print_mat.c,v $
-/* Revision 1.3  2002/06/01 18:23:54  sherrill
-/* Upgrade doxygen documentation
-/*
-/* Revision 1.2  2002/04/19 21:48:06  sherrill
-/* Remove some unused functions and do doxygen markup of libciomr.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:21  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.1  1991/06/15 18:29:43  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: print_mat.c,v 1.3 2002/06/01 18:23:54 sherrill Exp $";
-
 #include "includes.h"
 
-/*
+/*!
 ** print_mat: Print a matrix a of dimensions mxn to file pointer out.
 **
+** Arguments:
+**  \param a   = matrix to print
+**  \param m   = number of rows in matrix
+**  \param n   = number of columns in matrix
+**  \param out = file pointer for output
+**
 ** \ingroup (CIOMR)
 */
 void print_mat(double **a, int m, int n, FILE *out)
