@@ -1,16 +1,3 @@
-/* $Log: resource.c,v $
-/* Revision 1.2  2002/04/19 21:48:06  sherrill
-/* Remove some unused functions and do doxygen markup of libciomr.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:22  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.1  1991/06/15 18:29:48  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: resource.c,v 1.2 2002/04/19 21:48:06 sherrill Exp $";
-
 #include "includes.h"
 #include "common.h"
 
