@@ -1,70 +1,3 @@
-
-/* $Log: sequential.c,v $
-/* Revision 1.3  2003/04/22 14:59:26  crinders
-/* Corrected error in sequential.c with an incorrect fprintf on line 476 ud->unit and caller were switched.
-/*
-/* Revision 1.2  2002/04/19 21:48:06  sherrill
-/* Remove some unused functions and do doxygen markup of libciomr.
-/*
-/* Revision 1.1.1.1  2000/02/04 22:53:23  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.11  1997/09/14 03:28:55  sherrill
-/* Added iosize_() to types.h so the function prototype could be passed to
-/* flen.c, which was getting the wrong return type.  Also reformatted some
-/* of my old code just a little to make it look a bit nicer.
-/*
- * Revision 2.10  1997/09/12  13:53:04  crawdad
- * Changing marco name from ULL to PSI_FPTR.
- *
- * Revision 2.9  1997/08/25  21:50:08  crawdad
- * Making changes for extension of PSI file size limit.
- *
- * Revision 2.8  1997/06/23  12:26:00  crawdad
- * Multiple changes to libciomr: Moved "param.h" to "iomrparam.h" to avoid
- *     conflicts with similarly named system file under linux.  Corrected type
- *    casting in rread(), rwrit(), sread(), and swrit() functions.  Corrected
- *     unclosed tmpdisks.dat file in sequential.c.  Corrected block_matrix() to
- *    avoid malloc'ing zero-length arrays.
- *
- * -Daniel
- *
- * Revision 2.7  1996/07/02  21:06:30  sherrill
- * Completed the changes needed to use unit numbers greater than 99; changed
- * a hardwired 99 in init_ptrs.c to MAX_UNIT and increased a "unit" string
- * from 3 chars to 4.  Also removed a compiler warning in sequential.c by
- * casting ud to (char *) for malloc_check().
- *
- * Revision 2.6  1996/06/18  20:47:47  sherrill
- * Add the whole set of int_array routines to int_array.c (replacing
- * init_int_array.c), add block_matrix.c, and add a new function flen
- * which gets the file size for unit number x.
- *
- * Revision 2.5  1995/04/01  20:53:06  fermann
- * changed bytewise file pointers such as first, last and length to long
- * unsigned ints in order to handle up to 4 gigabyte tmp files (striped into
- * individual pieces of less than 2 gigabytes).  added functions li2sec and
- * sec2li for where they are needed.
- *
- * Revision 2.4  1994/06/02  02:28:02  seidl
- * use SITEDIR for location of tmpdisks.dat
- *
- * Revision 1.1  1994/05/02  23:11:21  cljanss
- * CCQC code as of May 1, 1994 that was missed in the initial cvs checkin.
- *
- * Revision 2.3  1993/09/08  20:00:59  psi
- * Add default disk striping
- *
- * Revision 2.2  1991/09/18  20:47:30  seidl
- * dec changes
- *
- * Revision 2.1  1991/06/15  18:30:03  seidl
- * *** empty log message ***
- * */
-
-static char *rcsid = "$Id: sequential.c,v 1.3 2003/04/22 14:59:26 crinders Exp $";
-
-
 #include <sys/file.h>
 #include "includes.h"
 #include "iomrparam.h"
