@@ -1,17 +1,3 @@
-
-/* $Log: sortc.c,v $
-/* Revision 1.1.1.1  2000/02/04 22:53:23  evaleev
-/* Started PSI 3 repository
-/*
-/* Revision 2.2  1999/11/01 20:10:59  evaleev
-/* Added explicit extern declarations of functions within the library.
-/*
-/* Revision 2.1  1991/06/15 18:30:05  seidl
-/* *** empty log message ***
-/* */
-
-static char *rcsid = "$Id: sortc.c,v 1.1.1.1 2000/02/04 22:53:23 evaleev Exp $";
-
 #include "includes.h"
 
 void sort_buffer_c(buffer,size)
