@@ -21,6 +21,10 @@ int dpd_buf4_close(dpdbuf4 *Buf)
 
   free_int_matrix(Buf->shift.rowtot,nirreps);
   free_int_matrix(Buf->shift.coltot,nirreps);
+
+  free_int_matrix(Buf->row_offset, nirreps);
+  free_int_matrix(Buf->col_offset, nirreps);
+
   free(Buf->shift.matrix);
 
   return 0;
