@@ -14,7 +14,7 @@ int dpd_file4_mat_irrep_rd(dpdfile4 *File, int irrep)
   /* If the data doesn't actually exist on disk, we just leave */
   if(psio_tocscan(File->filenum, File->label) == NULL) return 1;
 
-#ifdef DPD_TIMER
+#if 1
   timer_on("file4_rd");
 #endif
 
@@ -28,7 +28,7 @@ int dpd_file4_mat_irrep_rd(dpdfile4 *File, int irrep)
      psio_read(File->filenum, File->label, (char *) File->matrix[irrep][0],
 	       size*((long) sizeof(double)), irrep_ptr, &next_address);
 
-#ifdef DPD_TIMER
+#if 1
   timer_off("file4_rd");
 #endif
 
