@@ -3,6 +3,7 @@
 #include <string.h>
 #include <libipv1/ip_lib.h>
 #include <libpsio/psio.h>
+#include <libchkpt/chkpt.h>
 #include <libciomr/libciomr.h>
 #include <psifiles.h>
 
@@ -16,7 +17,8 @@ char *psi_file_prefix;
 
 int main(int argc, char *argv[])
 {
-  int unit=0, i=0;
+  int unit=0, i=0, get_chkpt_prefix=0;
+  char *prefix;
 
   while(--argc > 0) {
        i++;
@@ -28,6 +30,11 @@ int main(int argc, char *argv[])
            unit = cc2unit(argv[i+1]);
            argc--;
          }
+       else if(!strcmp(argv[i], "-prefix")) {
+           unit = PSIF_CHKPT;
+           get_chkpt_prefix = 1;
+           argc--;
+         }
     }
 
   if(!unit) { printf("Bad unit number.\n"); exit(PSI_RETURN_FAILURE); }
@@ -35,7 +42,15 @@ int main(int argc, char *argv[])
   init_io(argc-1, argv+i);
 
   psio_open(unit,PSIO_OPEN_OLD);
-  psio_tocprint(unit,stdout);
+  if (!get_chkpt_prefix)
+    psio_tocprint(unit,stdout);
+  else {
+    chkpt_init(PSIO_OPEN_OLD);
+    prefix = chkpt_rd_prefix();
+    chkpt_close();
+    printf("Checkpoint file prefix: %s\n", prefix);
+    free(prefix);
+  }
   psio_close(unit,1);
 
   exit_io();
