@@ -37,9 +37,11 @@ $PSITEST_TARGET_SUFFIX = "test";
 $PSITEST_TEST_SCRIPT = "runtest.pl";
 
 # These are definitions that default tester knows about -- should match Psi driver!
-@PSITEST_JOBTYPES = ("SP", "OPT", "DISP", "FREQ", "SYMM_FREQ", "OEPROP", "DBOC");
-@PSITEST_WFNS = ("SCF", "MP2", "MP2R12", "DETCI", "DETCAS", "BCCD", "BCCD_T", "CCSD", "CCSD_T",
-"EOM_CCSD", "LEOM_CCSD", "OOCCD", "CIS");
+@PSITEST_JOBTYPES = ("SP", "OPT", "DISP", "FREQ", "SYMM_FC", "FC", 
+"OEPROP", "DBOC");
+@PSITEST_WFNS = ("SCF", "MP2", "MP2R12", "DETCI", "DETCAS", "CASSCF",
+"RASSCF", "BCCD", "BCCD_T", "CC2", "CCSD", "CCSD_T", "CC3", "EOM_CC2", 
+"LEOM_CC2", "EOM_CCSD", "LEOM_CCSD", "OOCCD", "CIS", "EOM_CC3");
 @PSITEST_REFTYPES = ("RHF", "ROHF", "UHF", "TWOCON");
 @PSITEST_DERTYPES = ("NONE", "FIRST", "SECOND", "RESPONSE");
 
@@ -51,11 +53,12 @@ $PSITEST_EEOMTOL = 10**-5;        # Less stringent test for EOM-CC energies
 $PSITEST_GEOMTOL = 10**-6;        # Default test criterion for Cartesian geometries
 $PSITEST_GTOL = 10**-6;           # Default test criterion for gradients
 $PSITEST_HTOL = 10**-2;           # Default test criterion for Hessians
-$PSITEST_POLARTOL = 10**-4;       # Default test criterion for polarizabilities
+$PSITEST_POLARTOL = 10**-5;       # Default test criterion for polarizabilities
+$PSITEST_OPTROTTOL = 10**-3;      # Default test criterion for optical rotation
 $PSITEST_STABTOL = 10**-4;        # Default test criterion for Hessian eigenvalues
 $PSITEST_MPOPTOL = 10**-5;        # Default test criterion for Mulliken populations
-
-##################################################################
+$PSITEST_CIDIPTOL = 10**-4;       # Default test criterion for CI dipoles
+##################################################
 #
 # This is a "smart" tester -- it parses the input and figures out
 # what kinds of tests to run
@@ -130,21 +133,33 @@ sub do_tests
     }
 
     # I'll lump all single-point computations together
-    if ( $jobtype eq "SP" || $jobtype eq "FREQ" || $jobtype eq "SYMM_FREQ" || $jobtype eq "OEPROP" ||
-         $jobtype eq "DBOC" || $jobtype eq "RESPONSE" ) {
+    if ( $jobtype eq "SP" || $jobtype eq "FREQ" || $jobtype eq "SYMM_FC" || $jobtype eq "OEPROP" ||
+         $jobtype eq "DBOC" || $jobtype eq "RESPONSE" || $jobtype eq "FC" ) {
       
       $fail |= compare_nuc();
+
+      # DBOC is special, because it does not compute the wave function -- only check DBOC and break
+      if ($jobtype eq "DBOC") {
+        $fail |= compare_dboc();
+	last SWITCH1;
+      }
+      
       # All computations in Psi3 start with an SCF run
       $fail |= compare_scf_energy();
-        
+
       SWITCH2: {
         
           if ($wfn eq "CCSD")     { $fail |= compare_ccsd_energy(); last SWITCH2; }
-          if ($wfn eq "CCSD_T")   { $fail |= compare_ccsd_t_energy(); last SWITCH2; }
+          if ($wfn eq "CC2")      { $fail |= compare_cc2_energy(); last SWITCH2; }
+	  if ($wfn eq "CCSD_T")   { $fail |= compare_ccsd_t_energy(); last SWITCH2; }
+          if ($wfn eq "CC3")      { $fail |= compare_cc3_energy(); last SWITCH2; }
+          if ($wfn eq "EOM_CC2")  { $fail |= compare_eomcc2_energy(); last SWITCH2; }
           if ($wfn eq "EOM_CCSD") { $fail |= compare_eomccsd_energy(); last SWITCH2; }
+          if ($wfn eq "EOM_CC3")  { $fail |= compare_eomcc3_energy(); last SWITCH2; }
           if ($wfn eq "BCCD")     { $fail |= compare_bccd_energy(); last SWITCH2; }
           if ($wfn eq "BCCD_T")   { $fail |= compare_bccd_t_energy(); last SWITCH2; }
           if ($wfn eq "CASSCF")   { $fail |= compare_casscf_energy(); last SWITCH2; }
+          if ($wfn eq "RASSCF")   { $fail |= compare_rasscf_energy(); last SWITCH2; }
           if ($wfn eq "DETCI")    { $fail |= compare_ci_energy(); last SWITCH2; }
           if ($wfn eq "CIS")      { $fail |= compare_cis_energy(); last SWITCH2; }
           if ($wfn eq "MP2" && $direct == 1)
@@ -170,11 +185,15 @@ sub do_tests
         $fail |= compare_findif_freq($wfn);
       }
 
-      if ($jobtype eq "SYMM_FREQ" && $dertype eq "FIRST") {
+      if ($jobtype eq "FREQ" && $dertype eq "NONE") {
+        $fail |= compare_findif_freq($wfn);
+      }
+
+      if ($jobtype eq "SYMM_FC" && $dertype eq "FIRST") {
         $fail |= compare_findif_symm_freq($wfn);
       }
-      if ($jobtype eq "DBOC") {
-        $fail |= compare_dboc()
+      if ($jobtype eq "FC" && $dertype eq "FIRST") {
+        $fail |= compare_findif_freq($wfn);
       }
 
       if ($jobtype eq "OEPROP") {
@@ -189,15 +208,23 @@ sub do_tests
       }
      
       if ($jobtype eq "SP" && $dertype eq "RESPONSE") {
-        if ($wfn =~ "CC") {
+        if ($wfn eq "CC2") {
           $fail |= compare_cclambda_overlap($wfn);
-          $fail |= compare_ccsd_polar($wfn);
+          $fail |= compare_cc_response($wfn);
+        }
+        if ($wfn eq "CCSD") {
+          $fail |= compare_cclambda_overlap($wfn);
+          $fail |= compare_cc_response($wfn);
         }
         if ($wfn eq "SCF") {
           $fail |= compare_scf_polar();
         }
       }
 
+      if ($jobtype eq "OEPROP" && ($wfn eq "EOM_CC2" || $wfn eq "EOM_CCSD")) {
+        $fail |= compare_eomcc_oeprop();
+      }
+
       last SWITCH1;
     }
 
@@ -320,6 +347,22 @@ sub compare_scf_energy
   return $fail;
 }
 
+sub compare_cc2_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+                                                                                                              
+  if(abs(seek_cc2($REF_FILE) - seek_cc2($TEST_FILE)) > $PSITEST_ETOL) {
+    fail_test("CC2 energy"); $fail = 1;
+  }
+  else {
+    pass_test("CC2 energy");
+  }
+                                                                                                              
+  return $fail;
+}
+                                                                                                              
 sub compare_ccsd_energy
 {
   my $fail = 0;
@@ -352,6 +395,41 @@ sub compare_ccsd_t_energy
   return $fail;
 }
 
+sub compare_cc3_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  if(abs(seek_cc3($REF_FILE) - seek_cc3($TEST_FILE)) > $PSITEST_ETOL) {
+    fail_test("CC3 energy"); $fail = 1;
+  }
+  else {
+    pass_test("CC3 energy");
+  }
+ 
+  return $fail;
+}
+
+sub compare_eomcc2_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  @eom_ref = seek_eomcc($REF_FILE);
+  @eom_test = seek_eomcc($TEST_FILE);
+
+  if(!compare_arrays(\@eom_ref,\@eom_test,($#eom_ref+1),$PSITEST_EEOMTOL)) {
+    fail_test("EOM-CC2 energy"); $fail = 1;
+  }
+  else {
+    pass_test("EOM-CC2 energy");
+  }
+  
+  return $fail;
+}
+
 sub compare_eomccsd_energy
 {
   my $fail = 0;
@@ -371,6 +449,25 @@ sub compare_eomccsd_energy
   return $fail;
 }
 
+sub compare_eomcc3_energy
+{
+  my $fail = 0;  
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";   
+
+  @eom_ref = seek_eomcc($REF_FILE);   
+  @eom_test = seek_eomcc($TEST_FILE);
+
+  if(!compare_arrays(\@eom_ref,\@eom_test,($#eom_ref+1),$PSITEST_EEOMTOL)) {
+    fail_test("EOM-CC3 energy"); $fail = 1;
+  }  
+  else {
+    pass_test("EOM-CC3 energy");
+  }       
+  return $fail;
+}         
+
+
 sub compare_bccd_energy
 {
   my $fail = 0;
@@ -439,23 +536,138 @@ sub compare_scf_polar
   return $fail;
 }
 
-sub compare_ccsd_polar
+sub compare_cc_response
 {
   my $wfn = $_[0];
   my $fail = 0;
   my $REF_FILE = "$SRC_PATH/output.ref";
   my $TEST_FILE = "output.dat";
 
-  @polar_ref = seek_ccsd_polar($REF_FILE);
-  @polar_test = seek_ccsd_polar($TEST_FILE);
+  # Grab field frequencies
+  $nfreqs = seek_num_cc_response_freqs($TEST_FILE);
+#  printf "Number of frequencies = %d\n", $nfreqs;
+  @polar_freqs = seek_cc_response_freqs($TEST_FILE);
 
-  if(!compare_arrays(\@polar_ref,\@polar_test,($#polar_ref+1),$PSITEST_POLARTOL)) {
-    fail_test("$wfn Polarizability"); $fail = 1;
+  # What response property are we testing?
+  $property = seek_cc_response_property($TEST_FILE);
+#  printf "Response property = %s\n", $property;
+
+  if($property eq "ROTATION") {
+      # Length, velocity, or both?
+      $gauge = seek_cc_response_gauge($TEST_FILE);
+      if($gauge eq "BOTH") {
+	  for($i=0; $i < $nfreqs; $i++) {
+
+	      $alpha_ref = seek_cc_optrot($REF_FILE, $polar_freqs[$i], "LENGTH");
+	      $alpha_test = seek_cc_optrot($TEST_FILE, $polar_freqs[$i], "LENGTH");
+	      if(abs($alpha_ref - $alpha_test) >  $PSITEST_OPTROTTOL) {
+		  fail_test("$wfn Optical Rotation (LENGTH) @ $polar_freqs[$i]"); $fail = 1;
+	      }
+	      else {
+		  pass_test("$wfn Optical Rotation (LENGTH) @ $polar_freqs[$i]");
+	      }
+
+	      $alpha_ref = seek_cc_optrot($REF_FILE, $polar_freqs[$i], "VELOCITY");
+	      $alpha_test = seek_cc_optrot($TEST_FILE, $polar_freqs[$i], "VELOCITY");
+	      if(abs($alpha_ref - $alpha_test) >  $PSITEST_OPTROTTOL) {
+		  fail_test("$wfn Optical Rotation (VELOCITY) @ $polar_freqs[$i]"); $fail = 1;
+	      }
+	      else {
+		  pass_test("$wfn Optical Rotation (VELOCITY) @ $polar_freqs[$i]");
+	      }
+
+	      @vector_ref = seek_cc_delta($REF_FILE, $polar_freqs[$i]);
+	      @vector_test = seek_cc_delta($TEST_FILE, $polar_freqs[$i]);
+	      if(!compare_arrays(\@vector_ref, \@vector_test, ($#vector_test+1), $PSITEST_OPTROTTOL)) {
+		  fail_test("$wfn Optical Rotation Origin-Dependence Vector @ $polar_freqs[$i]"); $fail = 1;
+	      }
+	      else {
+		  pass_test("$wfn Optical Rotation Origin-Dependence Vector @ $polar_freqs[$i]");
+	      }
+	  }
+      }
+      else {
+	  for($i=0; $i < $nfreqs; $i++) {
+
+	      $alpha_ref = seek_cc_optrot($REF_FILE, $polar_freqs[$i], $gauge);
+	      $alpha_test = seek_cc_optrot($TEST_FILE, $polar_freqs[$i], $gauge);
+	      if(abs($alpha_ref - $alpha_test) >  $PSITEST_OPTROTTOL) {
+		  fail_test("$wfn Optical Rotation ($gauge) @ $polar_freqs[$i]"); $fail = 1;
+	      }
+	      else {
+		  pass_test("$wfn Optical Rotation ($gauge) @ $polar_freqs[$i]");
+	      }
+	  }
+      }
+
+  }
+  elsif($property eq "POLARIZABILITY") {
+      for($i=0; $i < $nfreqs; $i++) {
+	  $alpha_ref = seek_cc_polar($REF_FILE, $polar_freqs[$i], $gauge);
+	  $alpha_test = seek_cc_polar($TEST_FILE, $polar_freqs[$i], $gauge);
+	  if(abs($alpha_ref - $alpha_test) >  $PSITEST_POLARTOL) {
+	      fail_test("$wfn Polarizability @ $polar_freqs[$i]"); $fail = 1;
+	  }
+	  else {
+	      pass_test("$wfn Polarizability @ $polar_freqs[$i]");
+	  }
+      }
+  }
+
+  return $fail;
+}
+
+sub compare_eomcc_oeprop
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  $NSREF = seek_nstates($REF_FILE);
+  $NSTEST = seek_nstates($TEST_FILE);
+
+  $LABEL = "Number of States";
+  if($NSREF != $NSTEST) {
+    fail_test("$LABEL"); $fail = 1;
+  }  
+  else {
+    pass_test("$LABEL");
+    $NSTATES = $NSREF;
+  } 
+
+  @int_ref = seek_excitation_energy($REF_FILE,"OS       RS",$NSTATES);
+  @int_test = seek_excitation_energy($TEST_FILE,"OS       RS",$NSTATES);
+
+  $LABEL = "Excitation Energy";
+  if(!compare_arrays(\@int_ref, \@int_test, $NSTATES, $TOL)) {
+    fail_test("$LABEL"); $fail = 1;
   }
   else {
-    pass_test("$wfn Polarizability");
+    pass_test("$LABEL");
   }
-  
+
+  @int_ref = seek_osc_str($REF_FILE,"OS       RS",$NSTATES);
+  @int_test = seek_osc_str($TEST_FILE,"OS       RS",$NSTATES);
+
+  $LABEL = "Oscillator Strength";
+  if(!compare_arrays(\@int_ref, \@int_test, $NSTATES, $TTOL)) {
+    fail_test("$LABEL"); $fail = 1;
+  }
+  else {
+    pass_test("$LABEL");
+  }
+
+  @int_ref = seek_rot_str($REF_FILE,"OS       RS",$NSTATES);
+  @int_test = seek_rot_str($TEST_FILE,"OS       RS",$NSTATES);
+
+  $LABEL = "Rotational Strength";
+  if(!compare_arrays(\@int_ref, \@int_test, $NSTATES, $TTOL)) {
+    fail_test("$LABEL"); $fail = 1;
+  }
+  else {
+    pass_test("$LABEL");
+  }
+
   return $fail;
 }
 
@@ -475,6 +687,22 @@ sub compare_casscf_energy
   return $fail;
 }
 
+sub compare_rasscf_energy
+{
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  if(abs(seek_rasscf($REF_FILE) - seek_rasscf($TEST_FILE)) > $PSITEST_ETOL) {
+    fail_test("RASSCF energy"); $fail = 1;
+  }
+  else {
+    pass_test("RASSCF energy");
+  }
+  
+  return $fail;
+}
+
 sub compare_cis_energy
 {
   my $fail = 0;
@@ -506,10 +734,67 @@ sub compare_ci_energy
   else {
     pass_test("CI energy");
   }
+
+  if($fail == 0 && dip_check($REF_FILE) == 1) {
+    @ci_dip_ref = seek_ci_dip($REF_FILE);
+    @ci_dip_test = seek_ci_dip($TEST_FILE);
+    
+    $size_ci_dip_ref = @ci_dip_ref;
+    $size_ci_dip_test = @ci_dip_test;
+
+    if($size_ci_dip_ref != $size_ci_dip_test) {
+      fail_test("CI dipole"); $fail = 1;      
+    }
+    else {
+      for(my $i=0; $i < $size_ci_dip_ref; $i++) {
+        if(abs($ci_dip_ref[$i] - $ci_dip_test[$i]) > $PSITEST_CIDIPTOL) {
+          $j = $i+1; 
+          fail_test("CI dipole $j of $size_ci_dip_ref"); $fail = 1;
+        }
+        else {
+          $j = $i+1;
+          pass_test("CI dipole $j of $size_ci_dip_ref");
+        }
+      }
+    }
+  }
   
   return $fail;
 }
 
+sub dip_check
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/\|mu\|/) {
+      close(OUT);
+      return 1;
+    }
+  }
+
+  close(OUT);
+  return 0;
+}
+
+sub seek_ci_dip
+{
+  my $i = 0;
+  my @ci_dip;
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/\|mu\|/) {
+      @data = split(/ +/, $_);
+      $ci_dip[$i] = $data[4];
+      $i++;
+    }
+  }
+  
+  return @ci_dip;
+  close(OUT);
+}
+
 sub compare_dboc
 {
   my $fail = 0;
@@ -538,10 +823,35 @@ sub compare_mp2_energy
   else {
     pass_test("MP2 Energy");
   }
-  
+
+  if($fail == 0 && scs_check($REF_FILE) == 1) {
+    
+    if(abs(seek_scs_mp2($REF_FILE) - seek_scs_mp2($TEST_FILE)) > $PSITEST_ETOL) {
+      fail_test("SCS-MP2 Energy"); $fail = 1;
+    }
+    else {
+      pass_test("SCS-MP2 Energy");
+    }
+  } 
+ 
   return $fail;
 }
 
+sub scs_check
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/SCS\s+=\s+TRUE/) {
+      close(OUT);
+      return 1;
+    }
+  }
+  
+  close(OUT);
+  return 0;
+}
+
 sub compare_direct_mp2_energy
 {
   my $fail = 0;
@@ -934,6 +1244,26 @@ sub compare_findif_symm_freq
   return $fail;
 }
 
+sub compare_pair_energies
+{
+  my $wfn = $_[0];
+  my $spincase = $_[1];
+  my $fail = 0;
+  my $REF_FILE = "$SRC_PATH/output.ref";
+  my $TEST_FILE = "output.dat";
+
+  my @epair_s_ref = seek_pair_energies($REF_FILE, $wfn, $spincase);
+  my @epair_s_test = seek_pair_energies($TEST_FILE, $wfn, $spincase);  
+  if(!compare_arrays(\@epair_s_ref, \@epair_s_test, ($#epair_s_ref+1), $PSITEST_ETOL)) {
+    fail_test("$wfn $spincase Pair Energies"); $fail = 1;
+  }
+  else {
+    pass_test("$wfn $spincase Pair Energies");
+  }
+    
+  return $fail;
+}
+
 sub seek_nirreps
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -1049,7 +1379,7 @@ sub seek_mp2
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   seek(OUT,0,0);
   while(<OUT>) {
-    if (/MP2 total energy/) {
+    if (/\s+MP2 total energy/) {
       @data = split(/ +/, $_);
       $mp2 = $data[4];
       return $mp2;
@@ -1078,6 +1408,23 @@ sub seek_mp2_direct
   exit 1;
 }
 
+sub seek_scs_mp2
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/SCS-MP2 total energy/) {
+      @data = split(/ +/, $_);
+      $scs_mp2 = $data[4];
+      return $scs_mp2;
+    }
+  }
+  close(OUT);
+
+  printf "Error: Could not find SCS-MP2 energy in $_[0].\n";
+  exit 1;
+}
+
 sub seek_mp2r12
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -1113,6 +1460,23 @@ sub seek_mp2r12_mp2
   exit 1;
 }
 
+sub seek_cc2
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/Total CC2 energy/) {
+      @data = split(/ +/, $_);
+      $cc2 = $data[4];
+      return $cc2;
+    }
+  }
+  close(OUT);
+                                                                                                              
+  printf "Error: Could not find CC2 energy in $_[0].\n";
+  exit 1;
+}
+                                                                                                              
 sub seek_ccsd
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -1147,6 +1511,23 @@ sub seek_ccsd_t
   exit 1;
 }
 
+sub seek_cc3
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/Total CC3 energy/) {
+      @data = split(/ +/, $_);
+      $ccsd = $data[4];
+      return $ccsd;
+    }
+  }
+  close(OUT);
+
+  printf "Error: Could not find CC3 energy in $_[0].\n";
+  exit 1;
+}
+
 sub seek_bccd
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
@@ -1195,21 +1576,36 @@ sub seek_lambda
 sub seek_casscf
 {
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
-  @datafile = <OUT>;
-  close(OUT);
 
-  @line1 = split(/ +/, $datafile[0]);
-  $niter = $line1[1];
-  @line2 = split(/ +/, $datafile[$niter]);
-  $casscf = $line2[5];
-
-  if($casscf != 0.0) {
-    return $casscf;
+#Added to handle David's new CASSCF output format
+  while (<OUT>) {
+      if (/Final CASSCF Energy/) {
+	  @data = split(/=/, $_);
+	  $casscf = $data[2];
+	  return $casscf;
+      }
   }
 
   printf "Error: Could not find CASSCF energy in $_[0].\n";
   exit 1;
 }
+
+sub seek_rasscf
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+
+#Added to handle David's new RASSCF output format
+  while (<OUT>) {
+      if (/Final RASSCF Energy/) {
+	  @data = split(/=/, $_);
+	  $casscf = $data[2];
+	  return $casscf;
+      }
+  }
+
+  printf "Error: Could not find RASSCF energy in $_[0].\n";
+  exit 1;
+}
   
 sub seek_ci
 {
@@ -1299,8 +1695,8 @@ sub seek_geom_file11
 
   foreach $line (@datafile) {
     if($line =~ m/$match/) {
-      $lastiter = $linenum;
       $foundit = 1;
+      $lastiter = $linenum;
     }
     $linenum++;
   }
@@ -1336,8 +1732,8 @@ sub seek_grad_file11
 
   foreach $line (@datafile) {
     if($line =~ m/$match/) {
-      $lastiter = $linenum;
       $foundit = 1;
+      $lastiter = $linenum;
     }
     $linenum++;
   }
@@ -1374,7 +1770,7 @@ sub seek_findif_freq
     $linenum++;
     if ($line =~ m/$match/) {
       while ($j<$ndof) {
-        @test = split (/ +/,$datafile[$linenum+$j]);
+        @test = split (/ +/,$datafile[$linenum+1+$j]);
         $freq[$j] = $test[2];
         $j++;
       }
@@ -1496,7 +1892,7 @@ sub seek_eomcc
     return @evals;
   }
 
-  printf "Error: Could not find EOM-CCSD energies in $_[0].\n";
+  printf "Error: Could not find EOM energies in $_[0].\n";
   exit 1;
 }
 
@@ -1589,33 +1985,163 @@ sub seek_scf_polar
   exit 1;
 }
 
-sub seek_ccsd_polar
-{   
+sub seek_cc_response_property
+{
   open(OUT, "$_[0]") || die "cannot open $_[0] $!";
   @datafile = <OUT>;
   close(OUT);
-  
-  $linenum=0;
-  $start = 0;
+
   foreach $line (@datafile) {
-    if ($line =~ m/CCSD Dipole Polarizability/) {
-      $start = $linenum;
-    }
-    $linenum++;
+      if ($line =~ m/Property/) {
+	  @data = split(/ +/, $line);
+	  chomp($data[2]);
+	  return $data[2];
+      }
   }
 
-  for($i=0; $i < 3; $i++) {
-    @line = split(/ +/, $datafile[$start+7+$i]);
-    for($j=0; $j < 3; $j++) {
-      $polar[3*$i+$j] = $line[$j+2];
+  printf "Error: Could not determine type of response property in $_[0],\n";
+  exit 1;
+}
+
+sub seek_cc_response_gauge
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  foreach $line (@datafile) {
+      if ($line =~ m/Gauge/) {
+	  @data = split(/ +/, $line);
+	  chomp($data[2]);
+	  return $data[2];
+      }
+  }
+
+  printf "Error: Could not determine type of gauge in $_[0],\n";
+  exit 1;
+}
+
+sub seek_num_cc_response_freqs
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $value = 0;
+  foreach $line (@datafile) {
+      if ($line =~ m/Applied field/) {
+	  $value++;
+      }
+  }
+
+  if($value) {
+      return $value;
+  }
+
+  printf "Error: Could not find CC response frequencies in $_[0].\n";
+  exit 1;
+}
+
+sub seek_cc_response_freqs
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $value = 0;
+  foreach $line (@datafile) {
+    if ($line =~ m/Applied field/) {
+	@data = split(/ +/, $line);
+	chomp($data[4]);
+	$freqs[$value] = $data[4];
+	$value++;
     }
   }
-    
-  if($start != 0) {
-    return @polar;
+
+  if($value) {
+      return @freqs;
   }
-  
-  printf "Error: Could not find SCF polarizability tensor in $_[0].\n";
+
+  printf "Error: Could not find CC response frequencies in $_[0].\n";
+  exit 1;
+}
+
+sub seek_cc_optrot
+{
+  $freq = $_[1];
+  $gauge = $_[2];
+
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $linenum = 0;
+  foreach $line (@datafile) {
+      if($gauge eq "LENGTH") {
+	  if(($line =~ m/using length-gauge/)) {
+	      @data = split(/ +/, $datafile[$linenum+1]);
+	      if($data[0] =~ m/$freq/) {
+		  return $data[2];
+	      }
+	  }
+      }
+      elsif($gauge eq "VELOCITY") {
+	  if(($line =~ m/using velocity-gauge/)) {
+	      @data = split(/ +/, $datafile[$linenum+1]);
+	      if($data[0] =~ m/$freq/) {
+		  return $data[2];
+	      }
+	  }
+      }
+      $linenum++;
+  }
+
+  printf "Error: Could not find CC optical rotation in $_[0].\n";
+  exit 1;
+}
+
+sub seek_cc_polar
+{
+  $freq = $_[1];
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $linenum = 0;
+  foreach $line (@datafile) {
+      if($line =~ m/alpha_\($freq\)/) {
+	  @data = split(/ +/, $line);
+	  return $data[2];
+      }
+  }
+
+  printf "Error: Could not find CC polarizability in $_[0].\n";
+  exit 1;
+}
+
+sub seek_cc_delta
+{
+  $freq = $_[1];
+
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $linenum = 0;
+  foreach $line (@datafile) {
+      if($line =~ m/vector for length-gauge/) {
+#	  printf "%s\n", $datafile[$linenum+1];
+	  @data = split(/ +/, $datafile[$linenum+1]);
+	  $vector[0] = $data[3];
+	  $vector[1] = $data[6];
+	  $vector[2] = $data[9];
+#	  printf "%5.2f %5.2f %5.2f\n", $vector[0], $vector[1], $vector[2];
+	  return @vector;
+      }
+      $linenum++;
+  }
+
+  printf "Error: Could not find CC origin-dependence vector in $_[0].\n";
   exit 1;
 }
 
@@ -1882,6 +2408,175 @@ sub seek_mvd
   exit 1;
 }
 
+sub seek_pair_energies
+{
+  my $filename = $_[0];
+  my $wfn = $_[1];
+  my $spincase = $_[2];
+  my @pair_energies;
+
+  # This is the position of the desired pair energies
+  my $pos;
+  if ($wfn eq "MP2") {
+    $pos = 3;
+  }
+  elsif ($wfn eq "CC") {
+    $pos = 4;
+  }
+  else {
+    return @pair_energies;
+  }
+
+  open(OUT, "$filename") || die "cannot open $filename $!";
+  my @datafile = <OUT>;
+  close(OUT);
+
+  my $linenum=0;
+  my $start = 0;
+  my $end = 0;
+  foreach $line (@datafile) {
+    if ($line =~ m/$spincase pair energies/) {
+      $start = $linenum+3;
+    }
+    if ($start != 0 && $start <= $linenum && $end == 0 && $line =~ m/-------------/) {
+      $end = $linenum;
+    }
+    $linenum++;
+  }
+
+  for(my $i=$start; $i < $end; $i++) {
+    @line = split(/ +/, $datafile[$i]);
+    $pair_energies[$i-$start] = $line[$pos];
+  }
+
+  if($start != 0) {
+    return @pair_energies;
+  }
+
+  printf "Error: Could not find $wfn $spincase pair energies in $filename.\n";
+  exit 1;
+}
+
+sub seek_nstates
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  seek(OUT,0,0);
+  while(<OUT>) {
+    if (/Number of States =/) {
+      @data = split(/[ \t]+/, $_);
+      my $nstates = $data[5];
+      return $nstates;
+    }
+  }
+  close(OUT);
+
+  printf "Error: Could not find the number of states in $_[0].\n";
+  exit 1;
+}
+
+sub seek_excitation_energy
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $match = "$_[1]";
+  $nstates = "$_[2]";
+  $j=0;
+  $linenum=0;
+  foreach $line (@datafile) {
+    $linenum++;
+    if ($line =~ m/$match/) {
+      while ($j<$nstates) {
+        @test = split (/ +/,$datafile[$linenum+1+$j]);
+        $ex[$j] = $test[5];
+        $j++;
+      }
+    }
+  }
+
+  $OK = 1;
+  for($i=0; $i < $nstates; $i++) {
+    #printf "%d %8.4f\n", $i, $ex[$i];
+    if($ex[$i] < 0.0) {
+      $OK = 0; 
+    }
+  }
+  
+  if($OK && $nstates > 0) {
+    return @ex;
+  }
+
+  printf "Error: Check $_[1] in $_[0].\n";
+  exit 1;
+}
+
+sub seek_osc_str
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $match = "$_[1]";
+  $nstates = "$_[2]";
+  $j=0;
+  $linenum=0;
+  foreach $line (@datafile) {
+    $linenum++;
+    if ($line =~ m/$match/) {
+      while ($j<$nstates) {
+        @test = split (/ +/,$datafile[$linenum+1+$j]);
+        $os[$j] = $test[6];
+        $j++;
+      }
+    }
+  }
+
+  $OK = 1;
+  for($i=0; $i < $nstates; $i++) {
+    #printf "%d %8.4f\n", $i, $os[$i];
+    if($os[$i] < 0.0) {
+      $OK = 0; 
+    }
+  }
+  
+  if($OK && $nstates > 0) {
+    return @os;
+  }
+
+  printf "Error: Check $_[1] in $_[0].\n";
+  exit 1;
+}
+
+sub seek_rot_str
+{
+  open(OUT, "$_[0]") || die "cannot open $_[0] $!";
+  @datafile = <OUT>;
+  close(OUT);
+
+  $match = "$_[1]";
+  $nstates = "$_[2]";
+  $j=0;
+  $linenum=0;
+  foreach $line (@datafile) {
+    $linenum++;
+    if ($line =~ m/$match/) {
+      while ($j<$nstates) {
+        @test = split (/ +/,$datafile[$linenum+1+$j]);
+        $rs[$j] = $test[7];
+        $j++;
+      }
+    }
+  }
+
+  if($nstates > 0) {
+    return @rs;
+  }
+
+  printf "Error: Check $_[1] in $_[0].\n";
+  exit 1;
+}
+
 sub compare_arrays
 {
   my $A = $_[0];
@@ -1889,6 +2584,7 @@ sub compare_arrays
   my $dim = $_[2];
   my $tol = $_[3];
   my $OK = 1;
+  my $i=0;
   
   for($i=0; $i < $dim; $i++) {
     if(abs(@$A[$i] - @$B[$i]) > $tol) {
